@@ -5,6 +5,7 @@
  It may be used under the terms of the GNU General Public License. */
 
 #import <Foundation/Foundation.h>
+#import <CoreGraphics/CoreGraphics.h>
 
 @class HBJob;
 @class HBPicture;
@@ -36,12 +37,21 @@ typedef NS_ENUM(NSUInteger, HBState) {
 };
 
 // These constants specify the result of a scan or encode.
-typedef NS_ENUM(NSUInteger, HBCoreResult) {
-    HBCoreResultDone,
-    HBCoreResultCanceled,
-    HBCoreResultFailed,
+typedef NS_ENUM(NSUInteger, HBCoreResultCode) {
+    HBCoreResultCodeDone       = 0,
+    HBCoreResultCodeCanceled   = 1,
+    HBCoreResultCodeWrongInput = 2,
+    HBCoreResultCodeInit       = 3,
+    HBCoreResultCodeUnknown    = 4,
+    HBCoreResultCodeRead       = 5
 };
 
+struct HBCoreResult {
+    float            avgFps;
+    HBCoreResultCode code;
+};
+typedef struct HBCoreResult HBCoreResult;
+
 typedef void (^HBCoreProgressHandler)(HBState state, HBProgress progress, NSString *info);
 typedef void (^HBCoreCompletionHandler)(HBCoreResult result);
 
@@ -177,18 +187,11 @@ typedef void (^HBCoreCompletionHandler)(HBCoreResult result);
  *  into an CGImage.
  *
  *  @param index       the index of the desired image.
- *  @param title       Handle to hb_title_t of desired title
- *  @param frame       a HBPicture instance that describe the image's frame.
- *  @param deinterlace whether the preview image must be deinterlaced or not.
+ *  @param job           a HBJob instance.
  *
  *  @return a CGImageRef of the wanted image, NULL if the index is out of bounds.
  */
-- (nullable CGImageRef)copyImageAtIndex:(NSUInteger)index
-                      forTitle:(HBTitle *)title
-                  pictureFrame:(HBPicture *)frame
-                   deinterlace:(BOOL)deinterlace
-                        rotate:(int)angle
-                       flipped:(BOOL)flipped CF_RETURNS_RETAINED;
+- (nullable CGImageRef)copyImageAtIndex:(NSUInteger)index job:(HBJob *)job CF_RETURNS_RETAINED;
 
 /**
  *  Returns the counts of the available previews images.
