@@ -10,6 +10,7 @@
 #import "HBDVDDetector.h"
 #import "HBUtilities.h"
 #import "HBImageUtilities.h"
+#import "HBDirectUtilities.h"
 
 #import "HBStateFormatter+Private.h"
 #import "HBTitle+Private.h"
@@ -66,6 +67,7 @@ typedef void (^HBCoreCleanupHandler)(void);
 
 @end
 
+HB_OBJC_DIRECT_MEMBERS
 @implementation HBCore
 
 + (void)setDVDNav:(BOOL)enabled
@@ -102,7 +104,7 @@ typedef void (^HBCoreCleanupHandler)(void);
     if (self)
     {
         _name = @"HBCore";
-        _automaticallyPreventSleep = YES;
+        _automaticallyPreventSleep = NO;
         _state = HBStateIdle;
         _updateTimerQueue = queue;
         _titles = @[];
@@ -320,7 +322,9 @@ typedef void (^HBCoreCleanupHandler)(void);
 
     [HBUtilities writeToActivityLog:"%s scan done", self.name.UTF8String];
 
-    return (self.titles.count > 0) ? HBCoreResultDone : HBCoreResultFailed;
+    HBCoreResult result = {0};
+    result.code = (self.titles.count > 0) ? HBCoreResultCodeDone : HBCoreResultCodeUnknown;
+    return result;
 }
 
 - (void)cancelScan
@@ -331,31 +335,19 @@ typedef void (^HBCoreCleanupHandler)(void);
 
 #pragma mark - Preview images
 
-- (CGImageRef)copyImageAtIndex:(NSUInteger)index
-                      forTitle:(HBTitle *)title
-                  pictureFrame:(HBPicture *)frame
-                   deinterlace:(BOOL)deinterlace
-                        rotate:(int)angle
-                       flipped:(BOOL)flipped CF_RETURNS_RETAINED
+- (nullable CGImageRef)copyImageAtIndex:(NSUInteger)index job:(HBJob *)job CF_RETURNS_RETAINED
 {
     CGImageRef img = NULL;
 
-    hb_geometry_settings_t geo;
-    memset(&geo, 0, sizeof(geo));
-    geo.geometry.width = frame.displayWidth;
-    geo.geometry.height = frame.height;
-    // ignore the par.
-    geo.geometry.par.num = 1;
-    geo.geometry.par.den = 1;
-    int crop[4] = {frame.cropTop, frame.cropBottom, frame.cropLeft, frame.cropRight};
-    memcpy(geo.crop, crop, sizeof(int[4]));
-
-    hb_image_t *image = hb_get_preview2(_hb_handle, title.index, (int)index, &geo, deinterlace);
+    hb_job_t *hb_job = job.hb_job;
+    hb_dict_t *job_dict = hb_job_to_dict(hb_job);
+    hb_job_close(&hb_job);
+    hb_image_t *image = hb_get_preview3(_hb_handle, (int)index, job_dict);
 
     if (image)
     {
         // Create an CGImageRef and copy the libhb image into it.
-        // The image data returned by hb_get_preview2 is 4 bytes per pixel, BGRA format.
+        // The image data returned by hb_get_preview3 is 4 bytes per pixel, BGRA format.
         // Alpha is ignored.
         CFMutableDataRef imgData = CFDataCreateMutable(kCFAllocatorDefault, 0);
         CFDataSetLength(imgData, 3 * image->width * image->height);
@@ -378,9 +370,9 @@ typedef void (^HBCoreCleanupHandler)(void);
         CGDataProviderRef provider = CGDataProviderCreateWithCFData(imgData);
 
         CGBitmapInfo bitmapInfo = kCGBitmapByteOrderDefault | kCGImageAlphaNone;
-        CGColorSpaceRef colorSpace = copyColorSpace(title.hb_title->color_prim,
-                                                    title.hb_title->color_transfer,
-                                                    title.hb_title->color_matrix);
+        CGColorSpaceRef colorSpace = copyColorSpace(image->color_prim,
+                                                    image->color_transfer,
+                                                    image->color_matrix);
 
         img = CGImageCreate(image->width,
                             image->height,
@@ -401,16 +393,9 @@ typedef void (^HBCoreCleanupHandler)(void);
         hb_image_close(&image);
     }
 
-    if (img && (angle || flipped))
-    {
-        CGImageRef rotatedImg = CGImageRotated(img, angle, flipped);
-        CGImageRelease(img);
-        return rotatedImg;
-    }
-    else
-    {
-        return img;
-    }
+    hb_value_free(&job_dict);
+
+    return img;
 }
 
 - (NSUInteger)imagesCountForTitle:(HBTitle *)title
@@ -472,19 +457,17 @@ typedef void (^HBCoreCleanupHandler)(void);
         hb_rem(_hb_handle, job);
     }
 
-    HBCoreResult result = HBCoreResultDone;
-    switch (_hb_state->param.working.error)
+    HBCoreResult result = {_hb_state->param.working.rate_avg, (HBCoreResultCode)_hb_state->param.working.error};
+
+    switch (result.code)
     {
-        case HB_ERROR_NONE:
-            result = HBCoreResultDone;
+        case HBCoreResultCodeDone:
             [HBUtilities writeToActivityLog:"%s work done", self.name.UTF8String];
             break;
-        case HB_ERROR_CANCELED:
-            result = HBCoreResultCanceled;
+        case HBCoreResultCodeCanceled:
             [HBUtilities writeToActivityLog:"%s work canceled", self.name.UTF8String];
             break;
         default:
-            result = HBCoreResultFailed;
             [HBUtilities writeToActivityLog:"%s work failed", self.name.UTF8String];
             break;
     }
