@@ -5,7 +5,7 @@
  It may be used under the terms of the GNU General Public License. */
 
 #import "HBImageUtilities.h"
-#import <Cocoa/Cocoa.h>
+#import <CoreVideo/CoreVideo.h>
 #include "handbrake/handbrake.h"
 
 CGImageRef CreateScaledCGImageFromCGImage(CGImageRef image, CGFloat thumbnailHeight)
@@ -111,131 +111,120 @@ CGImageRef CGImageRotated(CGImageRef imgRef, CGFloat angle, BOOL flipped) CF_RET
     return rotatedImage;
 }
 
-static CGColorSpaceRef copyColorSpaceOld(int colorPrimaries)
-{
-    const CGFloat whitePoint[] = {0.95047, 1.0, 1.08883};
-    const CGFloat blackPoint[] = {0, 0, 0};
-
-    // See https://developer.apple.com/library/content/technotes/tn2257/_index.html
-    const CGFloat gamma[] = {1.961, 1.961, 1.961};
-
-    // RGB/XYZ Matrices (D65 white point)
-    switch (colorPrimaries) {
-        case HB_COLR_PRI_EBUTECH:
-        {
-            // Rec. 601, 625 line
-            const CGFloat matrix[] = {0.4305538, 0.2220043, 0.0201822,
-                0.3415498, 0.7066548, 0.1295534,
-                0.1783523, 0.0713409, 0.9393222};
-            return CGColorSpaceCreateCalibratedRGB(whitePoint, blackPoint, gamma, matrix);
-        }
-        case HB_COLR_PRI_SMPTEC:
-        {
-            // Rec. 601, 525 line
-            const CGFloat matrix[] = {0.3935209, 0.2123764, 0.0187391,
-                0.3652581, 0.7010599, 0.1119339,
-                0.1916769, 0.0865638, 0.9583847};
-            return CGColorSpaceCreateCalibratedRGB(whitePoint, blackPoint, gamma, matrix);
-        }
-        case HB_COLR_PRI_BT2020:
-        {
-            // Rec. 2020
-            const CGFloat matrix[] = {0.6369580, 0.2627002, 0.0000000,
-                0.1446169, 0.6779981, 0.0280727,
-                0.1688810, 0.0593017, 1.0609851};
-            return CGColorSpaceCreateCalibratedRGB(whitePoint, blackPoint, gamma, matrix);
-        }
-        case HB_COLR_PRI_BT709:
-        default:
-        {
-            // Rec. 709
-            const CGFloat matrix[] = {0.4124564, 0.2126729, 0.0193339,
-                0.3575761, 0.7151522, 0.1191920,
-                0.1804375, 0.0721750, 0.9503041};
-            return CGColorSpaceCreateCalibratedRGB(whitePoint, blackPoint, gamma, matrix);
-        }
-    }
-}
-
 CGColorSpaceRef copyColorSpace(int primaries, int transfer, int matrix)
 {
-    if (NSAppKitVersionNumber < NSAppKitVersionNumber10_11)
-    {
-        return copyColorSpaceOld(primaries);
-    }
-
-    CFStringRef primariesKey = NULL;
+    CFStringRef primariesValue = NULL;
     switch (primaries)
     {
         case HB_COLR_PRI_EBUTECH:
-            primariesKey = kCVImageBufferColorPrimaries_EBU_3213;
+            primariesValue = kCVImageBufferColorPrimaries_EBU_3213;
             break;
 
         case HB_COLR_PRI_SMPTEC:
-            primariesKey = kCVImageBufferColorPrimaries_SMPTE_C;
+            primariesValue = kCVImageBufferColorPrimaries_SMPTE_C;
             break;
 
         case HB_COLR_PRI_BT2020:
-            primariesKey = kCVImageBufferColorPrimaries_ITU_R_2020;
+            primariesValue = kCVImageBufferColorPrimaries_ITU_R_2020;
             break;
 
         case HB_COLR_PRI_BT709:
         default:
-            primariesKey = kCVImageBufferColorPrimaries_ITU_R_709_2;
+            primariesValue = kCVImageBufferColorPrimaries_ITU_R_709_2;
     }
 
-    CFStringRef transferKey = NULL;
+    CFStringRef transferValue = NULL;
+    CFNumberRef gammaValue = NULL;
     switch (transfer)
     {
-        case HB_COLR_TRA_SMPTE240M:
-            transferKey = kCVImageBufferTransferFunction_SMPTE_240M_1995;
+        case HB_COLR_TRA_GAMMA22:
+        {
+            transferValue = kCVImageBufferTransferFunction_UseGamma;
+            Float32 gamma = 2.2;
+            gammaValue = CFNumberCreate(NULL, kCFNumberFloat32Type, &gamma);
             break;
+        }
+
+        case HB_COLR_TRA_GAMMA28:
+        {
+            transferValue = kCVImageBufferTransferFunction_UseGamma;
+            Float32 gamma = 2.8;
+            gammaValue = CFNumberCreate(NULL, kCFNumberFloat32Type, &gamma);
+            break;
+        }
+
+        case HB_COLR_TRA_SMPTE240M:
+            transferValue = kCVImageBufferTransferFunction_SMPTE_240M_1995;
+            break;
+
+        case HB_COLR_TRA_LINEAR:
+            if (@available(macOS 10.14, *)) {
+            transferValue = kCVImageBufferTransferFunction_Linear;
+            break;
+            }
 
         case HB_COLR_TRA_BT2020_10:
         case HB_COLR_TRA_BT2020_12:
-            transferKey = kCVImageBufferTransferFunction_ITU_R_2020;
+            transferValue = kCVImageBufferTransferFunction_ITU_R_2020;
             break;
 
         case HB_COLR_TRA_SMPTEST2084:
-            transferKey = CFSTR("SMPTE_ST_2084_PQ"); //kCVImageBufferTransferFunction_SMPTE_ST_2084_PQ;
+            transferValue = kCVImageBufferTransferFunction_SMPTE_ST_2084_PQ;
             break;
 
         case HB_COLR_TRA_ARIB_STD_B67:
-            transferKey = CFSTR("ITU_R_2100_HLG"); //kCVImageBufferTransferFunction_ITU_R_2100_HLG;
+            transferValue = kCVImageBufferTransferFunction_ITU_R_2100_HLG;
+            break;
+
+        case HB_COLR_TRA_SMPTE428:
+            transferValue = kCVImageBufferTransferFunction_SMPTE_ST_428_1;
             break;
 
         case HB_COLR_TRA_BT709:
         default:
-            transferKey = kCVImageBufferTransferFunction_ITU_R_709_2;
+            transferValue = kCVImageBufferTransferFunction_ITU_R_709_2;
     }
 
-    CFStringRef matrixKey = NULL;
+    CFStringRef matrixValue = NULL;
     switch (matrix)
     {
         case HB_COLR_MAT_SMPTE170M:
-            matrixKey = kCVImageBufferYCbCrMatrix_ITU_R_601_4;
+            matrixValue = kCVImageBufferYCbCrMatrix_ITU_R_601_4;
             break;
 
         case HB_COLR_MAT_SMPTE240M:
-            matrixKey = kCVImageBufferYCbCrMatrix_SMPTE_240M_1995;
+            matrixValue = kCVImageBufferYCbCrMatrix_SMPTE_240M_1995;
             break;
 
         case HB_COLR_MAT_BT2020_NCL:
         case HB_COLR_MAT_BT2020_CL:
-            matrixKey = kCVImageBufferYCbCrMatrix_ITU_R_2020;
+            matrixValue = kCVImageBufferYCbCrMatrix_ITU_R_2020;
             break;
 
         case HB_COLR_MAT_BT709:
         default:
-            matrixKey = kCVImageBufferYCbCrMatrix_ITU_R_709_2;;
+            matrixValue = kCVImageBufferYCbCrMatrix_ITU_R_709_2;
     }
 
-    const void *keys[3] = { kCVImageBufferColorPrimariesKey, kCVImageBufferTransferFunctionKey, kCVImageBufferYCbCrMatrixKey };
-    const void *values[3] = { primariesKey, transferKey, matrixKey};
-    CFDictionaryRef attachments = CFDictionaryCreate(NULL, keys, values, 3, &kCFTypeDictionaryKeyCallBacks, &kCFTypeDictionaryValueCallBacks);
+    CGColorSpaceRef colorSpace = NULL;
+    if (transferValue == kCVImageBufferTransferFunction_UseGamma)
+    {
+        const void *keys[4] = { kCVImageBufferColorPrimariesKey, kCVImageBufferTransferFunctionKey, kCVImageBufferYCbCrMatrixKey, kCVImageBufferGammaLevelKey };
+        const void *values[4] = { primariesValue, transferValue, matrixValue, gammaValue };
+        CFDictionaryRef attachments = CFDictionaryCreate(NULL, keys, values, 4, &kCFTypeDictionaryKeyCallBacks, &kCFTypeDictionaryValueCallBacks);
 
-    CGColorSpaceRef colorSpace = CVImageBufferCreateColorSpaceFromAttachments(attachments);
-    CFRelease(attachments);
+        colorSpace = CVImageBufferCreateColorSpaceFromAttachments(attachments);
+        CFRelease(attachments);
+    }
+    else
+    {
+        const void *keys[3] = { kCVImageBufferColorPrimariesKey, kCVImageBufferTransferFunctionKey, kCVImageBufferYCbCrMatrixKey };
+        const void *values[3] = { primariesValue, transferValue, matrixValue };
+        CFDictionaryRef attachments = CFDictionaryCreate(NULL, keys, values, 3, &kCFTypeDictionaryKeyCallBacks, &kCFTypeDictionaryValueCallBacks);
+
+        colorSpace = CVImageBufferCreateColorSpaceFromAttachments(attachments);
+        CFRelease(attachments);
+    }
 
     return colorSpace;
 }
