@@ -16,6 +16,15 @@
 #import "HBTitle+Private.h"
 #import "HBMutablePreset.h"
 
+#import "HBRange.h"
+#import "HBVideo.h"
+#import "HBPicture.h"
+#import "HBFilters.h"
+#import "HBAudio.h"
+#import "HBSubtitles.h"
+
+#import "NSDictionary+HBAdditions.h"
+
 @implementation HBJob (HBJobConversion)
 
 - (NSDictionary *)jobDict
@@ -118,6 +127,11 @@
         job->chapter_markers = 0;
     }
 
+    if (self.metadataPassthru == NO && job->metadata && job->metadata->dict)
+    {
+        hb_dict_clear(job->metadata->dict);
+    }
+
     if (job->vcodec & HB_VCODEC_H264_MASK)
     {
         // iPod 5G atom
@@ -173,8 +187,8 @@
     }
 
     // Picture Size Settings
-    job->par.num = self.picture.parWidth;
-    job->par.den = self.picture.parHeight;
+    job->par.num = self.picture.parNum;
+    job->par.den = self.picture.parDen;
 
     // Video settings
     // Framerate
@@ -334,6 +348,10 @@
     {
         job->acodec_copy_mask |= HB_ACODEC_DCA_PASS;
     }
+    if (audioDefaults.allowMP2Passthru)
+    {
+        job->acodec_copy_mask |= HB_ACODEC_MP2_PASS;
+    }
     if (audioDefaults.allowMP3Passthru)
     {
         job->acodec_copy_mask |= HB_ACODEC_MP3_PASS;
@@ -406,10 +424,9 @@
     }
 
     // Now lets call the filters if applicable.
-    // The order of the filters is critical
+    hb_filter_object_t *filter;
 
     // Detelecine
-    hb_filter_object_t *filter;
     if (![self.filters.detelecine isEqualToString:@"off"])
     {
         int filter_id = HB_FILTER_DETELECINE;
@@ -453,6 +470,24 @@
         hb_value_free(&filter_dict);
     }
 
+    // Add framerate shaping filter
+    filter = hb_filter_init(HB_FILTER_VFR);
+    hb_add_filter(job, filter, [[NSString stringWithFormat:@"mode=%d:rate=%d/%d",
+                                 fps_mode, fps_num, fps_den] UTF8String]);
+
+    // Deblock
+    if (![self.filters.deblock isEqualToString:@"off"])
+    {
+        int filter_id = HB_FILTER_DEBLOCK;
+        hb_dict_t *filter_dict = hb_generate_filter_settings(filter_id,
+                                                             self.filters.deblock.UTF8String,
+                                                             self.filters.deblockTune.UTF8String,
+                                                             self.filters.deblockCustomString.UTF8String);
+        filter = hb_filter_init(filter_id);
+        hb_add_filter_dict(job, filter, filter_dict);
+        hb_value_free(&filter_dict);
+    }
+
     // Denoise
     if (![self.filters.denoise isEqualToString:@"off"])
     {
@@ -471,14 +506,14 @@
         hb_dict_free(&filter_dict);
     }
 
-    // Deblock
-    if (![self.filters.deblock isEqualToString:@"off"])
+    // Chroma Smooth
+    if (![self.filters.chromaSmooth isEqualToString:@"off"])
     {
-        int filter_id = HB_FILTER_DEBLOCK;
+        int filter_id = HB_FILTER_CHROMA_SMOOTH;
         hb_dict_t *filter_dict = hb_generate_filter_settings(filter_id,
-                                                             self.filters.deblock.UTF8String,
-                                                             self.filters.deblockTune.UTF8String,
-                                                             self.filters.deblockCustomString.UTF8String);
+                                                             self.filters.chromaSmooth.UTF8String,
+                                                             self.filters.chromaSmoothTune.UTF8String,
+                                                             self.filters.chromaSmoothCustomString.UTF8String);
         filter = hb_filter_init(filter_id);
         hb_add_filter_dict(job, filter, filter_dict);
         hb_value_free(&filter_dict);
@@ -511,30 +546,71 @@
         hb_dict_free(&filter_dict);
     }
 
-    // Add grayscale filter
+    // Grayscale
     if (self.filters.grayscale)
     {
         filter = hb_filter_init(HB_FILTER_GRAYSCALE);
         hb_add_filter(job, filter, NULL);
     }
 
-    // Add rotate filter
-    if (self.filters.rotate || self.filters.flip)
+    // Rotate
+    if (self.picture.angle || self.picture.flip)
     {
         int filter_id = HB_FILTER_ROTATE;
         hb_dict_t *filter_dict = hb_generate_filter_settings(filter_id,
                                                              NULL, NULL,
-                                                             [NSString stringWithFormat:@"angle=%d:hflip=%d", self.filters.rotate, self.filters.flip].UTF8String);
+                                                             [NSString stringWithFormat:@"angle=%d:hflip=%d",
+                                                              self.picture.angle, self.picture.flip].UTF8String);
 
         filter = hb_filter_init(filter_id);
         hb_add_filter_dict(job, filter, filter_dict);
         hb_dict_free(&filter_dict);
     }
 
-    // Add framerate shaping filter
-    filter = hb_filter_init(HB_FILTER_VFR);
-    hb_add_filter(job, filter, [[NSString stringWithFormat:@"mode=%d:rate=%d/%d",
-                                 fps_mode, fps_num, fps_den] UTF8String]);
+    // Pad
+    if (self.picture.padMode != HBPicturePadModeNone)
+    {
+        int filter_id = HB_FILTER_PAD;
+        NSString *color;
+        switch (self.picture.padColorMode) {
+            case HBPicturePadColorModeBlack:
+                color = @"black";
+                break;
+            case HBPicturePadColorModeDarkGray:
+                color = @"darkslategray";
+                break;
+            case HBPicturePadColorModeGray:
+                color = @"slategray";
+                break;
+            case HBPicturePadColorModeWhite:
+                color = @"white";
+                break;
+            case HBPicturePadColorModeCustom:
+                color = self.picture.padColorCustom;
+                break;
+        }
+        
+        NSString *settings = [NSString stringWithFormat:@"color=%@:top=%d:bottom=%d:left=%d:right=%d",
+                              color, self.picture.padTop, self.picture.padBottom, self.picture.padLeft, self.picture.padRight];
+        hb_dict_t *filter_dict = hb_generate_filter_settings(filter_id, NULL, NULL, settings.UTF8String);
+
+        filter = hb_filter_init(filter_id);
+        hb_add_filter_dict(job, filter, filter_dict);
+        hb_dict_free(&filter_dict);
+    }
+
+    // Colorspace
+    if (![self.filters.colorspace isEqualToString:@"off"])
+    {
+        int filter_id = HB_FILTER_COLORSPACE;
+        hb_dict_t *filter_dict = hb_generate_filter_settings(filter_id,
+                                                             self.filters.colorspace.UTF8String,
+                                                             NULL,
+                                                             self.filters.colorspaceCustomString.UTF8String);
+        filter = hb_filter_init(filter_id);
+        hb_add_filter_dict(job, filter, filter_dict);
+        hb_value_free(&filter_dict);
+    }
 
     return job;
 }
