@@ -21,6 +21,13 @@
 #import "HBAudioTransformers.h"
 #import "HBLocalizationUtilities.h"
 
+#import "HBRange.h"
+#import "HBVideo.h"
+#import "HBPicture.h"
+#import "HBFilters.h"
+#import "HBAudio.h"
+#import "HBSubtitles.h"
+
 #include "handbrake/handbrake.h"
 
 // Text Styles
@@ -72,15 +79,15 @@ static HBMixdownTransformer    *mixdownTransformer;
         NSString *title = nil;
         if (container->format & HB_MUX_MASK_MP4)
         {
-            title = HBKitLocalizedString(@"MP4 File", @"HBJob -> Format display name");
+            title = @"MP4";
         }
         else if (container->format & HB_MUX_MASK_MKV)
         {
-            title = HBKitLocalizedString(@"MKV File", @"HBJob -> Format display name");
+            title = @"MKV";
         }
         else if (container->format & HB_MUX_MASK_WEBM)
         {
-            title = HBKitLocalizedString(@"WebM File", @"HBJob -> Format display name");
+            title = @"WebM";
         }
         else
         {
@@ -98,12 +105,21 @@ static HBMixdownTransformer    *mixdownTransformer;
 {
     if (!detailAttr)
     {
+        
+        CGFloat indent = 100;
+        NSBundle *bundle = [NSBundle bundleForClass:[HBJob class]];
+        NSString *currentLocalization = bundle.preferredLocalizations.firstObject;
+        if ([currentLocalization hasPrefix:@"de"])
+        {
+            indent = 120;
+        }
+        
         // Attributes
         NSMutableParagraphStyle *ps = [NSParagraphStyle.defaultParagraphStyle mutableCopy];
-        ps.headIndent = 88.0;
+        ps.headIndent = indent;
         ps.paragraphSpacing = 1.0;
-        ps.tabStops = @[[[NSTextTab alloc] initWithType:NSRightTabStopType location:88],
-                        [[NSTextTab alloc] initWithType:NSLeftTabStopType location:90]];
+        ps.tabStops = @[[[NSTextTab alloc] initWithType:NSRightTabStopType location:indent - 2],
+                        [[NSTextTab alloc] initWithType:NSLeftTabStopType location:indent]];
 
         detailAttr = @{NSFontAttributeName: [NSFont systemFontOfSize:NSFont.smallSystemFontSize],
                        NSParagraphStyleAttributeName: ps,
@@ -205,7 +221,27 @@ static HBMixdownTransformer    *mixdownTransformer;
     NSMutableAttributedString *attrString = [[NSMutableAttributedString alloc] init];
     NSMutableString *options = [NSMutableString string];
 
-    [options appendString:@(hb_container_get_name(self.container))];
+    NSString *containerName;
+
+    if (self.container & HB_MUX_MASK_MP4)
+    {
+        containerName = @"MP4";
+    }
+    else if (self.container & HB_MUX_MASK_MKV)
+    {
+        containerName = @"MKV";
+    }
+    else if (self.container & HB_MUX_MASK_WEBM)
+    {
+        containerName = @"WebM";
+    }
+    else
+    {
+        containerName = @(hb_container_get_name(self.container));
+    }
+
+    [options appendString:containerName];
+
 
     if (self.chaptersEnabled)
     {
@@ -272,10 +308,6 @@ static HBMixdownTransformer    *mixdownTransformer;
     NSMutableAttributedString *attrString = [[NSMutableAttributedString alloc] init];
 
     NSString *pictureInfo = self.picture.summary;
-    if (self.picture.keepDisplayAspect)
-    {
-        pictureInfo = [pictureInfo stringByAppendingString:HBKitLocalizedString(@" Keep Aspect Ratio", @"Dimensions description")];
-    }
     [attrString appendString:@"\t"      withAttributes:detailAttr];
     [attrString appendString:HBKitLocalizedString(@"Dimensions:", @"Dimensions description") withAttributes:detailBoldAttr];
     [attrString appendString:@" \t"             withAttributes:detailAttr];
@@ -361,7 +393,22 @@ static HBMixdownTransformer    *mixdownTransformer;
         }
 
         [summary appendString:@")"];
+    }
 
+    // Chroma Smooth
+    if (![filters.chromaSmooth isEqualToString:@"off"])
+    {
+        [summary appendFormat:@", %@ (%@", HBKitLocalizedString(@"Chroma Smooth", @"Filters description"), [[[HBFilters chromaSmoothPresetDict] allKeysForObject:filters.chromaSmooth] firstObject]];
+        if (![filters.chromaSmooth isEqualToString:@"custom"])
+        {
+            [summary appendFormat:@", %@", [[[HBFilters chromaSmoothTunesDict] allKeysForObject:filters.chromaSmoothTune] firstObject]];
+        }
+        else
+        {
+            [summary appendFormat:@", %@", filters.chromaSmoothCustomString];
+        }
+
+        [summary appendString:@")"];
     }
 
     // Sharpen
@@ -395,6 +442,18 @@ static HBMixdownTransformer    *mixdownTransformer;
         [summary appendFormat:@", %@", HBKitLocalizedString(@"Grayscale", @"Filters description")];
     }
 
+    // Colorspace
+    if (![filters.colorspace isEqualToString:@"off"])
+    {
+        [summary appendFormat:@", %@ (%@", HBKitLocalizedString(@"Colorspace", @"Filters description"), [[[HBFilters colorspacePresetDict] allKeysForObject:filters.colorspace] firstObject]];
+        if ([filters.colorspace isEqualToString:@"custom"])
+        {
+            [summary appendFormat:@", %@", filters.colorspaceCustomString];
+        }
+
+        [summary appendString:@")"];
+    }
+
     if ([summary hasPrefix:@", "])
     {
         [summary deleteCharactersInRange:NSMakeRange(0, 2)];
@@ -920,6 +979,13 @@ static HBMixdownTransformer    *mixdownTransformer;
         }
     }
 
+    // Chroma Smooth
+    if (![filters.chromaSmooth isEqualToString:@"off"])
+    {
+        [summary appendString:HBKitLocalizedString(@"Chroma Smooth", @"HBJob -> filters short description")];
+        [summary appendString:@", "];
+    }
+
     // Sharpen
     if (![filters.sharpen isEqualToString:@"off"])
     {
@@ -938,10 +1004,10 @@ static HBMixdownTransformer    *mixdownTransformer;
         [summary appendString:@", "];
     }
 
-    // Rotation
-    if (filters.rotate || filters.flip)
+    // Colorspace
+    if (![filters.colorspace isEqualToString:@"off"])
     {
-        [summary appendString:HBKitLocalizedString(@"Rotation", @"HBJob -> filters short description")];
+        [summary appendString:HBKitLocalizedString(@"Colorspace", @"HBJob -> filters short description")];
         [summary appendString:@", "];
     }
 
@@ -972,15 +1038,15 @@ static HBMixdownTransformer    *mixdownTransformer;
     int container = [value intValue];
     if (container & HB_MUX_MASK_MP4)
     {
-        return HBKitLocalizedString(@"MP4 File", @"HBJob -> Format display name");
+        return @"MP4";
     }
     else if (container & HB_MUX_MASK_MKV)
     {
-        return HBKitLocalizedString(@"MKV File", @"HBJob -> Format display name");
+        return @"MKV";
     }
     else if (container & HB_MUX_MASK_WEBM)
     {
-        return HBKitLocalizedString(@"WebM File", @"HBJob -> Format display name");
+        return @"WebM";
     }
     else
     {
@@ -1003,15 +1069,15 @@ static HBMixdownTransformer    *mixdownTransformer;
 
 - (id)reverseTransformedValue:(id)value
 {
-    if ([value isEqualToString:HBKitLocalizedString(@"MP4 File", @"HBJob -> Format display name")])
+    if ([value isEqualToString:@"MP4"])
     {
         return @(HB_MUX_AV_MP4);
     }
-    else if ([value isEqualToString:HBKitLocalizedString(@"MKV File", @"HBJob -> Format display name")])
+    else if ([value isEqualToString:@"MKV"])
     {
         return @(HB_MUX_AV_MKV);
     }
-    else if ([value isEqualToString:HBKitLocalizedString(@"WebM File", @"HBJob -> Format display name")])
+    else if ([value isEqualToString:@"WebM"])
     {
         return @(HB_MUX_AV_WEBM);
     }
