@@ -6,20 +6,18 @@
 
 #import <Foundation/Foundation.h>
 
-@class HBPreset;
-@class HBMutablePreset;
+@class HBPreset, HBMutablePreset;
 @class HBTitle;
+@class HBVideo;
+@class HBRange;
+@class HBPicture;
+@class HBFilters;
+@class HBAudio;
+@class HBSubtitles;
+@class HBChapter;
 
-#import "HBRange.h"
-#import "HBVideo.h"
-#import "HBPicture.h"
-#import "HBFilters.h"
-
-#import "HBAudio.h"
-#import "HBSubtitles.h"
-#import "HBChapter.h"
-
-#import "HBSecurityAccessToken.h"
+#import <HandBrakeKit/HBPresetCoding.h>
+#import <HandBrakeKit/HBSecurityAccessToken.h>
 
 NS_ASSUME_NONNULL_BEGIN
 
@@ -31,13 +29,14 @@ extern NSString *HBChaptersChangedNotification;
  */
 @interface HBJob : NSObject <NSSecureCoding, NSCopying, HBPresetCoding, HBSecurityScope>
 
-- (instancetype)initWithTitle:(HBTitle *)title andPreset:(HBPreset *)preset;
-
-- (void)applyPreset:(HBPreset *)preset;
+- (nullable instancetype)initWithTitle:(HBTitle *)title preset:(HBPreset *)preset;
 
 @property (nonatomic, readwrite, weak, nullable) HBTitle *title;
 @property (nonatomic, readonly) int titleIdx;
 
+// Whether the source is a single file or a DVD-Video/Blu-ray
+@property (nonatomic, readonly, getter=isStream) BOOL stream;
+
 @property (nonatomic, readwrite, copy) NSString *presetName;
 
 /// The file URL of the source.
@@ -72,6 +71,8 @@ extern NSString *HBChaptersChangedNotification;
 @property (nonatomic, readwrite) BOOL chaptersEnabled;
 @property (nonatomic, readonly) NSArray<HBChapter *> *chapterTitles;
 
+@property (nonatomic, readwrite) BOOL metadataPassthru;
+
 @property (nonatomic, readwrite, weak, nullable) NSUndoManager *undo;
 
 @end
