@@ -39,13 +39,13 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
 @property (nonatomic, readwrite) HBSecurityAccessToken *fileURLToken;
 @property (nonatomic, readwrite) HBSecurityAccessToken *outputURLToken;
 @property (nonatomic, readwrite) HBSecurityAccessToken *subtitlesToken;
-@property (nonatomic, readwrite) NSInteger *accessCount;
+@property (nonatomic, readwrite) NSInteger accessCount;
 
 @end
 
 @implementation HBJob
 
-- (instancetype)initWithTitle:(HBTitle *)title andPreset:(HBPreset *)preset
+- (nullable instancetype)initWithTitle:(HBTitle *)title preset:(HBPreset *)preset
 {
     self = [super init];
     if (self) {
@@ -54,6 +54,7 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
 
         _title = title;
         _titleIdx = title.index;
+        _stream = title.isStream;
 
         _name = [title.name copy];
         _fileURL = title.url;
@@ -70,10 +71,13 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
         _subtitles = [[HBSubtitles alloc] initWithJob:self];
 
         _chapterTitles = [title.chapters copy];
-
+        _metadataPassthru = YES;
         _presetName = @"";
 
-        [self applyPreset:preset];
+        if ([self applyPreset:preset error:NULL] == NO)
+        {
+            return nil;
+        }
     }
 
     return self;
@@ -81,29 +85,45 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
 
 #pragma mark - HBPresetCoding
 
-- (void)applyPreset:(HBPreset *)preset
+- (BOOL)applyPreset:(HBPreset *)preset error:(NSError * __autoreleasing *)outError
 {
     NSAssert(self.title, @"HBJob: calling applyPreset: without a valid title loaded");
 
-    self.presetName = preset.name;
     NSDictionary *jobSettings = [self.title jobSettingsWithPreset:preset];
 
-    self.container = hb_container_get_from_name([preset[@"FileFormat"] UTF8String]);
+    if (jobSettings)
+    {
+        self.presetName = preset.name;
 
-    // MP4 specifics options.
-    self.mp4HttpOptimize = [preset[@"Mp4HttpOptimize"] boolValue];
-    self.mp4iPodCompatible = [preset[@"Mp4iPodCompatible"] boolValue];
+        self.container = hb_container_get_from_name([preset[@"FileFormat"] UTF8String]);
 
-    self.alignAVStart = [preset[@"AlignAVStart"] boolValue];
+        // MP4 specifics options.
+        self.mp4HttpOptimize = [preset[@"Mp4HttpOptimize"] boolValue];
+        self.mp4iPodCompatible = [preset[@"Mp4iPodCompatible"] boolValue];
 
-    // Chapter Markers
-    self.chaptersEnabled = [preset[@"ChapterMarkers"] boolValue];
+        self.alignAVStart = [preset[@"AlignAVStart"] boolValue];
 
-    [self.audio applyPreset:preset jobSettings:jobSettings];
-    [self.subtitles applyPreset:preset jobSettings:jobSettings];
-    [self.video applyPreset:preset jobSettings:jobSettings];
-    [self.picture applyPreset:preset jobSettings:jobSettings];
-    [self.filters applyPreset:preset jobSettings:jobSettings];
+        self.chaptersEnabled = [preset[@"ChapterMarkers"] boolValue];
+        self.metadataPassthru = [preset[@"MetadataPassthrough"] boolValue];
+
+        [self.audio applyPreset:preset jobSettings:jobSettings];
+        [self.subtitles applyPreset:preset jobSettings:jobSettings];
+        [self.video applyPreset:preset jobSettings:jobSettings];
+        [self.picture applyPreset:preset jobSettings:jobSettings];
+        [self.filters applyPreset:preset jobSettings:jobSettings];
+
+        return YES;
+    }
+    else
+    {
+        if (outError != NULL)
+        {
+            *outError = [NSError errorWithDomain:@"HBError" code:0 userInfo:@{NSLocalizedDescriptionKey: NSLocalizedString(@"Invalid preset", @"HBJob -> invalid preset"),
+                                                                          NSLocalizedRecoverySuggestionErrorKey: NSLocalizedString(@"The preset is not a valid, try to select a different one.", @"Job preset -> invalid preset recovery suggestion")}];
+        }
+
+        return NO;
+    }
 }
 
 - (void)writeToPreset:(HBMutablePreset *)preset
@@ -111,12 +131,14 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
     preset.name = self.presetName;
 
     preset[@"FileFormat"] = @(hb_container_get_short_name(self.container));
-    preset[@"ChapterMarkers"] = @(self.chaptersEnabled);
+
     // MP4 specifics options.
     preset[@"Mp4HttpOptimize"] = @(self.mp4HttpOptimize);
+    preset[@"AlignAVStart"] = @(self.alignAVStart);
     preset[@"Mp4iPodCompatible"] = @(self.mp4iPodCompatible);
 
-    preset[@"AlignAVStart"] = @(self.alignAVStart);
+    preset[@"ChapterMarkers"] = @(self.chaptersEnabled);
+    preset[@"MetadataPassthrough"] = @(self.metadataPassthru);
 
     [@[self.video, self.filters, self.picture, self.audio, self.subtitles] makeObjectsPerformSelector:@selector(writeToPreset:)
                                                                                                            withObject:preset];
@@ -283,11 +305,42 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
     [[NSNotificationCenter defaultCenter] postNotificationName:HBChaptersChangedNotification object:self];
 }
 
+- (void)setMetadataPassthru:(BOOL)metadataPassthru
+{
+    if (metadataPassthru != _metadataPassthru)
+    {
+        [[self.undo prepareWithInvocationTarget:self] setMetadataPassthru:_metadataPassthru];
+    }
+    _metadataPassthru = metadataPassthru;
+    [[NSNotificationCenter defaultCenter] postNotificationName:HBContainerChangedNotification object:self];
+}
+
 - (NSString *)description
 {
     return self.name;
 }
 
+- (void)refreshSecurityScopedResources
+{
+    if (_fileURLBookmark)
+    {
+        NSURL *resolvedURL = [HBUtilities URLFromBookmark:_fileURLBookmark];
+        if (resolvedURL)
+        {
+            _fileURL = resolvedURL;
+        }
+    }
+    if (_outputURLFolderBookmark)
+    {
+        NSURL *resolvedURL = [HBUtilities URLFromBookmark:_outputURLFolderBookmark];
+        if (resolvedURL)
+        {
+            _outputURL = resolvedURL;
+        }
+    }
+    [self.subtitles refreshSecurityScopedResources];
+}
+
 - (BOOL)startAccessingSecurityScopedResource
 {
 #ifdef __SANDBOX_ENABLED__
@@ -329,6 +382,7 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
         copy->_name = [_name copy];
         copy->_presetName = [_presetName copy];
         copy->_titleIdx = _titleIdx;
+        copy->_stream = _stream;
 
         copy->_fileURLBookmark = [_fileURLBookmark copy];
         copy->_outputURLFolderBookmark = [_outputURLFolderBookmark copy];
@@ -357,6 +411,8 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
 
         copy->_chaptersEnabled = _chaptersEnabled;
         copy->_chapterTitles = [[NSArray alloc] initWithArray:_chapterTitles copyItems:YES];
+
+        copy->_metadataPassthru = _metadataPassthru;
     }
 
     return copy;
@@ -376,6 +432,7 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
     encodeObject(_name);
     encodeObject(_presetName);
     encodeInt(_titleIdx);
+    encodeBool(_stream);
 
 #ifdef __SANDBOX_ENABLED__
     if (!_fileURLBookmark)
@@ -418,6 +475,8 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
 
     encodeBool(_chaptersEnabled);
     encodeObject(_chapterTitles);
+
+    encodeBool(_metadataPassthru);
 }
 
 - (instancetype)initWithCoder:(NSCoder *)decoder
@@ -429,36 +488,14 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
         decodeObjectOrFail(_name, NSString);
         decodeObjectOrFail(_presetName, NSString);
         decodeInt(_titleIdx); if (_titleIdx < 0) { goto fail; }
+        decodeBool(_stream);
 
 #ifdef __SANDBOX_ENABLED__
         decodeObject(_fileURLBookmark, NSData)
-
-        if (_fileURLBookmark)
-        {
-            _fileURL = [HBUtilities URLFromBookmark:_fileURLBookmark];
-        }
-
-        if (!_fileURL)
-        {
-            decodeObjectOrFail(_fileURL, NSURL);
-        }
-
         decodeObject(_outputURLFolderBookmark, NSData)
-
-        if (_outputURLFolderBookmark)
-        {
-            _outputURL = [HBUtilities URLFromBookmark:_outputURLFolderBookmark];
-        }
-
-        if (!_outputURL)
-        {
-            decodeObject(_outputURL, NSURL);
-        }
-#else
+#endif
         decodeObjectOrFail(_fileURL, NSURL);
         decodeObject(_outputURL, NSURL);
-#endif
-
         decodeObject(_outputFileName, NSString);
 
         decodeInt(_container); if (_container != HB_MUX_MP4 && _container != HB_MUX_MKV && _container != HB_MUX_WEBM) { goto fail; }
@@ -483,6 +520,8 @@ NSString *HBChaptersChangedNotification  = @"HBChaptersChangedNotification";
         decodeBool(_chaptersEnabled);
         decodeCollectionOfObjectsOrFail(_chapterTitles, NSArray, HBChapter);
 
+        decodeBool(_metadataPassthru);
+
         return self;
     }
 
