@@ -5,6 +5,8 @@
 
 #import "HBPreferencesController.h"
 
+@import HandBrakeKit.HBUtilities;
+
 NSString * const HBShowOpenPanelAtLaunch              = @"HBShowOpenPanelAtLaunch";
 NSString * const HBShowSummaryPreview                 = @"HBShowSummaryPreview";
 
@@ -38,6 +40,9 @@ NSString * const HBClearOldLogs                  = @"HBClearOldLogs";
 NSString * const HBQueuePauseIfLowSpace          = @"HBQueuePauseIfLowSpace";
 NSString * const HBQueueMinFreeSpace             = @"HBQueueMinFreeSpace";
 NSString * const HBQueueAutoClearCompletedItems  = @"HBQueueAutoClearCompletedItems";
+NSString * const HBQueueWorkerCounts             = @"HBQueueWorkerCounts";
+
+NSString * const HBKeepPresetEdits               = @"HBKeepPresetEdits";
 
 #define TOOLBAR_GENERAL     @"TOOLBAR_GENERAL"
 #define TOOLBAR_ADVANCED    @"TOOLBAR_ADVANCED"
@@ -76,13 +81,12 @@ NSString * const HBQueueAutoClearCompletedItems  = @"HBQueueAutoClearCompletedIt
  */
 + (void)registerUserDefaults
 {
-    NSString *moviesDirectory = [NSSearchPathForDirectoriesInDomains(NSMoviesDirectory, NSUserDomainMask, YES) firstObject];
-    NSURL *moviesURL = [NSURL fileURLWithPath:moviesDirectory isDirectory:YES];
+    NSURL *moviesURL = HBUtilities.defaultDestinationURL;
 
-    [[NSUserDefaults standardUserDefaults] registerDefaults:@{
+    [NSUserDefaults.standardUserDefaults registerDefaults:@{
         HBShowOpenPanelAtLaunch:            @YES,
         HBShowSummaryPreview:               @YES,
-        HBDefaultMpegExtension:             @"Auto",
+        HBDefaultMpegExtension:             @".mp4",
         HBUseDvdNav:                        @YES,
         HBLastDestinationDirectoryURL:      [NSKeyedArchiver archivedDataWithRootObject:moviesURL],
         HBLastSourceDirectoryURL:           [NSKeyedArchiver archivedDataWithRootObject:moviesURL],
@@ -99,8 +103,10 @@ NSString * const HBQueueAutoClearCompletedItems  = @"HBQueueAutoClearCompletedIt
         HBCqSliderFractional:               @2,
         HBQueuePauseIfLowSpace:             @YES,
         HBQueueMinFreeSpace:                @"2",
-        HBQueueAutoClearCompletedItems:     @NO
-        }];
+        HBQueueAutoClearCompletedItems:     @NO,
+        HBQueueWorkerCounts:                @1,
+        HBKeepPresetEdits:                  @YES
+    }];
 
     // Overwrite the update check interval because previous versions
     // could be set to a daily check.
@@ -138,12 +144,17 @@ NSString * const HBQueueAutoClearCompletedItems  = @"HBQueueAutoClearCompletedIt
  */
 - (void)windowDidLoad
 {
-    NSToolbar *toolbar = [[NSToolbar alloc] initWithIdentifier: @"Preferences Toolbar"];
-    [toolbar setDelegate: self];
-    [toolbar setAllowsUserCustomization: NO];
-    [toolbar setDisplayMode: NSToolbarDisplayModeIconAndLabel];
-    [toolbar setSizeMode: NSToolbarSizeModeRegular];
-    [[self window] setToolbar: toolbar];
+    if (@available (macOS 11, *))
+    {
+        self.window.toolbarStyle = NSWindowToolbarStylePreference;
+    }
+
+    NSToolbar *toolbar = [[NSToolbar alloc] initWithIdentifier:@"Preferences Toolbar"];
+    toolbar.delegate = self;
+    toolbar.allowsUserCustomization = NO;
+    toolbar.displayMode = NSToolbarDisplayModeIconAndLabel;
+    toolbar.sizeMode = NSToolbarSizeModeRegular;
+    self.window.toolbar = toolbar;
 
     // Format token field initialization
     [self.formatTokenField setTokenizingCharacterSet:[NSCharacterSet characterSetWithCharactersInString:@"%%"]];
@@ -153,7 +164,7 @@ NSString * const HBQueueAutoClearCompletedItems  = @"HBQueueAutoClearCompletedIt
     [self.builtInTokenField setTokenizingCharacterSet:[NSCharacterSet characterSetWithCharactersInString:@"%%"]];
     [self.builtInTokenField setStringValue:[self.buildInFormatTokens componentsJoinedByString:@"%%"]];
 
-    [toolbar setSelectedItemIdentifier: TOOLBAR_GENERAL];
+    toolbar.selectedItemIdentifier = TOOLBAR_GENERAL;
     [self setPrefView:nil];
 }
 
@@ -161,17 +172,27 @@ NSString * const HBQueueAutoClearCompletedItems  = @"HBQueueAutoClearCompletedIt
      itemForItemIdentifier: (NSString *)ident
  willBeInsertedIntoToolbar: (BOOL)flag
 {
-    if ( [ident isEqualToString:TOOLBAR_GENERAL] )
+    if ([ident isEqualToString:TOOLBAR_GENERAL])
     {
+        NSImage *image = [NSImage imageNamed:NSImageNamePreferencesGeneral];
+        if (@available (macOS 11, *))
+        {
+            image = [NSImage imageWithSystemSymbolName:@"gearshape" accessibilityDescription:@"General preferences"];
+        }
         return [self toolbarItemWithIdentifier:ident
                                          label:NSLocalizedString(@"General", @"Preferences General Toolbar Item")
-                                         image:[NSImage imageNamed:NSImageNamePreferencesGeneral]];
+                                         image:image];
     }
-    else if ( [ident isEqualToString:TOOLBAR_ADVANCED] )
+    else if ([ident isEqualToString:TOOLBAR_ADVANCED])
     {
+        NSImage *image = [NSImage imageNamed:NSImageNameAdvanced];
+        if (@available (macOS 11, *))
+        {
+            image = [NSImage imageWithSystemSymbolName:@"gearshape.2" accessibilityDescription:@"General preferences"];
+        }
         return [self toolbarItemWithIdentifier:ident
                                          label:NSLocalizedString(@"Advanced", @"Preferences Advanced Toolbar Item")
-                                         image:[NSImage imageNamed:NSImageNameAdvanced]];
+                                         image:image];
     }
 
     return nil;
