@@ -6,7 +6,7 @@
 
 #import "HBPreviewController.h"
 #import "HBPreviewGenerator.h"
-#import "HBPictureController.h"
+#import "HBCroppingController.h"
 
 #import "HBController.h"
 #import "HBPreviewView.h"
@@ -27,7 +27,7 @@
 #define MIN_WIDTH 480.0
 #define MIN_HEIGHT 360.0
 
-@interface HBPreviewController () <HBPreviewGeneratorDelegate, HBPictureHUDControllerDelegate, HBEncodingProgressHUDControllerDelegate, HBPlayerHUDControllerDelegate>
+@interface HBPreviewController () <NSMenuItemValidation, HBPreviewGeneratorDelegate, HBPictureHUDControllerDelegate, HBEncodingProgressHUDControllerDelegate, HBPlayerHUDControllerDelegate>
 
 @property (nonatomic, readonly) HBPictureHUDController *pictureHUD;
 @property (nonatomic, readonly) HBEncodingProgressHUDController *encodingHUD;
@@ -40,7 +40,7 @@
 
 @property (nonatomic) id<HBPlayer> player;
 
-@property (nonatomic) HBPictureController *pictureSettingsWindow;
+@property (nonatomic) NSPopover *croppingPopover;
 
 @property (nonatomic) NSPoint windowCenterPoint;
 @property (nonatomic, weak) IBOutlet HBPreviewView *previewView;
@@ -57,7 +57,10 @@
 
 - (void)windowDidLoad
 {
-    [self.window.contentView setWantsLayer:YES];
+    self.window.tabbingMode = NSWindowTabbingModeDisallowed;
+    self.window.excludedFromWindowsMenu = YES;
+    self.window.acceptsMouseMovedEvents = YES;
+    self.window.contentView.wantsLayer = YES;
 
     // Read the window center position
     // We need the center and we can't use the
@@ -75,9 +78,6 @@
         self.windowCenterPoint = [self.window HB_centerPoint];
     }
 
-    self.window.excludedFromWindowsMenu = YES;
-    self.window.acceptsMouseMovedEvents = YES;
-
     _pictureHUD = [[HBPictureHUDController alloc] init];
     self.pictureHUD.delegate = self;
     _encodingHUD = [[HBEncodingProgressHUDController alloc] init];
@@ -143,7 +143,8 @@
 - (void)setPicture:(HBPicture *)picture
 {
     _picture = picture;
-    self.pictureSettingsWindow.picture = _picture;
+    [self.croppingPopover close];
+    self.croppingPopover = nil;
 }
 
 - (void)setGenerator:(HBPreviewGenerator *)generator
@@ -207,7 +208,6 @@
         [self.player pause];
     }
 
-    [self.pictureSettingsWindow close];
     [self.generator purgeImageCache];
 }
 
@@ -412,7 +412,7 @@
         [CATransaction begin];
         CABasicAnimation *fadeInAnimation = [CABasicAnimation animationWithKeyPath:@"opacity"];
         fadeInAnimation.fromValue = @([hud.layer.presentationLayer opacity]);
-        fadeInAnimation.toValue = @(1.0);
+        fadeInAnimation.toValue = @1.0;
         fadeInAnimation.beginTime = 0.0;
         fadeInAnimation.duration = ANIMATION_DUR;
 
@@ -430,7 +430,7 @@
         [CATransaction begin];
         CABasicAnimation *fadeOutAnimation = [CABasicAnimation animationWithKeyPath:@"opacity"];
         fadeOutAnimation.fromValue = @([hud.layer.presentationLayer opacity]);
-        fadeOutAnimation.toValue = @(0.0);
+        fadeOutAnimation.toValue = @0.0;
         fadeOutAnimation.beginTime = 0.0;
         fadeOutAnimation.duration = ANIMATION_DUR;
 
@@ -481,21 +481,22 @@
     if (self.generator && self.window.isVisible)
     {
         CGImageRef image = [self.generator copyImageAtIndex:idx shouldCache:YES];
-        self.previewView.image = image;
-        CFRelease(image);
+        if (image)
+        {
+            self.previewView.image = image;
+            CFRelease(image);
+        }
     }
 }
 
-- (void)showPictureSettings
+- (void)showCroppingSettings:(id)sender
 {
-    if (self.pictureSettingsWindow == nil)
-    {
-        self.pictureSettingsWindow = [[HBPictureController alloc] init];
-        self.pictureSettingsWindow.previewController = self;
-    }
-
-    self.pictureSettingsWindow.picture = self.picture;
-    [self.pictureSettingsWindow showWindow:self];
+    HBCroppingController *croppingController = [[HBCroppingController alloc] initWithPicture:self.picture];
+    self.croppingPopover = [[NSPopover alloc] init];
+    self.croppingPopover.behavior = NSPopoverBehaviorTransient;
+    self.croppingPopover.contentViewController = croppingController;
+    self.croppingPopover.appearance = [NSAppearance appearanceNamed:NSAppearanceNameVibrantDark];
+    [self.croppingPopover showRelativeToRect:[sender bounds] ofView:sender preferredEdge:NSMaxYEdge];
 }
 
 #pragma mark - Encoding mode
