@@ -79,7 +79,7 @@
  *
  * @param index picture index in title.
  */
-- (CGImageRef) copyImageAtIndex: (NSUInteger) index shouldCache: (BOOL) cache
+- (nullable CGImageRef) copyImageAtIndex: (NSUInteger) index shouldCache: (BOOL) cache
 {
     if (index >= self.imagesCount)
     {
@@ -92,15 +92,7 @@
 
     if (!theImage)
     {
-        HBFilters *filters = self.job.filters;
-        BOOL deinterlace = (![filters.deinterlace isEqualToString:@"off"]);
-
-        theImage = (CGImageRef)[self.scanCore copyImageAtIndex:index
-                                                           forTitle:self.job.title
-                                                       pictureFrame:self.job.picture
-                                                        deinterlace:deinterlace
-                                                        rotate:self.job.filters.rotate
-                                                       flipped:self.job.filters.flip];
+        theImage = [self.scanCore copyImageAtIndex:index job:self.job];
         if (cache && theImage)
         {
             // The cost is the number of pixels of the image
@@ -127,7 +119,7 @@
 
 - (CGSize)imageSize
 {
-    return CGSizeMake(self.job.picture.displayWidth, self.job.picture.height);
+    return CGSizeMake(self.job.picture.displayWidth, self.job.picture.displayHeight);
 }
 
 - (void)imagesSettingsDidChange
@@ -190,12 +182,7 @@
 
         if (image == NULL)
         {
-            image = (CGImageRef)[self.scanCore copyImageAtIndex:index
-                                                       forTitle:self.job.title
-                                                   pictureFrame:self.job.picture
-                                                    deinterlace:NO
-                                                         rotate:self.job.filters.rotate
-                                                        flipped:self.job.filters.flip];
+            image = [self.scanCore copyImageAtIndex:index job:self.job];
             CFAutorelease(image);
         }
 
@@ -276,6 +263,7 @@
     // Init the libhb core
     NSInteger level = [NSUserDefaults.standardUserDefaults integerForKey:HBLoggingLevel];
     self.core = [[HBCore alloc] initWithLogLevel:level name:@"PreviewCore"];
+    self.core.automaticallyPreventSleep = YES;
 
     HBStateFormatter *formatter = [[HBStateFormatter alloc] init];
     formatter.twoLines = NO;
@@ -292,7 +280,7 @@
          }
        completionHandler:^(HBCoreResult result) {
            // Encode done, call the delegate and close libhb handle
-           if (result == HBCoreResultDone)
+           if (result.code == HBCoreResultCodeDone)
            {
                [self.delegate didCreateMovieAtURL:destURL];
            }
