@@ -9,18 +9,18 @@
 #import "HBAppDelegate.h"
 
 #import "HBQueue.h"
+#import "HBQueueWorker.h"
 #import "HBQueueTableViewController.h"
 #import "HBQueueDetailsViewController.h"
 #import "HBQueueInfoViewController.h"
 #import "HBQueueMultiSelectionViewController.h"
 
-#import "HBDockTile.h"
 #import "HBPreferencesKeys.h"
 #import "NSArray+HBAdditions.h"
 
 @import HandBrakeKit;
 
-@interface HBQueueController () <NSUserNotificationCenterDelegate, HBQueueTableViewControllerDelegate, HBQueueDetailsViewControllerDelegate>
+@interface HBQueueController () <NSToolbarItemValidation, NSMenuItemValidation, NSUserNotificationCenterDelegate, HBQueueTableViewControllerDelegate, HBQueueDetailsViewControllerDelegate>
 
 @property (nonatomic) NSSplitViewController *splitViewController;
 @property (nonatomic) HBQueueTableViewController *tableViewController;
@@ -32,11 +32,11 @@
 /// useful to avoid updating the UI needlessly
 @property (nonatomic) BOOL visible;
 
-@property (nonatomic, readonly) HBDockTile *dockTile;
-
 @property (nonatomic) IBOutlet NSToolbarItem *ripToolbarItem;
 @property (nonatomic) IBOutlet NSToolbarItem *pauseToolbarItem;
 
+@property (nonatomic, readonly) dispatch_queue_t sendQueue;
+
 @end
 
 @interface HBQueueController (TouchBar) <NSTouchBarProvider, NSTouchBarDelegate>
@@ -54,11 +54,9 @@
     if (self = [super initWithWindowNibName:@"Queue"])
     {
         _queue = queue;
+        _sendQueue = dispatch_queue_create("fr.handbrake.SendToQueue", DISPATCH_QUEUE_SERIAL);
 
-        // Load the dockTile and instantiate initial text fields
-        _dockTile = [[HBDockTile alloc] initWithDockTile:NSApplication.sharedApplication.dockTile
-                                                  image:NSApplication.sharedApplication.applicationIconImage];
-        __block double dockIconProgress;
+        NSUserNotificationCenter.defaultUserNotificationCenter.delegate = self;
 
         [NSNotificationCenter.defaultCenter addObserverForName:HBQueueLowSpaceAlertNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
             [self queueLowDiskSpaceAlert];
@@ -68,30 +66,9 @@
             [self queueCompletedAlerts];
         }];
 
-        [NSNotificationCenter.defaultCenter addObserverForName:HBQueueProgressNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
-            // Update dock icon
-            double progress = [note.userInfo[HBQueueProgressNotificationPercentKey] doubleValue];
-
-#define dockTileUpdateFrequency 0.1f
-
-            if (dockIconProgress < 100.0 * progress)
-            {
-                double hours = [note.userInfo[HBQueueProgressNotificationHoursKey] doubleValue];
-                double minutes = [note.userInfo[HBQueueProgressNotificationMinutesKey] doubleValue];
-                double seconds = [note.userInfo[HBQueueProgressNotificationSecondsKey] doubleValue];
-
-                [self.dockTile updateDockIcon:progress hours:hours minutes:minutes seconds:seconds];
-                dockIconProgress += dockTileUpdateFrequency;
-            }
-        }];
-
         [NSNotificationCenter.defaultCenter addObserverForName:HBQueueDidCompleteItemNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
-            // Restore dock icon
-            [self.dockTile updateDockIcon:-1.0 withETA:@""];
-            dockIconProgress = 0;
-
             // Run the per item notification and actions
-            HBQueueItem *item = note.userInfo[HBQueueItemNotificationItemKey];
+            HBQueueJobItem *item = note.userInfo[HBQueueItemNotificationItemKey];
             if (item.state == HBQueueItemStateCompleted)
             {
                 [self sendToExternalApp:item];
@@ -102,8 +79,6 @@
                 [self itemCompletedAlerts:item];
             }
         }];
-
-        NSUserNotificationCenter.defaultUserNotificationCenter.delegate = self;
     }
 
     return self;
@@ -116,9 +91,12 @@
 
 - (void)windowDidLoad
 {
-    if (@available (macOS 10.12, *))
+    self.window.tabbingMode = NSWindowTabbingModeDisallowed;
+
+    if (@available (macOS 11, *))
     {
-        self.window.tabbingMode = NSWindowTabbingModeDisallowed;
+        self.window.toolbarStyle = NSWindowToolbarStyleUnified;
+        self.window.titlebarSeparatorStyle = NSTitlebarSeparatorStyleLine;
     }
 
     // Set up the child view controllers
@@ -154,8 +132,8 @@
     [NSNotificationCenter.defaultCenter addObserverForName:HBQueueDidChangeStateNotification object:_queue queue:NSOperationQueue.mainQueue usingBlock:^(NSNotification * _Nonnull note) {
         [self updateUI];
     }];
-    [self updateUI];
 
+    [self updateUI];
     [self tableViewDidSelectItemsAtIndexes:[NSIndexSet indexSet]];
 }
 
@@ -164,29 +142,35 @@
     [self updateToolbarButtonsState];
     [self.window.toolbar validateVisibleItems];
 
-    if (@available(macOS 10.12.2, *))
-    {
-        [self _touchBar_updateButtonsState];
-        [self _touchBar_validateUserInterfaceItems];
-    }
+    [self _touchBar_updateButtonsState];
+    [self _touchBar_validateUserInterfaceItems];
 
-    NSString *string;
+    NSString *subtitle;
     if (self.queue.pendingItemsCount == 0)
     {
         self.window.title = NSLocalizedString(@"Queue", @"Queue window title");
+        subtitle = NSLocalizedString(@"No encode pending", @"Queue status");
     }
     else
     {
         if (self.queue.pendingItemsCount == 1)
         {
-            string = [NSString stringWithFormat: NSLocalizedString(@"%d encode pending", @"Queue status"), self.queue.pendingItemsCount];
+            subtitle = [NSString stringWithFormat: NSLocalizedString(@"%lu encode pending", @"Queue status"), (unsigned long)self.queue.pendingItemsCount];
         }
         else
         {
-            string = [NSString stringWithFormat: NSLocalizedString(@"%d encodes pending", @"Queue status"), self.queue.pendingItemsCount];
+            subtitle = [NSString stringWithFormat: NSLocalizedString(@"%lu encodes pending", @"Queue status"), (unsigned long)self.queue.pendingItemsCount];
         }
 
-        self.window.title = [NSString stringWithFormat: NSLocalizedString(@"Queue (%@)", @"Queue window title"), string];
+        if (@available(macOS 11, *)) {} else
+        {
+            self.window.title = [NSString stringWithFormat: NSLocalizedString(@"Queue (%@)", @"Queue window title"), subtitle];
+        }
+    }
+
+    if (@available(macOS 11, *))
+    {
+        self.window.subtitle = subtitle;
     }
 }
 
@@ -305,115 +289,86 @@
  */
 - (void)removeQueueItemsAtIndexes:(NSIndexSet *)indexes
 {
-    if ([self.queue.items beginTransaction] == HBDistributedArrayContentReload)
-    {
-        // Do not execture the action if the array changed.
-        [self.queue.items commit];
-        return;
-    }
-
     if (indexes.count)
     {
         NSMutableIndexSet *mutableIndexes = [indexes mutableCopy];
         // if this is a currently encoding job, we need to be sure to alert the user,
         // to let them decide to cancel it first, then if they do, we can come back and
         // remove it
-        NSIndexSet *workingIndexes = [self.queue.items indexesOfObjectsUsingBlock:^BOOL(HBQueueItem *item) {
+        NSIndexSet *workingIndexes = [self.queue.items HB_indexesOfObjectsUsingBlock:^BOOL(HBQueueJobItem *item) {
             return item.state == HBQueueItemStateWorking;
         }];
 
-        if ([mutableIndexes containsIndexes:workingIndexes])
+        NSIndexSet *workingSelectedIndexes = [workingIndexes HB_intersectionWith:indexes];
+        [mutableIndexes removeIndexes:workingSelectedIndexes];
+
+        if (workingSelectedIndexes.count)
         {
-            [mutableIndexes removeIndexes:workingIndexes];
-            NSArray<HBQueueItem *> *workingItems = [self.queue.items filteredArrayUsingBlock:^BOOL(HBQueueItem *item) {
-                return item.state == HBQueueItemStateWorking;
-            }];
+            NSString *alertTitle = [NSString stringWithFormat:NSLocalizedString(@"Stop This Encode and Remove It?", @"Queue Stop Alert -> stop and remove message")];
 
-            if (self.queue.currentItem && [workingItems containsObject:self.queue.currentItem])
+            // Which window to attach the sheet to?
+            NSWindow *targetWindow = self.window;
+
+            NSAlert *alert = [[NSAlert alloc] init];
+            [alert setMessageText:alertTitle];
+            [alert setInformativeText:NSLocalizedString(@"Your movie will be lost if you don't continue encoding.", @"Queue Stop Alert -> stop and remove informative text")];
+            [alert addButtonWithTitle:NSLocalizedString(@"Keep Encoding", @"Queue Stop Alert -> stop and remove first button")];
+            [alert addButtonWithTitle:NSLocalizedString(@"Stop Encoding and Delete", @"Queue Stop Alert -> stop and remove second button")];
+            if (@available(macOS 11, *))
             {
-                NSString *alertTitle = [NSString stringWithFormat:NSLocalizedString(@"Stop This Encode and Remove It?", @"Queue Stop Alert -> stop and remove message")];
-
-                // Which window to attach the sheet to?
-                NSWindow *targetWindow = self.window;
-
-                NSAlert *alert = [[NSAlert alloc] init];
-                [alert setMessageText:alertTitle];
-                [alert setInformativeText:NSLocalizedString(@"Your movie will be lost if you don't continue encoding.", @"Queue Stop Alert -> stop and remove informative text")];
-                [alert addButtonWithTitle:NSLocalizedString(@"Keep Encoding", @"Queue Stop Alert -> stop and remove first button")];
-                [alert addButtonWithTitle:NSLocalizedString(@"Stop Encoding and Delete", @"Queue Stop Alert -> stop and remove second button")];
-                [alert setAlertStyle:NSAlertStyleCritical];
-
-                [alert beginSheetModalForWindow:targetWindow completionHandler:^(NSModalResponse returnCode) {
-                    if (returnCode == NSAlertSecondButtonReturn)
-                    {
-                        [self.queue.items beginTransaction];
-
-                        NSInteger index = [self.queue.items indexOfObject:self.queue.currentItem];
-                        [self.queue cancelCurrentItemAndContinue];
-
-                        [self.queue removeItemAtIndex:index];
-                        [self.queue.items commit];
-                    }
-                }];
+                alert.buttons.lastObject.hasDestructiveAction = true;
             }
+            [alert setAlertStyle:NSAlertStyleCritical];
+
+            [alert beginSheetModalForWindow:targetWindow completionHandler:^(NSModalResponse returnCode) {
+                if (returnCode == NSAlertSecondButtonReturn)
+                {
+                    [self.queue cancelItemsAtIndexes:workingSelectedIndexes];
+                    [self.queue removeItemsAtIndexes:workingSelectedIndexes];
+                }
+            }];
         }
 
         // remove the non working items immediately
         [self.queue removeItemsAtIndexes:mutableIndexes];
     }
-    [self.queue.items commit];
 }
 
-- (void)doEditQueueItem:(HBQueueItem *)item
+- (void)doEditQueueItem:(HBQueueJobItem *)item
 {
-    NSParameterAssert(item);
-    [self.queue.items beginTransaction];
-
-    if (item == self.queue.currentItem)
-    {
-        [self.queue cancelCurrentItemAndContinue];
-    }
-    else
-    {
-        item.state = HBQueueItemStateWorking;
-    }
+    [self.queue prepareItemForEditingAtIndex:[self.queue.items indexOfObject:item]];
 
     [self.delegate openJob:[item.job copy] completionHandler:^(BOOL result) {
-        [self.queue.items beginTransaction];
-        if (result)
+        NSInteger index = [self.queue.items indexOfObject:item];
+        if (index != NSNotFound)
         {
-            // Now that source is loaded and settings applied, delete the queue item from the queue
-            NSInteger index = [self.queue.items indexOfObject:item];
-            item.state = HBQueueItemStateReady;
-            [self.queue removeItemAtIndex:index];
+            [self.queue resetItemsAtIndexes:[NSIndexSet indexSetWithIndex:index]];
+            if (result)
+            {
+                // Now that source is loaded and settings applied, delete the queue item from the queue
+                [self.queue removeItemsAtIndexes:[NSIndexSet indexSetWithIndex:index]];
+            }
+            else
+            {
+                NSBeep();
+            }
         }
         else
         {
-            item.state = HBQueueItemStateFailed;
-            NSBeep();
+            item.state = HBQueueItemStateReady;
         }
-        [self.queue.items commit];
     }];
-
-    [self.queue.items commit];
 }
 
 /**
  * Send the selected queue item back to the main window for rescan and possible edit.
  */
-- (void)editQueueItem:(HBQueueItem *)item
+- (void)editQueueItem:(HBQueueJobItem *)item
 {
-    if ([self.queue.items beginTransaction] == HBDistributedArrayContentReload)
-    {
-        // Do not execture the action if the array changed.
-        [self.queue.items commit];
-        return;
-    }
-
     // if this is a currently encoding item, we need to be sure to alert the user,
     // to let them decide to cancel it first, then if they do, we can come back and
     // remove it
-    if (item == self.queue.currentItem)
+    if (item.state == HBQueueItemStateWorking)
     {
         NSString *alertTitle = [NSString stringWithFormat:NSLocalizedString(@"Stop This Encode and Edit It?", @"Queue Edit Alert -> stop and edit message")];
 
@@ -425,6 +380,10 @@
         [alert setInformativeText:NSLocalizedString(@"Your movie will be lost if you don't continue encoding.", @"Queue Edit Alert -> stop and edit informative text")];
         [alert addButtonWithTitle:NSLocalizedString(@"Keep Encoding", @"Queue Edit Alert -> stop and edit first button")];
         [alert addButtonWithTitle:NSLocalizedString(@"Stop Encoding and Edit", @"Queue Edit Alert -> stop and edit second button")];
+        if (@available(macOS 11, *))
+        {
+            alert.buttons.lastObject.hasDestructiveAction = true;
+        }
         [alert setAlertStyle:NSAlertStyleCritical];
 
         [alert beginSheetModalForWindow:docWindow completionHandler:^(NSModalResponse returnCode) {
@@ -434,12 +393,10 @@
             }
         }];
     }
-    else if (item.state != HBQueueItemStateWorking)
+    else if (item.state != HBQueueItemStateWorking && item.state != HBQueueItemStateRescanning)
     {
         [self doEditQueueItem:item];
     }
-
-    [self.queue.items commit];
 }
 
 - (void)resetQueueItemsAtIndexes:(NSIndexSet *)indexes
@@ -458,7 +415,7 @@ NSString * const HBQueueItemNotificationPathKey = @"HBQueueItemNotificationPathK
     if ([path isKindOfClass:[NSString class]] && path.length)
     {
         NSURL *fileURL = [NSURL fileURLWithPath:path];
-        [[NSWorkspace sharedWorkspace] activateFileViewerSelectingURLs:@[fileURL]];
+        [NSWorkspace.sharedWorkspace activateFileViewerSelectingURLs:@[fileURL]];
     }
 }
 
@@ -481,43 +438,48 @@ NSString * const HBQueueItemNotificationPathKey = @"HBQueueItemNotificationPathK
  *
  *  @param job the job of the file to send
  */
-- (void)sendToExternalApp:(HBQueueItem *)item
+- (void)sendToExternalApp:(HBQueueJobItem *)item
 {
     // This end of encode action is called as each encode rolls off of the queue
     if ([NSUserDefaults.standardUserDefaults boolForKey:HBSendToAppEnabled] == YES)
     {
+        NSURL *outputURL = item.outputURL;
+        NSString *completeOutputPath = item.completeOutputURL.path;
+
+        dispatch_async(_sendQueue, ^{
 #ifdef __SANDBOX_ENABLED__
-        BOOL accessingSecurityScopedResource = [item.outputURL startAccessingSecurityScopedResource];
+            BOOL accessingSecurityScopedResource = [outputURL startAccessingSecurityScopedResource];
 #endif
 
-        NSWorkspace *workspace = NSWorkspace.sharedWorkspace;
-        NSString *app = [workspace fullPathForApplication:[NSUserDefaults.standardUserDefaults objectForKey:HBSendToApp]];
+            NSWorkspace *workspace = NSWorkspace.sharedWorkspace;
+            NSString *app = [workspace fullPathForApplication:[NSUserDefaults.standardUserDefaults objectForKey:HBSendToApp]];
 
-        if (app)
-        {
-            if (![workspace openFile:item.completeOutputURL.path withApplication:app])
+            if (app)
             {
-                [HBUtilities writeToActivityLog:"Failed to send file to: %s", app];
+                if (![workspace openFile:completeOutputPath withApplication:app])
+                {
+                    [HBUtilities writeToActivityLog:"Failed to send file to: %s", app];
+                }
+            }
+            else
+            {
+                [HBUtilities writeToActivityLog:"Send file to: app not found"];
             }
-        }
-        else
-        {
-            [HBUtilities writeToActivityLog:"Send file to: app not found"];
-        }
 
 #ifdef __SANDBOX_ENABLED__
-        if (accessingSecurityScopedResource)
-        {
-            [item.outputURL stopAccessingSecurityScopedResource];
-        }
+            if (accessingSecurityScopedResource)
+            {
+                [outputURL stopAccessingSecurityScopedResource];
+            }
 #endif
+        });
     }
 }
 
 /**
  *  Runs the alert for a single job
  */
-- (void)itemCompletedAlerts:(HBQueueItem *)item
+- (void)itemCompletedAlerts:(HBQueueJobItem *)item
 {
     NSUserDefaults *ud = NSUserDefaults.standardUserDefaults;
 
@@ -697,14 +659,22 @@ NSString * const HBQueueItemNotificationPathKey = @"HBQueueItemNotificationPathK
     [alert setInformativeText:NSLocalizedString(@"Select Continue Encoding to dismiss this dialog without making changes.", @"Queue Alert -> cancel rip informative text")];
     [alert addButtonWithTitle:NSLocalizedString(@"Continue Encoding", @"Queue Alert -> cancel rip first button")];
     [alert addButtonWithTitle:NSLocalizedString(@"Skip Current Job", @"Queue Alert -> cancel rip second button")];
+    if (@available(macOS 11, *))
+    {
+        alert.buttons.lastObject.hasDestructiveAction = true;
+    }
     [alert addButtonWithTitle:NSLocalizedString(@"Stop After Current Job", @"Queue Alert -> cancel rip third button")];
     [alert addButtonWithTitle:NSLocalizedString(@"Stop All", @"Queue Alert -> cancel rip fourth button")];
+    if (@available(macOS 11, *))
+    {
+        alert.buttons.lastObject.hasDestructiveAction = true;
+    }
     [alert setAlertStyle:NSAlertStyleCritical];
 
     [alert beginSheetModalForWindow:window completionHandler:^(NSModalResponse returnCode) {
         if (returnCode == NSAlertSecondButtonReturn)
         {
-            [self.queue cancelCurrentItemAndContinue];
+            [self.queue cancelCurrentAndContinue];
         }
         else if (returnCode == NSAlertThirdButtonReturn)
         {
@@ -712,7 +682,7 @@ NSString * const HBQueueItemNotificationPathKey = @"HBQueueItemNotificationPathK
         }
         else if (returnCode == NSAlertThirdButtonReturn + 1)
         {
-            [self.queue cancelCurrentItemAndStop];
+            [self.queue cancelCurrentAndStop];
         }
     }];
 }
@@ -751,7 +721,7 @@ NSString * const HBQueueItemNotificationPathKey = @"HBQueueItemNotificationPathK
     }
     else
     {
-        NSArray<HBQueueItem *> *items = [self.queue.items objectsAtIndexes:indexes];
+        NSArray<id<HBQueueItem>> *items = [self.queue.items objectsAtIndexes:indexes];
         self.infoViewController.item = items.firstObject;
         [self switchToViewController:self.infoViewController];
     }
@@ -776,9 +746,12 @@ NSString * const HBQueueItemNotificationPathKey = @"HBQueueItemNotificationPathK
     }
 }
 
-- (void)tableViewEditItem:(HBQueueItem *)item
+- (void)tableViewEditItem:(id<HBQueueItem>)item
 {
-    [self editQueueItem:item];
+    if ([item isKindOfClass:[HBQueueJobItem class]])
+    {
+        [self editQueueItem:item];
+    }
 }
 
 - (void)tableViewRemoveItemsAtIndexes:(nonnull NSIndexSet *)indexes
@@ -790,15 +763,21 @@ NSString * const HBQueueItemNotificationPathKey = @"HBQueueItemNotificationPathK
     [self resetQueueItemsAtIndexes:indexes];
 }
 
-- (void)detailsViewEditItem:(nonnull HBQueueItem *)item
+- (void)detailsViewEditItem:(nonnull id<HBQueueItem>)item
 {
-    [self editQueueItem:item];
+    if ([item isKindOfClass:[HBQueueJobItem class]])
+    {
+        [self editQueueItem:item];
+    }
 }
 
-- (void)detailsViewResetItem:(nonnull HBQueueItem *)item
+- (void)detailsViewResetItem:(nonnull id<HBQueueItem>)item
 {
-    NSUInteger index = [self.queue.items indexOfObject:item];
-    [self resetQueueItemsAtIndexes:[NSIndexSet indexSetWithIndex:index]];
+    if ([item isKindOfClass:[HBQueueJobItem class]])
+    {
+        NSUInteger index = [self.queue.items indexOfObject:item];
+        [self resetQueueItemsAtIndexes:[NSIndexSet indexSetWithIndex:index]];
+    }
 }
 
 - (IBAction)resetAll:(id)sender
