@@ -18,29 +18,33 @@
 
 @interface HBMetadata ()
 
-@property (nonatomic, readonly) hb_metadata_t *hb_metadata;
-@property (nonatomic, copy) NSString *releaseDate;
+@property (nonatomic, readonly, nullable) hb_metadata_t *metadata;
+@property (nonatomic, copy, nullable) NSString *releaseDate;
 
 @end
 
 @implementation HBMetadata
-- (instancetype)initWithMetadata:(hb_metadata_t *)data
+- (instancetype)initWithMetadata:(hb_metadata_t *)metadata
 {
     self = [super init];
     if (self)
     {
-        _hb_metadata = data;
+        _metadata = metadata;
     }
     return self;
 }
 
 - (NSString *)releaseDate
 {
-    if (self.hb_metadata->release_date == nil)
+    if (_metadata && _metadata->dict)
     {
-        return nil;
+        const char *releaseDate = hb_dict_get_string(_metadata->dict, "ReleaseDate");
+        if (releaseDate)
+        {
+            return @(releaseDate);
+        }
     }
-    return @(self.hb_metadata->release_date);
+    return nil;
 }
 
 @end
@@ -118,6 +122,9 @@ fail:
 
 @property (nonatomic, readonly, nullable) NSData *bookmark;
 
+@property (nonatomic, readwrite) NSInteger accessCount;
+@property (nonatomic, readwrite) HBSecurityAccessToken *fileURLToken;
+
 @end
 
 @implementation HBTitleSubtitlesTrack
@@ -148,6 +155,47 @@ fail:
     return self;
 }
 
+- (void)refreshSecurityScopedResources
+{
+    if (_bookmark)
+    {
+        NSURL *resolvedURL = [HBUtilities URLFromBookmark:_bookmark];
+        if (resolvedURL)
+        {
+            _fileURL = resolvedURL;
+        }
+    }
+}
+
+- (BOOL)startAccessingSecurityScopedResource
+{
+#ifdef __SANDBOX_ENABLED__
+    if (self.accessCount == 0)
+    {
+        if (_fileURL)
+        {
+            self.fileURLToken = [HBSecurityAccessToken tokenWithObject:_fileURL];
+        }
+    }
+    self.accessCount += 1;
+    return YES;
+#else
+    return NO;
+#endif
+}
+
+- (void)stopAccessingSecurityScopedResource
+{
+#ifdef __SANDBOX_ENABLED__
+    self.accessCount -= 1;
+    NSAssert(self.accessCount >= 0, @"[HBSubtitles stopAccessingSecurityScopedResource:] unbalanced call");
+    if (self.accessCount == 0)
+    {
+        self.fileURLToken = nil;
+    }
+#endif
+}
+
 + (BOOL)supportsSecureCoding { return YES ;}
 
 - (void)encodeWithCoder:(nonnull NSCoder *)coder
@@ -185,12 +233,7 @@ fail:
 
         if (_bookmark)
         {
-            _fileURL =  [HBUtilities URLFromBookmark:_bookmark];
-
-            if (!_fileURL)
-            {
-                decodeObjectOrFail(_fileURL, NSURL);
-            }
+            decodeObjectOrFail(_fileURL, NSURL);
         }
 #else
         decodeObject(_fileURL, NSURL);
@@ -458,7 +501,8 @@ fail:
                 {
                     title = @(chapter->title);
                 }
-                else
+
+                if (title == NULL)
                 {
                     title = [NSString stringWithFormat:HBKitLocalizedString(@"Chapter %d", "Title -> chapter name"), i + 1];
                 }
@@ -477,11 +521,11 @@ fail:
     return _chapters;
 }
 
-- (NSDictionary *)jobSettingsWithPreset:(HBPreset *)preset
+- (nullable NSDictionary *)jobSettingsWithPreset:(HBPreset *)preset
 {
     NSDictionary *result = nil;
 
-    hb_dict_t *hb_preset = [preset content].hb_value;
+    hb_dict_t *hb_preset = preset.content.hb_value;
     hb_dict_t *job = hb_preset_job_init(self.hb_handle, self.hb_title->index, hb_preset);
 
     if (job)
