@@ -116,8 +116,7 @@
 
 - (BOOL)twoPassSupported
 {
-    return !((self.encoder & HB_VCODEC_FFMPEG_VT_H264) ||
-            (self.encoder & HB_VCODEC_FFMPEG_VT_H265));
+    return hb_video_twopass_is_supported(self.encoder);
 }
 
 + (NSSet<NSString *> *)keyPathsForValuesAffectingConstantQualityLabel
@@ -137,7 +136,7 @@
 
 - (BOOL)isConstantQualitySupported
 {
-    return (self.qualityMaxValue == 0 && self.qualityMinValue == 0) == NO;
+    return hb_video_quality_is_supported(self.encoder);
 }
 
 + (NSSet<NSString *> *)keyPathsForValuesAffectingUnparseOptions
@@ -147,7 +146,7 @@
 }
 
 /**
- *  This is called everytime a x264 widget in the video tab is changed to
+ *  This is called every time a x264 widget in the video tab is changed to
  *  display the expanded options in a text field via outlet fDisplayX264PresetsUnparseTextField
  */
 - (NSString *)unparseOptions
