@@ -149,7 +149,7 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 {
     if (frameRate != _frameRate)
     {
-        [(HBVideo *)[self.undo prepareWithInvocationTarget:self] setFrameRate:_frameRate];
+        [[self.undo prepareWithInvocationTarget:self] setFrameRate:_frameRate];
     }
     _frameRate = frameRate;
     [self postChangedNotification];
@@ -286,21 +286,12 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 
 - (void)validateQualityType
 {
-    if (self.qualityType != 0)
+    if (self.qualityType != 0 && !hb_video_quality_is_supported(self.encoder))
     {
-        int direction;
-        float minValue, maxValue, granularity;
-        hb_video_quality_get_limits(self.encoder,
-                                    &minValue, &maxValue, &granularity, &direction);
-
-        if (minValue == 0 && maxValue == 0)
-        {
-            self.qualityType = 0;
-        }
+        self.qualityType = 0;
     }
 
-    if ((self.encoder & HB_VCODEC_FFMPEG_VT_H264) ||
-        (self.encoder & HB_VCODEC_FFMPEG_VT_H265))
+    if (!hb_video_twopass_is_supported(self.encoder))
     {
         self.twoPass = NO;
     }
@@ -309,8 +300,13 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
 - (void)validatePresetsSettings
 {
     NSArray *presets = self.presets;
-    if (presets.count && ![presets containsObject:self.preset]) {
-        if (presets.count > self.mediumPresetIndex)
+    if (presets.count && ![presets containsObject:self.preset])
+    {
+        if (self.encoder & HB_VCODEC_VT_MASK)
+        {
+            self.preset = self.presets.lastObject;
+        }
+        else if (presets.count > self.mediumPresetIndex)
         {
             self.preset = presets[self.mediumPresetIndex];
         }
@@ -364,7 +360,7 @@ NSString * const HBVideoChangedNotification = @"HBVideoChangedNotification";
     return [NSSet setWithObjects:@"encoder", nil];
 }
 
-- (NSArray *)presets
+- (NSArray<NSString *> *)presets
 {
     NSMutableArray *temp = [NSMutableArray array];
 
@@ -651,7 +647,7 @@ fail:
      * for the fVidQualityMatrix. It should also be noted that any preset that used the deprecated Target Size
      * setting of 0 would set us to 0 or ABR since ABR is now tagged 0. Fortunately this does not affect any built-in
      * presets since they all use Constant Quality or Average Bitrate.*/
-    if (qualityType == -1)
+    if (qualityType == -1 || hb_video_quality_is_supported(self.encoder) == 0)
     {
         qualityType = 0;
     }
