@@ -1,5 +1,5 @@
 ﻿// --------------------------------------------------------------------------------------------------------------------
-// <copyright file="HandBrakeEncoderHelpers.cs" company="HandBrake Project (http://handbrake.fr)">
+// <copyright file="HandBrakeEncoderHelpers.cs" company="HandBrake Project (https://handbrake.fr)">
 //   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
 // </copyright>
 // <summary>
@@ -14,19 +14,13 @@ namespace HandBrake.Interop.Interop
     using System.Linq;
 
     using HandBrake.Interop.Interop.HbLib;
-    using HandBrake.Interop.Interop.HbLib.Wrappers.Interfaces;
     using HandBrake.Interop.Interop.Helpers;
-    using HandBrake.Interop.Interop.Model;
-    using HandBrake.Interop.Interop.Model.Encoding;
-    using HandBrake.Interop.Interop.Providers;
-    using HandBrake.Interop.Interop.Providers.Interfaces;
+    using HandBrake.Interop.Interop.Interfaces.Model;
+    using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
+    using HandBrake.Interop.Utilities;
 
-    /// <summary>
-    /// The encoders.
-    /// </summary>
     public static class HandBrakeEncoderHelpers
     {
-        private static IHbFunctions hbFunctions;
         private static List<HBAudioEncoder> audioEncoders;
         private static List<HBVideoEncoder> videoEncoders;
         private static List<HBRate> videoFramerates;
@@ -40,9 +34,6 @@ namespace HandBrake.Interop.Interop
         /// </summary>
         static HandBrakeEncoderHelpers()
         {
-            IHbFunctionsProvider hbFunctionsProvider = new HbFunctionsProvider();
-            hbFunctions = hbFunctionsProvider.GetHbFunctionsWrapper();
-
             if (!HandBrakeUtils.IsInitialised())
             {
                 throw new Exception("Please Initialise with HandBrakeUtils.EnsureGlobalInit before using!");
@@ -58,7 +49,7 @@ namespace HandBrake.Interop.Interop
             {
                 if (audioEncoders == null)
                 {
-                    audioEncoders = InteropUtilities.ToListFromIterator<hb_encoder_s, HBAudioEncoder>(hbFunctions.hb_audio_encoder_get_next, HandBrakeUnitConversionHelpers.NativeToAudioEncoder);
+                    audioEncoders = InteropUtilities.ToListFromIterator<hb_encoder_s, HBAudioEncoder>(HBFunctions.hb_audio_encoder_get_next, HandBrakeUnitConversionHelpers.NativeToAudioEncoder);
                 }
 
                 return audioEncoders;
@@ -74,7 +65,7 @@ namespace HandBrake.Interop.Interop
             {
                 if (videoEncoders == null)
                 {
-                    videoEncoders = InteropUtilities.ToListFromIterator<hb_encoder_s, HBVideoEncoder>(hbFunctions.hb_video_encoder_get_next, HandBrakeUnitConversionHelpers.NativeToVideoEncoder);
+                    videoEncoders = InteropUtilities.ToListFromIterator<hb_encoder_s, HBVideoEncoder>(HBFunctions.hb_video_encoder_get_next, HandBrakeUnitConversionHelpers.NativeToVideoEncoder);
                 }
 
                 return videoEncoders;
@@ -90,7 +81,7 @@ namespace HandBrake.Interop.Interop
             {
                 if (videoFramerates == null)
                 {
-                    videoFramerates = InteropUtilities.ToListFromIterator<hb_rate_s, HBRate>(hbFunctions.hb_video_framerate_get_next, HandBrakeUnitConversionHelpers.NativeToRate);
+                    videoFramerates = InteropUtilities.ToListFromIterator<hb_rate_s, HBRate>(HBFunctions.hb_video_framerate_get_next, HandBrakeUnitConversionHelpers.NativeToRate);
                 }
 
                 return videoFramerates;
@@ -106,7 +97,7 @@ namespace HandBrake.Interop.Interop
             {
                 if (mixdowns == null)
                 {
-                    mixdowns = InteropUtilities.ToListFromIterator<hb_mixdown_s, HBMixdown>(hbFunctions.hb_mixdown_get_next, HandBrakeUnitConversionHelpers.NativeToMixdown);
+                    mixdowns = InteropUtilities.ToListFromIterator<hb_mixdown_s, HBMixdown>(HBFunctions.hb_mixdown_get_next, HandBrakeUnitConversionHelpers.NativeToMixdown);
                 }
 
                 return mixdowns;
@@ -122,7 +113,7 @@ namespace HandBrake.Interop.Interop
             {
                 if (audioBitrates == null)
                 {
-                    audioBitrates = InteropUtilities.ToListFromIterator<hb_rate_s, int>(hbFunctions.hb_audio_bitrate_get_next, b => b.rate);
+                    audioBitrates = InteropUtilities.ToListFromIterator<hb_rate_s, int>(HBFunctions.hb_audio_bitrate_get_next, b => b.rate);
                 }
 
                 return audioBitrates;
@@ -138,7 +129,7 @@ namespace HandBrake.Interop.Interop
             {
                 if (audioSampleRates == null)
                 {
-                    audioSampleRates = InteropUtilities.ToListFromIterator<hb_rate_s, HBRate>(hbFunctions.hb_audio_samplerate_get_next, HandBrakeUnitConversionHelpers.NativeToRate);
+                    audioSampleRates = InteropUtilities.ToListFromIterator<hb_rate_s, HBRate>(HBFunctions.hb_audio_samplerate_get_next, HandBrakeUnitConversionHelpers.NativeToRate);
                 }
 
                 return audioSampleRates;
@@ -154,7 +145,7 @@ namespace HandBrake.Interop.Interop
             {
                 if (containers == null)
                 {
-                    containers = InteropUtilities.ToListFromIterator<hb_container_s, HBContainer>(hbFunctions.hb_container_get_next, HandBrakeUnitConversionHelpers.NativeToContainer);
+                    containers = InteropUtilities.ToListFromIterator<hb_container_s, HBContainer>(HBFunctions.hb_container_get_next, HandBrakeUnitConversionHelpers.NativeToContainer);
                 }
 
                 return containers;
@@ -168,7 +159,7 @@ namespace HandBrake.Interop.Interop
         {
             get
             {
-                return hbFunctions.hb_subtitle_can_burn((int)hb_subtitle_s_subsource.IMPORTSRT) > 0;
+                return HBFunctions.hb_subtitle_can_burn((int)hb_subtitle_s_subsource.IMPORTSRT) > 0;
             }
         }
 
@@ -179,7 +170,7 @@ namespace HandBrake.Interop.Interop
         {
             get
             {
-                return hbFunctions.hb_subtitle_can_burn((int)hb_subtitle_s_subsource.IMPORTSSA) > 0;
+                return HBFunctions.hb_subtitle_can_burn((int)hb_subtitle_s_subsource.IMPORTSSA) > 0;
             }
         }
 
@@ -270,6 +261,20 @@ namespace HandBrake.Interop.Interop
             return Containers.SingleOrDefault(c => c.ShortName == shortName);
         }
 
+        /// <summary>
+        /// Returns true if the given video encoder supports two-pass mode.
+        /// </summary>
+        /// <param name="encoderId">
+        /// The encoder ID.
+        /// </param>
+        /// <returns>
+        /// True if the given video encoder supports two-pass mode.
+        /// </returns>
+        public static bool VideoEncoderSupportsTwoPass(int encoderId)
+		{
+            return HBFunctions.hb_video_twopass_is_supported((uint)encoderId) > 0;
+		}
+
         /// <summary>
         /// Returns true if the subtitle source type can be set to forced only.
         /// </summary>
@@ -281,7 +286,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static bool SubtitleCanSetForcedOnly(int source)
         {
-            return hbFunctions.hb_subtitle_can_force(source) > 0;
+            return HBFunctions.hb_subtitle_can_force(source) > 0;
         }
 
         /// <summary>
@@ -295,7 +300,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static bool SubtitleCanBurn(int source)
         {
-            return hbFunctions.hb_subtitle_can_burn(source) > 0;
+            return HBFunctions.hb_subtitle_can_burn(source) > 0;
         }
 
         /// <summary>
@@ -312,7 +317,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static bool SubtitleCanPassthrough(int subtitleSourceType, int muxer)
         {
-            return hbFunctions.hb_subtitle_can_pass(subtitleSourceType, muxer) > 0;
+            return HBFunctions.hb_subtitle_can_pass(subtitleSourceType, muxer) > 0;
         }
 
         /// <summary>
@@ -360,7 +365,7 @@ namespace HandBrake.Interop.Interop
         /// The encoder to examine.
         /// </param>
         /// <returns>
-        /// True if the given encoder is comatible with the given audio track.
+        /// True if the given encoder is compatible with the given audio track.
         /// </returns>
         /// <remarks>
         /// Only works with passthrough encoders.
@@ -384,7 +389,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static bool MixdownHasRemixSupport(HBMixdown mixdown, ulong layout)
         {
-            return hbFunctions.hb_mixdown_has_remix_support(mixdown.Id, layout) > 0;
+            return HBFunctions.hb_mixdown_has_remix_support(mixdown.Id, layout) > 0;
         }
 
         /// <summary>
@@ -401,7 +406,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static bool MixdownHasCodecSupport(HBMixdown mixdown, HBAudioEncoder encoder)
         {
-            return hbFunctions.hb_mixdown_has_codec_support(mixdown.Id, (uint)encoder.Id) > 0;
+            return HBFunctions.hb_mixdown_has_codec_support(mixdown.Id, (uint)encoder.Id) > 0;
         }
 
         /// <summary>
@@ -417,12 +422,15 @@ namespace HandBrake.Interop.Interop
         /// <returns>True if available.</returns>
         public static bool MixdownIsSupported(HBMixdown mixdown, HBAudioEncoder encoder, long channelLayout)
         {
-            return hbFunctions.hb_mixdown_is_supported(mixdown.Id, (uint)encoder.Id, (uint)channelLayout) > 0;
+            return HBFunctions.hb_mixdown_is_supported(mixdown.Id, (uint)encoder.Id, (uint)channelLayout) > 0;
         }
 
         /// <summary>
         /// Determines if DRC can be applied to the given track with the given encoder.
         /// </summary>
+        /// <param name="handle">
+        /// The handle.
+        /// </param>
         /// <param name="trackNumber">
         /// The track Number.
         /// </param>
@@ -437,7 +445,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static bool CanApplyDrc(IntPtr handle, int trackNumber, HBAudioEncoder encoder, int title)
         {
-            return hbFunctions.hb_audio_can_apply_drc2(handle, title, trackNumber, encoder.Id) > 0; 
+            return HBFunctions.hb_audio_can_apply_drc2(handle, title, trackNumber, encoder.Id) > 0; 
         }
 
         /// <summary>
@@ -476,7 +484,7 @@ namespace HandBrake.Interop.Interop
                 return null;
             }
 
-            int sanitizedMixdown = hbFunctions.hb_mixdown_get_best((uint)encoder.Id, layout, mixdown.Id);
+            int sanitizedMixdown = HBFunctions.hb_mixdown_get_best((uint)encoder.Id, layout, mixdown.Id);
             if (sanitizedMixdown != -1)
             {
                 return Mixdowns.Single(m => m.Id == sanitizedMixdown);
@@ -499,7 +507,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static HBMixdown GetDefaultMixdown(HBAudioEncoder encoder, ulong layout)
         {
-            int defaultMixdown = hbFunctions.hb_mixdown_get_default((uint)encoder.Id, layout);
+            int defaultMixdown = HBFunctions.hb_mixdown_get_default((uint)encoder.Id, layout);
             return Mixdowns.Single(m => m.Id == defaultMixdown);
         }
 
@@ -511,7 +519,7 @@ namespace HandBrake.Interop.Interop
         /// <returns>The sanitized sample rate.</returns>
         public static int SanitizeSampleRate(HBAudioEncoder encoder, int sampleRate)
         {
-            return hbFunctions.hb_audio_samplerate_find_closest(sampleRate, (uint)encoder.Id);
+            return HBFunctions.hb_audio_samplerate_find_closest(sampleRate, (uint)encoder.Id);
         }
 
         /// <summary>
@@ -534,7 +542,7 @@ namespace HandBrake.Interop.Interop
             int low = 0;
             int high = 0;
 
-            hbFunctions.hb_audio_bitrate_get_limits((uint)encoder.Id, sampleRate, mixdown.Id, ref low, ref high);
+            HBFunctions.hb_audio_bitrate_get_limits((uint)encoder.Id, sampleRate, mixdown.Id, ref low, ref high);
 
             return new BitrateLimits(low, high);
         }
@@ -555,7 +563,7 @@ namespace HandBrake.Interop.Interop
             float granularity = 0;
             int direction = 0;
 
-            hbFunctions.hb_video_quality_get_limits((uint)encoder.Id, ref low, ref high, ref granularity, ref direction);
+            HBFunctions.hb_video_quality_get_limits((uint)encoder.Id, ref low, ref high, ref granularity, ref direction);
 
             return new VideoQualityLimits(low, high, granularity, direction == 0);
         }
@@ -580,7 +588,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static int SanitizeAudioBitrate(int audioBitrate, HBAudioEncoder encoder, int sampleRate, HBMixdown mixdown)
         {
-            return hbFunctions.hb_audio_bitrate_get_best((uint)encoder.Id, audioBitrate, sampleRate, mixdown.Id);
+            return HBFunctions.hb_audio_bitrate_get_best((uint)encoder.Id, audioBitrate, sampleRate, mixdown.Id);
         }
 
         /// <summary>
@@ -600,7 +608,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static int GetDefaultBitrate(HBAudioEncoder encoder, int sampleRate, HBMixdown mixdown)
         {
-            return hbFunctions.hb_audio_bitrate_get_default((uint)encoder.Id, sampleRate, mixdown.Id);
+            return HBFunctions.hb_audio_bitrate_get_default((uint)encoder.Id, sampleRate, mixdown.Id);
         }
 
         /// <summary>
@@ -616,7 +624,7 @@ namespace HandBrake.Interop.Interop
         {
             float low = 0, high = 0, granularity = 0;
             int direction = 0;
-            hbFunctions.hb_audio_quality_get_limits((uint)encoderId, ref low, ref high, ref granularity, ref direction);
+            HBFunctions.hb_audio_quality_get_limits((uint)encoderId, ref low, ref high, ref granularity, ref direction);
 
             return new RangeLimits(direction == 0, granularity, high, low);
         }
@@ -634,7 +642,7 @@ namespace HandBrake.Interop.Interop
         {
             float low = 0, high = 0, granularity = 0;
             int direction = 0;
-            hbFunctions.hb_audio_compression_get_limits((uint)encoderId, ref low, ref high, ref granularity, ref direction);
+            HBFunctions.hb_audio_compression_get_limits((uint)encoderId, ref low, ref high, ref granularity, ref direction);
 
             return new RangeLimits(direction == 0, granularity, high, low);
         }
@@ -650,7 +658,7 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static double GetDefaultQuality(HBAudioEncoder encoder)
         {
-           return hbFunctions.hb_audio_quality_get_default((uint)encoder.Id);
+           return HBFunctions.hb_audio_quality_get_default((uint)encoder.Id);
         }
 
         /// <summary>
@@ -664,13 +672,18 @@ namespace HandBrake.Interop.Interop
         /// </returns>
         public static double GetDefaultAudioCompression(HBAudioEncoder encoder)
         {
-            return hbFunctions.hb_audio_compression_get_default((uint)encoder.Id);
+            return HBFunctions.hb_audio_compression_get_default((uint)encoder.Id);
         }
 
-        public static uint BuildCopyMask(bool audioAllowMP3Pass, bool audioAllowAACPass, bool audioAllowAC3Pass, bool audioAllowDTSPass, bool audioAllowDTSHDPass, bool audioAllowEac3Pass, bool audioAllowFlacPass, bool audioAllowTruehdPass)
+        public static uint BuildCopyMask(bool audioAllowMP2Pass, bool audioAllowMP3Pass, bool audioAllowAACPass, bool audioAllowAC3Pass, bool audioAllowDTSPass, bool audioAllowDTSHDPass, bool audioAllowEac3Pass, bool audioAllowFlacPass, bool audioAllowTruehdPass)
         {
             uint mask = 0;
 
+            if (audioAllowMP2Pass)
+            {
+                mask |= NativeConstants.HB_ACODEC_MP2_PASS;
+            }
+
             if (audioAllowMP3Pass)
             {
                 mask |= NativeConstants.HB_ACODEC_MP3_PASS;
@@ -713,5 +726,19 @@ namespace HandBrake.Interop.Interop
 
             return mask;
         }
+
+        public static List<int> GetQsvAdaptorList()
+        {
+            if (HandBrakeHardwareEncoderHelper.IsQsvAvailable)
+            {
+                IntPtr gpuListPtr = HBFunctions.hb_qsv_adapters_list();
+
+                List<int> gpuList = InteropUtilities.ToListFromHandBrakeList<int>(gpuListPtr);
+
+                return gpuList;
+            }
+
+            return new List<int>();
+        }
     }
 }
