@@ -13,14 +13,14 @@ namespace HandBrakeWPF.Converters
     using System.Collections.Generic;
     using System.Globalization;
     using System.Windows.Data;
-    using HandBrake.Interop.Interop.Model.Encoding;
-    using HandBrake.Interop.Model;
 
+    using HandBrakeWPF.Model.Filters;
     using HandBrakeWPF.Model.Options;
+    using HandBrakeWPF.Model.Video;
     using HandBrakeWPF.Services.Queue.Model;
     using HandBrakeWPF.Utilities;
-    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
-    using PresetPictureSettingsMode = HandBrakeWPF.Model.Picture.PresetPictureSettingsMode;
+    using OutputFormat = Services.Encode.Model.Models.OutputFormat;
+    using VideoEncoder = Model.Video.VideoEncoder;
 
     /// <summary>
     /// Enum Combo Converter
@@ -40,11 +40,6 @@ namespace HandBrakeWPF.Converters
                 return EnumHelper<VideoEncoder>.GetEnumDisplayValues(typeof(VideoEncoder));
             }
 
-            if (value is IEnumerable<PresetPictureSettingsMode>)
-            {
-                return EnumHelper<PresetPictureSettingsMode>.GetEnumDisplayValues(typeof(PresetPictureSettingsMode));
-            }
-
             if (value is IEnumerable<Detelecine>)
             {
                 return EnumHelper<Detelecine>.GetEnumDisplayValues(typeof(Detelecine));
@@ -101,11 +96,6 @@ namespace HandBrakeWPF.Converters
                 return EnumHelper<VideoEncoder>.GetDisplay((VideoEncoder)value);
             }
 
-            if (targetType == typeof(PresetPictureSettingsMode) || value.GetType() == typeof(PresetPictureSettingsMode))
-            {
-                return EnumHelper<PresetPictureSettingsMode>.GetDisplay((PresetPictureSettingsMode)value);
-            }
-
             if (targetType == typeof(Detelecine) || value.GetType() == typeof(Detelecine))
             {
                 return EnumHelper<Detelecine>.GetDisplay((Detelecine)value);
@@ -176,11 +166,6 @@ namespace HandBrakeWPF.Converters
                 return EnumHelper<VideoEncoder>.GetValue(value.ToString());
             }
 
-            if (targetType == typeof(PresetPictureSettingsMode) || value.GetType() == typeof(PresetPictureSettingsMode))
-            {
-                return EnumHelper<PresetPictureSettingsMode>.GetValue(value.ToString());
-            }
-
             if (targetType == typeof(Denoise) || value.GetType() == typeof(Denoise))
             {
                 return EnumHelper<Denoise>.GetValue(value.ToString());
