@@ -14,9 +14,8 @@ namespace HandBrakeWPF.Converters.Video
     using System.Linq;
     using System.Windows.Data;
 
-    using HandBrake.Interop.Interop.Model.Encoding;
-
     using EncodeTask = Services.Encode.Model.EncodeTask;
+    using VideoEncoder = HandBrakeWPF.Model.Video.VideoEncoder;
     using VideoLevel = Services.Encode.Model.Models.Video.VideoLevel;
     using VideoPreset = Services.Encode.Model.Models.Video.VideoPreset;
     using VideoProfile = Services.Encode.Model.Models.Video.VideoProfile;
@@ -49,7 +48,8 @@ namespace HandBrakeWPF.Converters.Video
             {
                 VideoTune tune = task.VideoTunes.FirstOrDefault();
 
-                return string.Format("Preset: {0}{5}Tune: {1}{5}Profile: {2}{5}Level: {3}{5}Extra Arguments: {4}{5}",
+                return string.Format(
+                    "Preset: {0}, Tune: {1}{5}Profile: {2}, Level: {3}{5}Extra Arguments: {4}{5}",
                     task.VideoPreset != null ? task.VideoPreset.ShortName : VideoPreset.None.DisplayName,
                     tune != null ? tune.ShortName : VideoTune.None.DisplayName,
                     task.VideoProfile != null ? task.VideoProfile.ShortName : VideoProfile.Auto.DisplayName,
