@@ -12,21 +12,18 @@ namespace HandBrakeWPF.Helpers
     using System;
     using System.IO;
     using System.Linq;
-    using System.Reflection;
 
     using Caliburn.Micro;
 
-    using HandBrake.Interop.Interop.Model.Encoding;
-
-    using HandBrakeWPF.Converters;
     using HandBrakeWPF.Extensions;
     using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Services.Presets.Model;
 
-    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
-    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
+    using EncodeTask = Services.Encode.Model.EncodeTask;
+    using OutputFormat = Services.Encode.Model.Models.OutputFormat;
+    using VideoEncodeRateType = Model.Video.VideoEncodeRateType;
 
     /// <summary>
     /// The Destination AutoName Helper
@@ -37,7 +34,7 @@ namespace HandBrakeWPF.Helpers
         /// Function which generates the filename and path automatically based on 
         /// the Source Name, DVD title and DVD Chapters
         /// </summary>
-        public static string AutoName(EncodeTask task, string sourceOrLabelName, Preset presetName)
+        public static string AutoName(EncodeTask task, string titleName, string sourceDisplayName, Preset presetName)
         {
             IUserSettingService userSettingService = IoC.Get<IUserSettingService>();
             if (task.Destination == null)
@@ -45,29 +42,13 @@ namespace HandBrakeWPF.Helpers
                 task.Destination = string.Empty;
             }
 
+            string sourceOrLabelName = !string.IsNullOrEmpty(titleName) ? titleName : sourceDisplayName;
+
             if (task.Title != 0)
             {
-                // Get the Source Name and remove any invalid characters
+                // Get the Source Name and remove any invalid characters and clean it per users options.
                 string sourceName = Path.GetInvalidFileNameChars().Aggregate(sourceOrLabelName, (current, character) => current.Replace(character.ToString(), string.Empty));
-
-                // Remove Underscores
-                if (userSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNameRemoveUnderscore))
-                {
-                    sourceName = sourceName.Replace("_", " ");
-                }
-
-                if (userSettingService.GetUserSetting<bool>(UserSettingConstants.RemovePunctuation))
-                {
-                    sourceName = sourceName.Replace("-", string.Empty);
-                    sourceName = sourceName.Replace(",", string.Empty);
-                    sourceName = sourceName.Replace(".", string.Empty); 
-                }
-                  
-                // Switch to "Title Case"
-                if (userSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNameTitleCase))
-                {
-                    sourceName = sourceName.ToTitleCase();
-                }
+                sourceName = CleanupSourceName(sourceName, userSettingService);
 
                 // Get the Selected Title Number
                 string dvdTitle = task.Title.ToString();
@@ -81,32 +62,8 @@ namespace HandBrakeWPF.Helpers
                     combinedChapterTag = chapterStart + "-" + chapterFinish;
                 }
 
-                // Local method to check if we have a creation time in the meta data. If not, fall back to source file creation time.
-                DateTime obtainCreateDateObject()
-                {
-                    var rd = task.MetaData.ReleaseDate;
-                    if (DateTime.TryParse(rd, out var d))
-                    {
-                        return d;
-                    }
-
-                    try
-                    {
-                        return File.GetCreationTime(task.Source);
-                    }
-                    catch (Exception e)
-                    {
-                        if (e is UnauthorizedAccessException || e is PathTooLongException || e is NotSupportedException)
-                        {
-                            // Suspect the most likely concerns trying to grab the creation date in which we would want to swallow exception.
-                            return default(DateTime);
-                        }
-
-                        throw e;                            
-                    }
-                }
-
-                var creationDateTime = obtainCreateDateObject();
+                // Creation Date / Time
+                var creationDateTime = ObtainCreateDateObject(task);
                 string createDate = creationDateTime.Date.ToShortDateString().Replace('/', '-');
                 string createTime = creationDateTime.ToString("HH-mm"); 
 
@@ -139,10 +96,36 @@ namespace HandBrakeWPF.Helpers
                 return false;
             }
 
-            // If there is an auto name path, use it...
-            return userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Trim().StartsWith(Constants.SourcePath) ||
-                (userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Contains(Constants.SourceFolderName) ||
-                 Directory.Exists(userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Trim()));
+            if (string.IsNullOrEmpty(
+                    userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Trim()))
+            {
+                return false;
+            }
+
+            return true;
+        }
+
+        private static string CleanupSourceName(string sourceName, IUserSettingService userSettingService)
+        {
+            if (userSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNameRemoveUnderscore))
+            {
+                sourceName = sourceName.Replace("_", " ");
+            }
+
+            if (userSettingService.GetUserSetting<bool>(UserSettingConstants.RemovePunctuation))
+            {
+                sourceName = sourceName.Replace("-", string.Empty);
+                sourceName = sourceName.Replace(",", string.Empty);
+                sourceName = sourceName.Replace(".", string.Empty);
+            }
+
+            // Switch to "Title Case"
+            if (userSettingService.GetUserSetting<bool>(UserSettingConstants.AutoNameTitleCase))
+            {
+                sourceName = sourceName.ToTitleCase();
+            }
+
+            return sourceName;
         }
 
         private static string GenerateDestinationFileName(EncodeTask task, IUserSettingService userSettingService, string sourceName, string dvdTitle, string combinedChapterTag, string createDate, string createTime)
@@ -153,25 +136,21 @@ namespace HandBrakeWPF.Helpers
                 destinationFilename = userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNameFormat);
                 destinationFilename =
                     destinationFilename
-                        .RegexReplace(Constants.Source, sourceName)
-                        .RegexReplace(Constants.Title, dvdTitle)
-                        .RegexReplace(Constants.Chapters, combinedChapterTag)
-                        .RegexReplace(Constants.Date, DateTime.Now.Date.ToShortDateString().Replace('/', '-'))
-                        .RegexReplace(Constants.Time, DateTime.Now.ToString("HH-mm"))
-                        .RegexReplace(Constants.CretaionDate, createDate)
-                        .RegexReplace(Constants.CreationTime, createTime);
+                        .Replace(Constants.Source, sourceName)
+                        .Replace(Constants.Title, dvdTitle)
+                        .Replace(Constants.Chapters, combinedChapterTag)
+                        .Replace(Constants.Date, DateTime.Now.Date.ToShortDateString().Replace('/', '-'))
+                        .Replace(Constants.Time, DateTime.Now.ToString("HH-mm"))
+                        .Replace(Constants.CreationDate, createDate)
+                        .Replace(Constants.CreationTime, createTime);
 
                 if (task.VideoEncodeRateType == VideoEncodeRateType.ConstantQuality)
                 {
-                    destinationFilename = destinationFilename.Replace(Constants.Quality, task.Quality.ToString());
-                    destinationFilename = destinationFilename.Replace(Constants.Bitrate, string.Empty);
+                    destinationFilename = destinationFilename.Replace(Constants.QualityBitrate, task.Quality.ToString());
                 }
                 else
                 {
-                    destinationFilename = destinationFilename.Replace(
-                        Constants.Bitrate,
-                        task.VideoBitrate.ToString());
-                    destinationFilename = destinationFilename.Replace(Constants.Quality, string.Empty);
+                    destinationFilename = destinationFilename.Replace(Constants.QualityBitrate, task.VideoBitrate.ToString());
                 }
             }
             else
@@ -211,30 +190,35 @@ namespace HandBrakeWPF.Helpers
 
         private static string GetAutonamePath(IUserSettingService userSettingService, EncodeTask task, string sourceName)
         {
-            string autoNamePath = string.Empty;
+            string autoNamePath = userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Trim().Replace("/", "\\");
 
-            // If there is an auto name path, use it...
-            if (userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Trim().StartsWith("{source_path}") && !string.IsNullOrEmpty(task.Source))
+            // If enabled, use the current Destination path.
+            if (!userSettingService.GetUserSetting<bool>(UserSettingConstants.AlwaysUseDefaultPath) && !string.IsNullOrEmpty(task.Destination))
             {
-                string savedPath = userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Trim().Replace("{source_path}\\", string.Empty).Replace("{source_path}", string.Empty);
+                string path = Path.GetDirectoryName(task.Destination);
+                if (!string.IsNullOrEmpty(path))
+                {
+                    return path;
+                }
+            }
 
-                string directory = Directory.Exists(task.Source)
-                                       ? task.Source
-                                       : Path.GetDirectoryName(task.Source);
+            // Handle {source_path} 
+            if (autoNamePath.StartsWith(Constants.SourcePath) && !string.IsNullOrEmpty(task.Source))
+            {
+                string savedPath = autoNamePath.Replace(Constants.SourcePath + "\\", string.Empty).Replace(Constants.SourcePath, string.Empty);
+                string directory = Directory.Exists(task.Source) ? task.Source : Path.GetDirectoryName(task.Source);
                 autoNamePath = Path.Combine(directory, savedPath);
             }
-            else
-            {
-                autoNamePath = userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Trim();
-            }
 
-            if (userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Contains("{source}") && !string.IsNullOrEmpty(task.Source))
+            // Handle {source}
+            if (autoNamePath.Contains(Constants.Source) && !string.IsNullOrEmpty(task.Source))
             {
                 sourceName = Path.GetInvalidPathChars().Aggregate(sourceName, (current, character) => current.Replace(character.ToString(), string.Empty));
-                autoNamePath = autoNamePath.Replace("{source}", sourceName);
+                autoNamePath = autoNamePath.Replace(Constants.Source, sourceName);
             }
 
-            if (userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Contains("{source_folder_name}") && !string.IsNullOrEmpty(task.Source))
+            // Handle {source_folder_name}
+            if (autoNamePath.Contains(Constants.SourceFolderName) && !string.IsNullOrEmpty(task.Source))
             {
                 // Second Case: We have a Path, with "{source_folder}" in it, therefore we need to replace it with the folder name from the source.
                 string path = Path.GetDirectoryName(task.Source);
@@ -243,7 +227,7 @@ namespace HandBrakeWPF.Helpers
                     string[] filesArray = path.Split(Path.AltDirectorySeparatorChar, Path.DirectorySeparatorChar);
                     string sourceFolder = filesArray[filesArray.Length - 1];
 
-                    autoNamePath = userSettingService.GetUserSetting<string>(UserSettingConstants.AutoNamePath).Replace("{source_folder_name}", sourceFolder);
+                    autoNamePath = autoNamePath.Replace(Constants.SourceFolderName, sourceFolder);
                 }
             }
 
@@ -275,17 +259,14 @@ namespace HandBrakeWPF.Helpers
 
             if (behaviour != AutonameFileCollisionBehaviour.AppendNumber)
             {
-                if (autoNamePath?.ToLower() == task.Source?.ToLower())
-                {
-                    autoNamePath = Path.Combine(Path.GetDirectoryName(autoNamePath), prefix + filenameWithoutExt + postfix + extension);
+                autoNamePath = Path.Combine(Path.GetDirectoryName(autoNamePath), prefix + filenameWithoutExt + postfix + extension);
 
-                    int counter = 0;
-                    while (File.Exists(autoNamePath))
-                    {
-                        counter = counter + 1;
-                        string appendedNumber = string.Format("({0})", counter);
-                        autoNamePath = Path.Combine(Path.GetDirectoryName(autoNamePath), prefix + filenameWithoutExt + postfix + appendedNumber + extension);
-                    }
+                int counter = 0;
+                while (File.Exists(autoNamePath))
+                {
+                    counter = counter + 1;
+                    string appendedNumber = string.Format("({0})", counter);
+                    autoNamePath = Path.Combine(Path.GetDirectoryName(autoNamePath), prefix + filenameWithoutExt + postfix + appendedNumber + extension);
                 }
             }
             else
@@ -301,5 +282,29 @@ namespace HandBrakeWPF.Helpers
 
             return autoNamePath;
         }
+
+        private static DateTime ObtainCreateDateObject(EncodeTask task)
+        {
+            var rd = task.MetaData.ReleaseDate;
+            if (DateTime.TryParse(rd, out var d))
+            {
+                return d;
+            }
+
+            try
+            {
+                return File.GetCreationTime(task.Source);
+            }
+            catch (Exception e)
+            {
+                if (e is UnauthorizedAccessException || e is PathTooLongException || e is NotSupportedException)
+                {
+                    // Suspect the most likely concerns trying to grab the creation date in which we would want to swallow exception.
+                    return default(DateTime);
+                }
+
+                throw;
+            }
+        }
     }
 }
