@@ -14,25 +14,22 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
     using System.ComponentModel;
     using System.Globalization;
     using System.Linq;
+    using System.Text.Json.Serialization;
 
     using Caliburn.Micro;
 
     using HandBrake.Interop.Interop;
-    using HandBrake.Interop.Interop.Model;
-    using HandBrake.Interop.Interop.Model.Encoding;
+    using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
 
     using HandBrakeWPF.Model.Audio;
     using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.Utilities;
 
-    using Newtonsoft.Json;
-
-    [JsonObject(MemberSerialization.OptOut)]
     public class AudioTrack : PropertyChangedBase
     {
         private int bitrate;
         private double drc;
-        private HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder encoder;
+        private AudioEncoder encoder;
         private int gain;
         private string mixDown;
         private double sampleRate;
@@ -46,9 +43,8 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
         private double? quality;
         private string trackName;
 
-        /// <summary>
-        ///   Initializes a new instance of the <see cref = "AudioTrack" /> class.
-        /// </summary>
+        private bool isExpandedTrackView;
+
         public AudioTrack()
         {
             // Default Values
@@ -66,20 +62,10 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
 
             // Setup Backing Properties
-            this.EncoderRateType = HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType.Bitrate;
+            this.EncoderRateType = AudioEncoderRateType.Bitrate;
             this.SetupLimits();
         }
 
-        /// <summary>
-        /// Initializes a new instance of the <see cref="AudioTrack"/> class.
-        /// Copy Constructor
-        /// </summary>
-        /// <param name="track">
-        /// The track.
-        /// </param>
-        /// <param name="setScannedTrack">
-        /// The set Scanned Track.
-        /// </param>
         public AudioTrack(AudioTrack track, bool setScannedTrack)
         {
             this.bitrate = track.Bitrate;
@@ -110,29 +96,41 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             this.SetupLimits();
         }
 
-        /// <summary>
-        /// Initializes a new instance of the <see cref="AudioTrack"/> class. 
-        /// Create a track from a behaviour track.
-        /// </summary>
-        /// <param name="track">
-        /// The Behavior track
-        /// </param>
-        /// <param name="sourceTrack">
-        /// The source track we are dealing with.
-        /// </param>
-        /// <param name="fallback">
-        /// An encoder to fall back to.
-        /// </param>
-        public AudioTrack(AudioBehaviourTrack track, Audio sourceTrack, AudioEncoder fallback)
+        public AudioTrack(AudioBehaviourTrack track, Audio sourceTrack, AllowedPassthru fallback, OutputFormat container)
         {
             AudioEncoder chosenEncoder = track.Encoder;
             HBAudioEncoder encoderInfo = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(track.Encoder));
             if (track.IsPassthru && (sourceTrack.Codec & encoderInfo.Id) == 0)
             {
-                chosenEncoder = fallback;
-                encoderInfo = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(track.Encoder));
+                chosenEncoder = fallback.AudioEncoderFallback;
             }
 
+            if (track.IsPassthru && chosenEncoder == AudioEncoder.Passthrough)
+            {
+                HBAudioEncoder fallbackEncoderInfo = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(fallback.AudioEncoderFallback));
+
+                if (fallbackEncoderInfo != null)
+                {
+                    int format = HandBrakeEncoderHelpers.GetContainer(EnumHelper<OutputFormat>.GetShortName(container)).Id;
+                    int copyMask = checked((int)HandBrakeEncoderHelpers.BuildCopyMask(
+                        fallback.AudioAllowMP2Pass,
+                        fallback.AudioAllowMP3Pass,
+                        fallback.AudioAllowAACPass,
+                        fallback.AudioAllowAC3Pass,
+                        fallback.AudioAllowDTSPass,
+                        fallback.AudioAllowDTSHDPass,
+                        fallback.AudioAllowEAC3Pass,
+                        fallback.AudioAllowFlacPass,
+                        fallback.AudioAllowTrueHDPass));
+
+                    HBAudioEncoder autoPassthruEncoderOption = HandBrakeEncoderHelpers.GetAutoPassthruEncoder(sourceTrack.Codec, copyMask, fallbackEncoderInfo.Id, format);
+                    AudioEncoder autoPassthru = EnumHelper<AudioEncoder>.GetValue(autoPassthruEncoderOption.ShortName);
+                    chosenEncoder = autoPassthru;
+                }
+            }
+
+            encoderInfo = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(chosenEncoder));
+
             this.scannedTrack = sourceTrack;
             this.drc = track.DRC;
             this.encoder = chosenEncoder;
@@ -162,11 +160,8 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             this.SetupLimits();
         }
 
-        #region Track Properties
+        /* Audio Track Properties */
 
-        /// <summary>
-        ///   Gets or sets Dynamic Range Compression
-        /// </summary>
         public double DRC
         {
             get
@@ -184,9 +179,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        ///   Gets or sets the Gain for the audio track
-        /// </summary>
         public int Gain
         {
             get
@@ -204,9 +196,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        ///   Gets or sets Audio Mixdown (ShortName)
-        /// </summary>
         public string MixDown
         {
             get
@@ -225,9 +214,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        ///   Gets or sets Audio Encoder
-        /// </summary>
         public AudioEncoder Encoder
         {
             get
@@ -256,14 +242,11 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
                 this.NotifyOfPropertyChange(() => this.AudioEncoderRateTypes);
                 if (!this.AudioEncoderRateTypes.Contains(this.EncoderRateType))
                 {
-                    this.EncoderRateType = HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType.Bitrate; // Default to bitrate.
+                    this.EncoderRateType = AudioEncoderRateType.Bitrate; // Default to bitrate.
                 }
             }
         }
 
-        /// <summary>
-        ///   Gets or sets Audio SampleRate
-        /// </summary>
         public double SampleRate
         {
             get
@@ -279,9 +262,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets or sets the encoder rate type.
-        /// </summary>
         public AudioEncoderRateType EncoderRateType
         {
             get
@@ -299,15 +279,12 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
 
                 if (!this.Quality.HasValue)
                 {
-                    HBAudioEncoder hbAudioEncoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder>.GetShortName(this.Encoder));
+                    HBAudioEncoder hbAudioEncoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(this.Encoder));
                     this.Quality = HandBrakeEncoderHelpers.GetDefaultQuality(hbAudioEncoder);
                 }
             }
         }
 
-        /// <summary>
-        ///   Gets or sets Audio Bitrate
-        /// </summary>
         public int Bitrate
         {
             get
@@ -322,9 +299,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        ///   Gets or sets Audio quality
-        /// </summary>
         public double? Quality
         {
             get
@@ -339,9 +313,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets or sets the track name.
-        /// </summary>
         public string TrackName
         {
             get => this.trackName;
@@ -353,30 +324,24 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        #endregion
+        /* UI Only Properties */ 
 
-        /// <summary>
-        ///   Gets AudioEncoderDisplayValue.
-        /// </summary>
         [JsonIgnore]
         public string AudioEncoderDisplayValue
         {
             get
             {
-                return EnumHelper<HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder>.GetDisplay(this.Encoder);
+                return EnumHelper<AudioEncoder>.GetDisplay(this.Encoder);
             }
         }
 
-        /// <summary>
-        ///   Gets the The UI display value for bit rate
-        /// </summary>
         [JsonIgnore]
         public string BitRateDisplayValue
         {
             get
             {
-                if (this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.Ac3Passthrough || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.DtsPassthrough
-                    || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.DtsHDPassthrough)
+                if (this.Encoder == AudioEncoder.Ac3Passthrough || this.Encoder == AudioEncoder.DtsPassthrough
+                    || this.Encoder == AudioEncoder.DtsHDPassthrough)
                 {
                     return "Auto";
                 }
@@ -385,10 +350,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether is default.
-        /// TODO - Can this be removed? May have been added as a quick fix for a styling quirk.
-        /// </summary>
         [JsonIgnore]
         public bool IsDefault
         {
@@ -402,9 +363,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        ///  Gets or sets the The UI display value for sample rate
-        /// </summary>
         [JsonIgnore]
         public string SampleRateDisplayValue
         {
@@ -427,9 +385,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        ///   Gets or sets the Scanned Audio Tracks
-        /// </summary>
         [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
         public Audio ScannedTrack
         {
@@ -450,9 +405,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        ///   Gets the Audio Track Name
-        /// </summary>
         [JsonIgnore]
         public int? Track
         {
@@ -467,19 +419,16 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets a value indicating whether IsPassthru.
-        /// </summary>
         [JsonIgnore]
         public bool IsPassthru
         {
             get
             {
-                if (this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.Ac3Passthrough || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.DtsPassthrough
-                    || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.DtsHDPassthrough || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.AacPassthru
-                    || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.Mp3Passthru || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.Passthrough ||
-                    this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.EAc3Passthrough || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.TrueHDPassthrough
-                    || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.FlacPassthru)
+                if (this.Encoder == AudioEncoder.Ac3Passthrough || this.Encoder == AudioEncoder.DtsPassthrough
+                    || this.Encoder == AudioEncoder.DtsHDPassthrough || this.Encoder == AudioEncoder.AacPassthru
+                    || this.Encoder == AudioEncoder.Mp3Passthru || this.Encoder == AudioEncoder.Passthrough ||
+                    this.Encoder == AudioEncoder.EAc3Passthrough || this.Encoder == AudioEncoder.TrueHDPassthrough
+                    || this.Encoder == AudioEncoder.FlacPassthru || this.Encoder == AudioEncoder.Mp2Passthru)
                 {
                     return true;
                 }
@@ -487,9 +436,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets the bitrates.
-        /// </summary>
         [JsonIgnore]
         public IEnumerable<int> Bitrates
         {
@@ -499,9 +445,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets the quality compression values.
-        /// </summary>
         [JsonIgnore]
         public IEnumerable<double> EncoderQualityValues
         {
@@ -511,68 +454,56 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets the audio encoder rate types.
-        /// </summary>
         [JsonIgnore]
         public IEnumerable<AudioEncoderRateType> AudioEncoderRateTypes
         {
             get
             {
-                IList<HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType> types = EnumHelper<HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType>.GetEnumList().ToList();
-                HBAudioEncoder hbaenc = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder>.GetShortName(this.Encoder));
+                IList<AudioEncoderRateType> types = EnumHelper<AudioEncoderRateType>.GetEnumList().ToList();
+                HBAudioEncoder hbaenc = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(this.Encoder));
                 if (hbaenc == null || !hbaenc.SupportsQuality)
                 {
-                    types.Remove(HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType.Quality);
+                    types.Remove(AudioEncoderRateType.Quality);
                 }
 
                 return types;
             }
         }
 
-        /// <summary>
-        /// Gets a value indicating whether can set bitrate.
-        /// </summary>
         [JsonIgnore]
         public bool IsBitrateVisible
         {
             get
             {
-                if (this.IsPassthru || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac24)
+                if (this.IsPassthru || this.Encoder == AudioEncoder.ffflac || this.Encoder == AudioEncoder.ffflac24)
                 {
                     return false;
                 }
 
-                return Equals(this.EncoderRateType, HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType.Bitrate);
+                return Equals(this.EncoderRateType, AudioEncoderRateType.Bitrate);
             }
         }
 
-        /// <summary>
-        /// Gets a value indicating whether is quality visible.
-        /// </summary>
         [JsonIgnore]
         public bool IsQualityVisible
         {
             get
             {
-                if (this.IsPassthru || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac24)
+                if (this.IsPassthru || this.Encoder == AudioEncoder.ffflac || this.Encoder == AudioEncoder.ffflac24)
                 {
                     return false;
                 }
 
-                return Equals(this.EncoderRateType, HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType.Quality);
+                return Equals(this.EncoderRateType, AudioEncoderRateType.Quality);
             }
         }
 
-        /// <summary>
-        /// Gets a value indicating whether is rate type visible.
-        /// </summary>
         [JsonIgnore]
         public bool IsRateTypeVisible
         {
             get
             {
-                if (this.IsPassthru || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac24)
+                if (this.IsPassthru || this.Encoder == AudioEncoder.ffflac || this.Encoder == AudioEncoder.ffflac24)
                 {
                     return false;
                 }
@@ -581,32 +512,35 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// Gets a value indicating whether IsLossless.
-        /// </summary>
         [JsonIgnore]
         public bool IsLossless
         {
             get
             {
-                return this.IsPassthru || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac || this.Encoder == HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder.ffflac24;
+                return this.IsPassthru || this.Encoder == AudioEncoder.ffflac || this.Encoder == AudioEncoder.ffflac24;
             }
         }
 
-        /// <summary>
-        /// Gets TrackReference.
-        /// </summary>
         [JsonIgnore]
         public AudioTrack TrackReference
         {
             get { return this; }
         }
 
-        #region Handler Methods
+        [JsonIgnore]
+        public bool IsExpandedTrackView
+        {
+            get => this.isExpandedTrackView;
+            set
+            {
+                if (value == this.isExpandedTrackView) return;
+                this.isExpandedTrackView = value;
+                this.NotifyOfPropertyChange(() => this.IsExpandedTrackView);
+            }
+        }
+
+        /* Helper Methods */
 
-        /// <summary>
-        /// The setup limits.
-        /// </summary>
         private void SetupLimits()
         {
             this.SetupBitrateLimits();
@@ -614,9 +548,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             this.GetDefaultMixdownIfNull();
         }
 
-        /// <summary>
-        /// The calculate bitrate limits.
-        /// </summary>
         private void SetupBitrateLimits()
         {
             // Base set of bitrates available.
@@ -627,15 +558,18 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             int low = 32;
 
             // Based on the users settings, find the high and low bitrates.
-            HBAudioEncoder hbaenc = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder>.GetShortName(this.Encoder));
+            HBAudioEncoder hbaenc = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(this.Encoder));
             HBRate rate = HandBrakeEncoderHelpers.AudioSampleRates.FirstOrDefault(t => t.Name == this.SampleRate.ToString(CultureInfo.InvariantCulture));
             HBMixdown mixdown = this.mixDown != null ? HandBrakeEncoderHelpers.GetMixdown(this.mixDown) : HandBrakeEncoderHelpers.GetMixdown("dpl2");
 
-            BitrateLimits limits = HandBrakeEncoderHelpers.GetBitrateLimits(hbaenc, rate != null ? rate.Rate : 48000, mixdown);
-            if (limits != null)
+            if (hbaenc != null)
             {
-                max = limits.High;
-                low = limits.Low;
+                BitrateLimits limits = HandBrakeEncoderHelpers.GetBitrateLimits(hbaenc, rate != null ? rate.Rate : 48000, mixdown);
+                if (limits != null)
+                {
+                    max = limits.High;
+                    low = limits.Low;
+                }
             }
 
             // Return the subset of available bitrates.
@@ -650,13 +584,10 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        /// <summary>
-        /// The setup quality compression limits.
-        /// </summary>
         private void SetupQualityCompressionLimits()
         {
-            HBAudioEncoder hbAudioEncoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder>.GetShortName(this.Encoder));
-            if (hbAudioEncoder.SupportsQuality)
+            HBAudioEncoder hbAudioEncoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(this.Encoder));
+            if (hbAudioEncoder != null && hbAudioEncoder.SupportsQuality)
             {
                 RangeLimits limits = null;
 
@@ -700,7 +631,7 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
 
             // Default the audio quality value if it's out of range.
-            if (Equals(this.EncoderRateType, HandBrakeWPF.Services.Encode.Model.Models.AudioEncoderRateType.Quality))
+            if (Equals(this.EncoderRateType, AudioEncoderRateType.Quality))
             {
                 if (this.Quality.HasValue && !this.encoderQualityValues.Contains(this.Quality.Value))
                 {
@@ -711,9 +642,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             this.NotifyOfPropertyChange(() => this.EncoderQualityValues);
         }
 
-        /// <summary>
-        /// Set the default mixdown when the mixdown is null or "none"
-        /// </summary>
         private void GetDefaultMixdownIfNull()
         {
             if (this.ScannedTrack == null)
@@ -724,11 +652,15 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             HBAudioEncoder aencoder = HandBrakeEncoderHelpers.GetAudioEncoder(EnumHelper<AudioEncoder>.GetShortName(this.encoder));
             HBMixdown currentMixdown = HandBrakeEncoderHelpers.GetMixdown(this.mixDown);
             HBMixdown sanitisedMixdown = HandBrakeEncoderHelpers.SanitizeMixdown(currentMixdown, aencoder, (uint)this.ScannedTrack.ChannelLayout);
-            HBMixdown defaultMixdown = HandBrakeEncoderHelpers.GetDefaultMixdown(aencoder, (uint)this.ScannedTrack.ChannelLayout);
-
+            HBMixdown defaultMixdown = sanitisedMixdown;
+            if (aencoder != null)
+            {
+                defaultMixdown = HandBrakeEncoderHelpers.GetDefaultMixdown(aencoder, (uint)this.ScannedTrack.ChannelLayout);
+            }
+         
             if (this.mixDown == null || this.mixDown == "none")
             {
-                this.MixDown = defaultMixdown.ShortName;
+                this.MixDown = defaultMixdown?.ShortName;
             }
             else if (sanitisedMixdown != null)
             {
@@ -736,8 +668,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             }
         }
 
-        #endregion
-
         public override string ToString()
         {
             return string.Format("Audio Track: Title {0}", this.ScannedTrack.ToString());
