@@ -9,17 +9,12 @@
 
 namespace HandBrakeWPF.Services.Encode.Model.Models
 {
-    using System;
-
     using Caliburn.Micro;
 
     using HandBrake.Interop.Utilities;
 
     using HandBrakeWPF.Services.Scan.Model;
 
-    using Newtonsoft.Json;
-
-    [JsonObject(MemberSerialization.OptOut)]
     public class SubtitleTrack : PropertyChangedBase
     {
         #region Constants and Fields
@@ -173,7 +168,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
                 this.NotifyOfPropertyChange(() => this.SourceTrack);
                 if (this.sourceTrack != null)
                 {
-                    this.Track = this.sourceTrack.ToString();
                     this.SubtitleType = this.sourceTrack.SubtitleType;
                 }
                 
@@ -257,12 +251,6 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
         /// </summary>
         public SubtitleType SubtitleType { get; set; }
 
-        /// <summary>
-        ///   Gets or sets Track.
-        /// </summary>
-        [Obsolete("Use SourceTrack Instead")]
-        public string Track { get; set; }
-
         public string Name
         {
             get => this.name;
@@ -285,7 +273,7 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             {
                 if (this.SourceTrack != null)
                 {
-                    return this.SourceTrack.CanForce || this.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch;
+                    return this.SourceTrack.CanForce || this.SourceTrack.IsFakeForeignAudioScanTrack;
                 }
 
                 return false;
@@ -301,10 +289,15 @@ namespace HandBrakeWPF.Services.Encode.Model.Models
             {    
                 if (this.SourceTrack != null)
                 {
-                    return this.SourceTrack.CanBurnIn || this.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch || this.SubtitleType == SubtitleType.SRT;
+                    return this.SourceTrack.CanBurnIn || this.SourceTrack.IsFakeForeignAudioScanTrack;
                 }
 
-                if (this.SubtitleType == SubtitleType.SRT)
+                if (this.SubtitleType == SubtitleType.IMPORTSRT)
+                {
+                    return true;
+                }
+
+                if (this.SubtitleType == SubtitleType.IMPORTSSA)
                 {
                     return true;
                 }
