@@ -9,7 +9,6 @@
 
 namespace HandBrakeWPF.Services.Presets.Factories
 {
-    using System;
     using System.Collections.Generic;
     using System.Collections.ObjectModel;
     using System.Globalization;
@@ -17,46 +16,37 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
     using HandBrake.Interop.Interop;
     using HandBrake.Interop.Interop.HbLib;
+    using HandBrake.Interop.Interop.Interfaces.Model;
+    using HandBrake.Interop.Interop.Interfaces.Model.Filters;
+    using HandBrake.Interop.Interop.Interfaces.Model.Picture;
+    using HandBrake.Interop.Interop.Interfaces.Model.Presets;
     using HandBrake.Interop.Interop.Json.Presets;
-    using HandBrake.Interop.Interop.Model;
-    using HandBrake.Interop.Interop.Model.Encoding;
-    using HandBrake.Interop.Model;
     using HandBrake.Interop.Utilities;
 
     using HandBrakeWPF.Model.Audio;
     using HandBrakeWPF.Model.Filters;
-    using HandBrakeWPF.Model.Picture;
     using HandBrakeWPF.Model.Subtitles;
+    using HandBrakeWPF.Model.Video;
     using HandBrakeWPF.Services.Encode.Model.Models;
     using HandBrakeWPF.Services.Presets.Model;
     using HandBrakeWPF.Utilities;
 
-    using AudioEncoder = HandBrakeWPF.Services.Encode.Model.Models.AudioEncoder;
-    using AudioTrack = HandBrakeWPF.Services.Encode.Model.Models.AudioTrack;
-    using DenoisePreset = HandBrakeWPF.Services.Encode.Model.Models.DenoisePreset;
-    using DenoiseTune = HandBrakeWPF.Services.Encode.Model.Models.DenoiseTune;
-    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
-    using FramerateMode = HandBrakeWPF.Services.Encode.Model.Models.FramerateMode;
-    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
-    using VideoLevel = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoLevel;
-    using VideoPreset = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoPreset;
-    using VideoProfile = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoProfile;
-    using VideoTune = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoTune;
+    using AudioEncoder = Encode.Model.Models.AudioEncoder;
+    using AudioTrack = Encode.Model.Models.AudioTrack;
+    using DenoisePreset = Encode.Model.Models.DenoisePreset;
+    using DenoiseTune = Encode.Model.Models.DenoiseTune;
+    using EncodeTask = Encode.Model.EncodeTask;
+    using FramerateMode = Encode.Model.Models.FramerateMode;
+    using OutputFormat = Encode.Model.Models.OutputFormat;
+    using VideoEncoder = HandBrakeWPF.Model.Video.VideoEncoder;
+    using VideoEncodeRateType = HandBrakeWPF.Model.Video.VideoEncodeRateType;
+    using VideoLevel = Encode.Model.Models.Video.VideoLevel;
+    using VideoPreset = Encode.Model.Models.Video.VideoPreset;
+    using VideoProfile = Encode.Model.Models.Video.VideoProfile;
+    using VideoTune = Encode.Model.Models.Video.VideoTune;
 
-    /// <summary>
-    /// The json preset factory.
-    /// </summary>
     public class JsonPresetFactory
     {
-        /// <summary>
-        /// The create preset.
-        /// </summary>
-        /// <param name="importedPreset">
-        /// The preset.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Preset"/>.
-        /// </returns>
         public static Preset ImportPreset(HBPreset importedPreset)
         {
             Preset preset = new Preset();
@@ -71,28 +61,30 @@ namespace HandBrakeWPF.Services.Presets.Factories
             /* Output Settings */
             preset.Task.OptimizeMP4 = importedPreset.Mp4HttpOptimize;
             preset.Task.IPod5GSupport = importedPreset.Mp4iPodCompatible;
-            preset.Task.OutputFormat = GetFileFormat(importedPreset.FileFormat.Replace("file", string.Empty).Trim()); // TOOD null check.
+            preset.Task.OutputFormat = GetFileFormat(importedPreset.FileFormat.Replace("file", string.Empty).Trim());
             preset.Task.AlignAVStart = importedPreset.AlignAVStart;
+            preset.Task.MetaData.PassthruMetadataEnabled = importedPreset.MetadataPassthrough;
 
             /* Picture Settings */
-            preset.PictureSettingsMode = (PresetPictureSettingsMode)importedPreset.UsesPictureSettings;
             preset.Task.MaxWidth = importedPreset.PictureWidth.HasValue && importedPreset.PictureWidth.Value > 0 ? importedPreset.PictureWidth.Value : (int?)null;
             preset.Task.MaxHeight = importedPreset.PictureHeight.HasValue && importedPreset.PictureHeight.Value > 0 ? importedPreset.PictureHeight.Value : (int?)null;
             preset.Task.Cropping = new Cropping(importedPreset.PictureTopCrop, importedPreset.PictureBottomCrop, importedPreset.PictureLeftCrop, importedPreset.PictureRightCrop);
             preset.Task.HasCropping = !importedPreset.PictureAutoCrop;
-            preset.Task.Modulus = importedPreset.PictureModulus;
             preset.Task.KeepDisplayAspect = importedPreset.PictureKeepRatio;
+            preset.Task.AllowUpscaling = importedPreset.PictureAllowUpscaling;
+            preset.Task.OptimalSize = importedPreset.PictureUseMaximumSize;
 
+            preset.Task.Padding = new PaddingFilter();
+            preset.Task.Padding.Set(importedPreset.PicturePadTop, importedPreset.PicturePadBottom, importedPreset.PicturePadLeft, importedPreset.PicturePadRight, importedPreset.PicturePadColor, importedPreset.PicturePadMode);
+            
             switch (importedPreset.PicturePAR)
             {
                 case "custom":
                     preset.Task.Anamorphic = Anamorphic.Custom;
                     preset.Task.DisplayWidth = importedPreset.PictureDARWidth;
                     break;
-                case "loose":
-                    preset.Task.Anamorphic = Anamorphic.Loose;
-                    break;
                 case "auto":
+                case "loose":
                     preset.Task.Anamorphic = Anamorphic.Automatic;
                     break;
                 default:
@@ -103,6 +95,27 @@ namespace HandBrakeWPF.Services.Presets.Factories
             /* Filter Settings */
             preset.Task.Grayscale = importedPreset.VideoGrayScale;
 
+            if (!string.IsNullOrEmpty(importedPreset.PictureColorspacePreset))
+            {
+                preset.Task.Colourspace = new FilterPreset(HandBrakeFilterHelpers.GetFilterPresets((int)hb_filter_ids.HB_FILTER_COLORSPACE).FirstOrDefault(s => s.ShortName == importedPreset.PictureColorspacePreset));
+                preset.Task.CustomColourspace = importedPreset.PictureColorspaceCustom;
+            }
+            else
+            {
+                preset.Task.Colourspace = new FilterPreset("Off", "off");
+            }
+            
+            if (!string.IsNullOrEmpty(importedPreset.PictureChromaSmoothPreset))
+            {
+                preset.Task.ChromaSmooth = new FilterPreset(HandBrakeFilterHelpers.GetFilterPresets((int)hb_filter_ids.HB_FILTER_CHROMA_SMOOTH).FirstOrDefault(s => s.ShortName == importedPreset.PictureChromaSmoothPreset));
+                preset.Task.ChromaSmoothTune = new FilterTune(HandBrakeFilterHelpers.GetFilterTunes((int)hb_filter_ids.HB_FILTER_CHROMA_SMOOTH).FirstOrDefault(s => s.ShortName == importedPreset.PictureChromaSmoothTune));
+                preset.Task.CustomChromaSmooth = importedPreset.PictureChromaSmoothCustom;
+            }
+            else
+            {
+                preset.Task.ChromaSmooth = new FilterPreset("Off", "off");
+            }
+
             if (!string.IsNullOrEmpty(importedPreset.PictureDeblockPreset))
             {
                 preset.Task.DeblockPreset = new FilterPreset(HandBrakeFilterHelpers.GetFilterPresets((int)hb_filter_ids.HB_FILTER_DEBLOCK).FirstOrDefault(s => s.ShortName == importedPreset.PictureDeblockPreset));
@@ -316,7 +329,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
                 string[] split = importedPreset.VideoTune.Split(',');
                 foreach (var item in split)
                 {
-                    preset.Task.VideoTunes.Add(new VideoTune(item, item));
+                    preset.Task.VideoTunes.Add(new VideoTune(item?.Trim(), item?.Trim()));
                 }
             }
 
@@ -349,7 +362,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             /* Audio Settings */
             preset.AudioTrackBehaviours = new AudioBehaviours();
-            preset.Task.AllowedPassthruOptions.AudioEncoderFallback = EnumHelper<AudioEncoder>.GetValue(importedPreset.AudioEncoderFallback);
+            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioEncoderFallback = EnumHelper<AudioEncoder>.GetValue(importedPreset.AudioEncoderFallback);
             preset.AudioTrackBehaviours.SelectedBehaviour = importedPreset.AudioTrackSelectionBehavior == "all"
                                                                      ? AudioBehaviourModes.AllMatching
                                                                      : AudioBehaviourModes.FirstMatch;
@@ -358,35 +371,38 @@ namespace HandBrakeWPF.Services.Presets.Factories
 
             if (importedPreset.AudioCopyMask != null)
             {
-                preset.Task.AllowedPassthruOptions.SetFalse();
+                preset.AudioTrackBehaviours.AllowedPassthruOptions.SetFalse();
                 foreach (var item in importedPreset.AudioCopyMask)
                 {
                     AudioEncoder encoder = EnumHelper<AudioEncoder>.GetValue(item);
                     switch (encoder)
                     {
                         case AudioEncoder.AacPassthru:
-                            preset.Task.AllowedPassthruOptions.AudioAllowAACPass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowAACPass = true;
                             break;
                         case AudioEncoder.Ac3Passthrough:
-                            preset.Task.AllowedPassthruOptions.AudioAllowAC3Pass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowAC3Pass = true;
                             break;
                         case AudioEncoder.EAc3Passthrough:
-                            preset.Task.AllowedPassthruOptions.AudioAllowEAC3Pass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowEAC3Pass = true;
                             break;
                         case AudioEncoder.DtsHDPassthrough:
-                            preset.Task.AllowedPassthruOptions.AudioAllowDTSHDPass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowDTSHDPass = true;
                             break;
                         case AudioEncoder.DtsPassthrough:
-                            preset.Task.AllowedPassthruOptions.AudioAllowDTSPass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowDTSPass = true;
                             break;
                         case AudioEncoder.FlacPassthru:
-                            preset.Task.AllowedPassthruOptions.AudioAllowFlacPass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowFlacPass = true;
+                            break;
+                        case AudioEncoder.Mp2Passthru:
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowMP2Pass = true;
                             break;
                         case AudioEncoder.Mp3Passthru:
-                            preset.Task.AllowedPassthruOptions.AudioAllowMP3Pass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowMP3Pass = true;
                             break;
                         case AudioEncoder.TrueHDPassthrough:
-                            preset.Task.AllowedPassthruOptions.AudioAllowTrueHDPass = true;
+                            preset.AudioTrackBehaviours.AllowedPassthruOptions.AudioAllowTrueHDPass = true;
                             break;
                     }
                 }
@@ -397,7 +413,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
                 IList<string> names = LanguageUtilities.GetLanguageNames(importedPreset.AudioLanguageList);
                 foreach (var name in names)
                 {
-                    preset.AudioTrackBehaviours.SelectedLangauges.Add(name);
+                    preset.AudioTrackBehaviours.SelectedLanguages.Add(name);
                 }
             }
 
@@ -407,7 +423,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
             {
                 foreach (var audioTrack in importedPreset.AudioList)
                 {
-                    AudioBehaviourTrack track = new AudioBehaviourTrack();
+                    AudioBehaviourTrack track = new AudioBehaviourTrack(EnumHelper<AudioEncoder>.GetValue(importedPreset.AudioEncoderFallback));
                     
                     // track.CompressionLevel = audioTrack.AudioCompressionLevel;
                     // track.AudioDitherMethod = audioTrack.AudioDitherMethod;
@@ -456,7 +472,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
                 IList<string> names = LanguageUtilities.GetLanguageNames(importedPreset.SubtitleLanguageList);
                 foreach (var name in names)
                 {
-                    preset.SubtitleTrackBehaviours.SelectedLangauges.Add(name);
+                    preset.SubtitleTrackBehaviours.SelectedLanguages.Add(name);
                 }
             }
 
@@ -478,25 +494,11 @@ namespace HandBrakeWPF.Services.Presets.Factories
             // public int PictureForceHeight { get; set; }
             // public int PictureForceWidth { get; set; }
             // public List<object> ChildrenArray { get; set; }
-            // public bool Folder { get; set; }
-            // public bool FolderOpen { get; set; }
             // public int Type { get; set; }
 
             return preset;
         }
 
-        /// <summary>
-        /// The export preset.
-        /// </summary>
-        /// <param name="export">
-        /// The export.
-        /// </param>
-        /// <param name="config">
-        /// HandBrakes configuration options.
-        /// </param>
-        /// <returns>
-        /// The <see cref="Preset"/>.
-        /// </returns>
         public static PresetTransportContainer ExportPreset(Preset export, HBConfiguration config)
         {
             PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
@@ -507,12 +509,6 @@ namespace HandBrakeWPF.Services.Presets.Factories
             return container;
         }
 
-        /// <summary>
-        /// Export a list of Presets.
-        /// </summary>
-        /// <param name="exportList">A list of presets to export</param>
-        /// <param name="config">HB's configuration</param>
-        /// <returns>A list of JSON object presets.</returns>
         public static PresetTransportContainer ExportPresets(IEnumerable<Preset> exportList, HBConfiguration config)
         {
             PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
@@ -526,16 +522,38 @@ namespace HandBrakeWPF.Services.Presets.Factories
             return container;
         }
 
-        /// <summary>
-        /// The create hb preset.
-        /// </summary>
-        /// <param name="export">
-        /// The export.
-        /// </param>
-        /// <param name="config">HandBrakes current configuration</param>
-        /// <returns>
-        /// The <see cref="HBPreset"/>.
-        /// </returns>
+        public static PresetTransportContainer ExportPresetCategories(IList<PresetDisplayCategory> categories, HBConfiguration config)
+        {
+            PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
+            PresetTransportContainer container = new PresetTransportContainer(presetVersion.Major, presetVersion.Minor, presetVersion.Micro);
+
+            List<object> presets = new List<object>();
+            foreach (var category in categories)
+            {
+                presets.Add(CreatePresetCategory(category, config));
+            }
+
+            container.PresetList = presets;
+
+            return container;
+        }
+
+        public static HBPresetCategory CreatePresetCategory(PresetDisplayCategory category, HBConfiguration config)
+        {
+            HBPresetCategory preset = new HBPresetCategory();
+            preset.Folder = true;
+            preset.PresetName = category.Category;
+            preset.PresetDescription = string.Empty;
+            preset.ChildrenArray = new List<HBPreset>();
+
+            foreach (Preset singlePreset in category.Presets)
+            {
+                preset.ChildrenArray.Add(CreateHbPreset(singlePreset, config));
+            }
+
+            return preset;
+        }
+
         public static HBPreset CreateHbPreset(Preset export, HBConfiguration config)
         {
             HBPreset preset = new HBPreset();
@@ -544,13 +562,12 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.PresetDescription = export.Description;
             preset.PresetName = export.Name;
             preset.Type = export.IsBuildIn ? 0 : 1;
-            preset.UsesPictureSettings = (int)export.PictureSettingsMode;
             preset.Default = export.IsDefault;
 
             // Audio
-            preset.AudioCopyMask = export.Task.AllowedPassthruOptions.AllowedPassthruOptions.Select(EnumHelper<AudioEncoder>.GetShortName).ToList();
-            preset.AudioEncoderFallback = EnumHelper<AudioEncoder>.GetShortName(export.Task.AllowedPassthruOptions.AudioEncoderFallback);
-            preset.AudioLanguageList = LanguageUtilities.GetLanguageCodes(export.AudioTrackBehaviours.SelectedLangauges);
+            preset.AudioCopyMask = export.AudioTrackBehaviours.AllowedPassthruOptions.AllowedPassthruOptions.Select(EnumHelper<AudioEncoder>.GetShortName).ToList();
+            preset.AudioEncoderFallback = EnumHelper<AudioEncoder>.GetShortName(export.AudioTrackBehaviours.AllowedPassthruOptions.AudioEncoderFallback);
+            preset.AudioLanguageList = LanguageUtilities.GetLanguageCodes(export.AudioTrackBehaviours.SelectedLanguages);
             preset.AudioTrackSelectionBehavior = EnumHelper<AudioBehaviourModes>.GetShortName(export.AudioTrackBehaviours.SelectedBehaviour);
             preset.AudioSecondaryEncoderMode = export.AudioTrackBehaviours.SelectedTrackDefaultBehaviour == AudioTrackDefaultsMode.FirstTrack; // 1 = First Track, 0 = All
             preset.AudioList = new List<AudioList>();
@@ -580,7 +597,7 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.SubtitleBurnBDSub = false; // TODO not supported yet.
             preset.SubtitleBurnDVDSub = false; // TODO not supported yet.
             preset.SubtitleBurnBehavior = EnumHelper<SubtitleBurnInBehaviourModes>.GetShortName(export.SubtitleTrackBehaviours.SelectedBurnInBehaviour);
-            preset.SubtitleLanguageList = LanguageUtilities.GetLanguageCodes(export.SubtitleTrackBehaviours.SelectedLangauges);
+            preset.SubtitleLanguageList = LanguageUtilities.GetLanguageCodes(export.SubtitleTrackBehaviours.SelectedLanguages);
             preset.SubtitleTrackSelectionBehavior = EnumHelper<SubtitleBehaviourModes>.GetShortName(export.SubtitleTrackBehaviours.SelectedBehaviour);
 
             // Chapters
@@ -591,34 +608,42 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.Mp4HttpOptimize = export.Task.OptimizeMP4;
             preset.Mp4iPodCompatible = export.Task.IPod5GSupport;
             preset.AlignAVStart = export.Task.AlignAVStart;
+            preset.MetadataPassthrough = export.Task.MetaData?.PassthruMetadataEnabled ?? false;
 
             // Picture Settings
             preset.PictureForceHeight = 0; // TODO
             preset.PictureForceWidth = 0; // TODO
-            preset.PictureHeight = preset.UsesPictureSettings >= 1 ? export.Task.MaxHeight : 0; // TODO; // TODO
+            preset.PictureHeight = export.Task.MaxHeight;
             preset.PictureItuPAR = false; // TODO Not supported Yet
             preset.PictureKeepRatio = export.Task.KeepDisplayAspect;
             preset.PictureLeftCrop = export.Task.Cropping.Left;
             preset.PictureLooseCrop = false; // TODO Not Supported Yet
-            preset.PictureModulus = export.Task.Modulus ?? 16;
             preset.PicturePAR = EnumHelper<Anamorphic>.GetShortName(export.Task.Anamorphic);
             preset.PicturePARHeight = export.Task.PixelAspectY;
             preset.PicturePARWidth = export.Task.PixelAspectX;
             preset.PictureRightCrop = export.Task.Cropping.Right;
 
+            preset.PicturePadMode = export.Task.Padding.Mode;
+            preset.PicturePadTop = export.Task.Padding.Y;
+            preset.PicturePadBottom = export.Task.Padding.Bottom;
+            preset.PicturePadLeft = export.Task.Padding.X;
+            preset.PicturePadRight = export.Task.Padding.Right;
+            preset.PicturePadColor = export.Task.Padding.Color;
+            preset.PictureUseMaximumSize = export.Task.OptimalSize;
+            preset.PictureAllowUpscaling = export.Task.AllowUpscaling;
+
             if (export.Task.Rotation != 0 || export.Task.FlipVideo)
             {
                 preset.PictureRotate = string.Format("{0}:{1}", export.Task.Rotation, export.Task.FlipVideo ? "1" : "0");
             }
 
             preset.PictureTopCrop = export.Task.Cropping.Top;
-            preset.PictureWidth = preset.UsesPictureSettings >= 1 ? export.Task.MaxWidth : 0; // TODO
+            preset.PictureWidth = export.Task.MaxWidth;
             preset.PictureDARWidth = export.Task.DisplayWidth.HasValue ? (int)export.Task.DisplayWidth.Value : 0;
             preset.PictureAutoCrop = !export.Task.HasCropping;
             preset.PictureBottomCrop = export.Task.Cropping.Bottom;
 
             // Filters
-            preset.UsesPictureFilters = true;
             preset.PictureDeblockPreset = export.Task.DeblockPreset?.Key;
             preset.PictureDeblockTune = export.Task.DeblockTune?.Key;
             preset.PictureDeblockCustom = export.Task.CustomDeblock;
@@ -645,6 +670,13 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.PictureSharpenTune = export.Task.SharpenTune != null ? export.Task.SharpenTune.Key : string.Empty;
             preset.PictureSharpenCustom = export.Task.SharpenCustom;
 
+            preset.PictureColorspacePreset = export.Task.Colourspace?.Key;
+            preset.PictureColorspaceCustom = export.Task.CustomColourspace;
+
+            preset.PictureChromaSmoothPreset = export.Task.ChromaSmooth?.Key;
+            preset.PictureChromaSmoothTune = export.Task.ChromaSmoothTune?.Key;
+            preset.PictureChromaSmoothCustom = export.Task.CustomChromaSmooth;
+            
             // Video
             preset.VideoEncoder = EnumHelper<VideoEncoder>.GetShortName(export.Task.VideoEncoder);
             preset.VideoFramerate = export.Task.Framerate.HasValue ? export.Task.Framerate.ToString() : null;
@@ -654,34 +686,24 @@ namespace HandBrakeWPF.Services.Presets.Factories
             preset.VideoOptionExtra = export.Task.ExtraAdvancedArguments;
             preset.VideoPreset = export.Task.VideoPreset != null ? export.Task.VideoPreset.ShortName : null;
             preset.VideoProfile = export.Task.VideoProfile != null ? export.Task.VideoProfile.ShortName : null;
-            preset.VideoQSVAsyncDepth = 4; // Defaulted to 4 for now.
             preset.VideoQSVDecode = config.EnableQuickSyncDecoding;
             preset.VideoQualitySlider = export.Task.Quality.HasValue ? export.Task.Quality.Value : 0;
             preset.VideoQualityType = (int)export.Task.VideoEncodeRateType;
-            preset.VideoScaler = EnumHelper<VideoScaler>.GetShortName(config.ScalingMode);
-            preset.VideoTune = export.Task.VideoTunes.Aggregate(string.Empty, (current, item) => !string.IsNullOrEmpty(current) ? string.Format("{0}, {1}", current, item.ShortName) : item.ShortName);
+            preset.VideoScaler = EnumHelper<VideoScaler>.GetShortName(VideoScaler.Lanczos);
+            preset.VideoTune = export.Task.VideoTunes.Aggregate(string.Empty, (current, item) => !string.IsNullOrEmpty(current) ? string.Format("{0},{1}", current, item.ShortName) : item.ShortName);
             preset.VideoAvgBitrate = export.Task.VideoBitrate ?? 0;
             preset.VideoColorMatrixCode = 0; // TODO not supported.
             preset.VideoTurboTwoPass = export.Task.TurboFirstPass;
             preset.VideoTwoPass = export.Task.TwoPass;
 
             // Unknown
-            preset.ChildrenArray = new List<object>(); // We don't support nested presets.
-            preset.Folder = false; // TODO
-            preset.FolderOpen = false; // TODO
+            preset.ChildrenArray = new List<object>(); 
+            preset.Folder = false;
+            preset.FolderOpen = false;
 
             return preset;
         }
 
-        /// <summary>
-        /// Get the OutputFormat Enum for a given string
-        /// </summary>
-        /// <param name="format">
-        /// OutputFormat as a string
-        /// </param>
-        /// <returns>
-        /// An OutputFormat Enum
-        /// </returns> 
         private static OutputFormat GetFileFormat(string format)
         {
             switch (format.ToLower())
@@ -695,6 +717,9 @@ namespace HandBrakeWPF.Services.Presets.Factories
                 case "mkv":
                 case "av_mkv":
                     return OutputFormat.Mkv;
+                case "webm":
+                case "av_webm":
+                    return OutputFormat.WebM;
             }
         }
     }
