@@ -12,70 +12,52 @@ namespace HandBrakeWPF.Services.Presets
     using System;
     using System.Collections.Generic;
     using System.Collections.ObjectModel;
-    using System.Collections.Specialized;
     using System.ComponentModel;
-    using System.Diagnostics;
     using System.IO;
     using System.Linq;
+    using System.Runtime.InteropServices;
+    using System.Text.Json;
     using System.Windows;
 
     using HandBrake.Interop.Interop;
+    using HandBrake.Interop.Interop.Interfaces.Model;
+    using HandBrake.Interop.Interop.Interfaces.Model.Presets;
     using HandBrake.Interop.Interop.Json.Presets;
-    using HandBrake.Interop.Interop.Model;
-    using HandBrake.Interop.Model;
     using HandBrake.Interop.Utilities;
 
     using HandBrakeWPF.Factories;
-    using HandBrakeWPF.Model.Picture;
     using HandBrakeWPF.Properties;
-    using HandBrakeWPF.Services.Encode.Model.Models;
     using HandBrakeWPF.Services.Interfaces;
-    using HandBrakeWPF.Services.Logging;
     using HandBrakeWPF.Services.Logging.Interfaces;
-    using HandBrakeWPF.Services.Logging.Model;
     using HandBrakeWPF.Services.Presets.Factories;
     using HandBrakeWPF.Services.Presets.Interfaces;
     using HandBrakeWPF.Services.Presets.Model;
     using HandBrakeWPF.Utilities;
 
-    using Newtonsoft.Json;
+    using GeneralApplicationException = Exceptions.GeneralApplicationException;
+    using VideoEncoder = HandBrakeWPF.Model.Video.VideoEncoder;
 
-    using GeneralApplicationException = HandBrakeWPF.Exceptions.GeneralApplicationException;
-
-    /// <summary>
-    /// The preset service manages HandBrake's presets
-    /// </summary>
     public class PresetService : IPresetService
     {
         public const int ForcePresetReset = 3;
-        public static string UserPresetCatgoryName = "Custom Presets";
-        private readonly string presetFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(VersionHelper.IsNightly()), "presets.json");
+        public static string UserPresetCategoryName = "Custom Presets";
+        private readonly string presetFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(HandBrakeVersionHelper.IsNightly()), "presets.json");
         private readonly ObservableCollection<IPresetObject> presets = new ObservableCollection<IPresetObject>(); // Can store Presets and PresetDisplayCategory objects.
         private readonly Dictionary<string, Preset> flatPresetDict = new Dictionary<string, Preset>();
         private readonly List<Preset> flatPresetList = new List<Preset>();
         private readonly IErrorService errorService;
         private readonly IUserSettingService userSettingService;
-        private ILog log = LogService.GetLogger();
+        private ILog log;
 
-
-        /// <summary>
-        /// Initializes a new instance of the <see cref="PresetService"/> class.
-        /// </summary>
-        /// <param name="errorService">
-        /// The error service.
-        /// </param>
-        /// <param name="userSettingService">
-        /// The User setting service.
-        /// </param>
-        public PresetService(IErrorService errorService, IUserSettingService userSettingService)
+        public PresetService(IErrorService errorService, IUserSettingService userSettingService, ILog logService)
         {
+            this.log = logService;
             this.errorService = errorService;
             this.userSettingService = userSettingService;
         }
 
-        /// <summary>
-        /// Gets a Collection of presets.
-        /// </summary>
+        public event EventHandler PresetCollectionChanged;
+
         public ObservableCollection<IPresetObject> Presets
         {
             get
@@ -84,9 +66,8 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        /// <summary>
-        /// Gets the DefaultPreset.
-        /// </summary>
+        public List<Preset> FlatPresetList => this.flatPresetList.ToList();
+
         public Preset DefaultPreset
         {
             get
@@ -95,9 +76,6 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        /// <summary>
-        /// The load.
-        /// </summary>
         public void Load()
         {
             // Load the presets from file
@@ -109,20 +87,6 @@ namespace HandBrakeWPF.Services.Presets
             return this.Add(preset, false);
         }
 
-        /// <summary>
-        /// Add a new preset to the system.
-        /// Performs an Update if it already exists
-        /// </summary>
-        /// <param name="preset">
-        /// A Preset to add
-        /// </param>
-        /// <param name="isLoading">
-        /// Prevents Saving of presets.
-        /// </param>
-        /// <returns>
-        /// True if added,
-        /// False if name already exists
-        /// </returns>
         public bool Add(Preset preset, bool isLoading)
         {
             if (!this.CheckIfPresetExists(preset.Name))
@@ -151,6 +115,7 @@ namespace HandBrakeWPF.Services.Presets
                 if (!isLoading)
                 {
                     this.SavePresetFiles();
+                    this.OnPresetCollectionChanged();
                 }
 
                 return true;
@@ -158,21 +123,16 @@ namespace HandBrakeWPF.Services.Presets
             else
             {
                 this.Update(preset);
+                this.OnPresetCollectionChanged();
                 return true;
             }
         }
 
-        /// <summary>
-        /// The import.
-        /// </summary>
-        /// <param name="filename">
-        /// The filename.
-        /// </param>
         public void Import(string filename)
         {
             if (!string.IsNullOrEmpty(filename))
             {
-                PresetTransportContainer container = null;
+                PresetTransportContainer container;
                 try
                 {
                     container = HandBrakePresetService.GetPresetsFromFile(filename);
@@ -195,13 +155,15 @@ namespace HandBrakeWPF.Services.Presets
                     bool containsBuildInPreset = false;
                     foreach (var objectPreset in container.PresetList)
                     {
-                        PresetCategory category = JsonConvert.DeserializeObject<PresetCategory>(objectPreset.ToString());
+                        HBPresetCategory category = JsonSerializer.Deserialize<HBPresetCategory>(objectPreset.ToString(), JsonSettings.Options);
                         if (category != null && category.ChildrenArray != null && category.ChildrenArray.Count > 0)
                         {
                             foreach (HBPreset hbPreset in category.ChildrenArray)
                             {
-                                Preset preset = this.ConvertHbPreset(hbPreset);
-                                if (preset != null && !preset.IsBuildIn)
+                                Preset preset = this.ConvertHbPreset(hbPreset, category.PresetName);
+                                preset.IsPresetDisabled = this.IsPresetDisabled(preset);
+                                preset.IsDefault = false; // When importing, force the user to reset default manually.  This prevents conflicts.
+                                if (!preset.IsBuildIn)
                                 {
                                     this.AddOrUpdateImportedPreset(preset);
                                 }
@@ -213,11 +175,13 @@ namespace HandBrakeWPF.Services.Presets
                         }
                         else
                         {
-                            HBPreset hbPreset = JsonConvert.DeserializeObject<HBPreset>(objectPreset.ToString());
+                            HBPreset hbPreset = JsonSerializer.Deserialize<HBPreset>(objectPreset.ToString(), JsonSettings.Options);
                             if (hbPreset != null)
                             {
-                                Preset preset = this.ConvertHbPreset(hbPreset);
-                                if (preset != null && !preset.IsBuildIn)
+                                Preset preset = this.ConvertHbPreset(hbPreset, null);
+                                preset.IsDefault = false; // When importing, force the user to reset default manually.  This prevents conflicts.
+                                preset.IsPresetDisabled = this.IsPresetDisabled(preset);
+                                if (!preset.IsBuildIn)
                                 {
                                     this.AddOrUpdateImportedPreset(preset);
                                 }
@@ -241,38 +205,24 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        /// <summary>
-        /// The export.
-        /// </summary>
-        /// <param name="filename">
-        /// The filename.
-        /// </param>
-        /// <param name="preset">
-        /// The preset.
-        /// </param>
-        /// <param name="configuration">
-        /// The configuration.
-        /// </param>
         public void Export(string filename, Preset preset, HBConfiguration configuration)
         {
-            // TODO Add support for multiple export
             PresetTransportContainer container = JsonPresetFactory.ExportPreset(preset, configuration);
             HandBrakePresetService.ExportPreset(filename, container);
         }
 
-        /// <summary>
-        /// Update a preset
-        /// </summary>
-        /// <param name="update">
-        /// The updated preset
-        /// </param>
+        public void ExportCategories(string filename, IList<PresetDisplayCategory> categories, HBConfiguration configuration)
+        {
+            PresetTransportContainer container = JsonPresetFactory.ExportPresetCategories(categories, configuration);
+            HandBrakePresetService.ExportPreset(filename, container);
+        }
+
         public void Update(Preset update)
         {
             Preset preset;
             if (this.flatPresetDict.TryGetValue(update.Name, out preset))
             {
                 preset.Task = update.Task;
-                preset.PictureSettingsMode = update.PictureSettingsMode;
                 preset.Category = update.Category;
                 preset.Description = update.Description;
                 preset.AudioTrackBehaviours = update.AudioTrackBehaviours;
@@ -283,45 +233,40 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        /// <summary>
-        /// Replace an existing preset with a modified one.
-        /// </summary>
-        /// <param name="existing">
-        /// The existing.
-        /// </param>
-        /// <param name="replacement">
-        /// The replacement.
-        /// </param>
         public void Replace(Preset existing, Preset replacement)
         {
-            this.Remove(existing);
+            this.Remove(existing, true, true);
             this.Add(replacement, false);
+            this.OnPresetCollectionChanged();
         }
 
-        /// <summary>
-        /// Remove a preset with a given name from either the built in or user preset list.
-        /// </summary>
-        /// <param name="preset">
-        /// The Preset to remove
-        /// </param>
-        /// <returns>True if successfully removed, false otherwise.</returns>
         public bool Remove(Preset preset)
         {
-            if (preset == null || preset.IsDefault)
+            return this.Remove(preset, false, false);
+        }
+
+        public bool Remove(Preset preset, bool overrideDefaultCheck, bool skipCategoryRemoval)
+        {
+            if (preset == null)
             {
                 return false;
             }
 
-            PresetDisplayCategory cateogry = this.presets.FirstOrDefault(p => p.Category == preset.Category) as PresetDisplayCategory;
-            if (cateogry != null)
+            if (preset.IsDefault && !overrideDefaultCheck)
+            {
+                return false;
+            }
+            
+            PresetDisplayCategory category = this.presets.FirstOrDefault(p => p.Category == preset.Category) as PresetDisplayCategory;
+            if (category != null)
             {
                 // Remove the preset, and cleanup the category if it's not got any presets in it.
-                cateogry.Presets.Remove(preset);
+                category.Presets.Remove(preset);
                 this.flatPresetList.Remove(preset);
                 this.flatPresetDict.Remove(preset.Name);
-                if (cateogry.Presets.Count == 0)
+                if (category.Presets.Count == 0 && !skipCategoryRemoval)
                 {
-                    this.presets.Remove(cateogry);
+                    this.presets.Remove(category);
                 }
             }
             else
@@ -332,16 +277,41 @@ namespace HandBrakeWPF.Services.Presets
             }
 
             this.SavePresetFiles();
+            this.OnPresetCollectionChanged();
 
             return true;
         }
 
-        /// <summary>
-        /// Remove a group of presets by category
-        /// </summary>
-        /// <param name="categoryName">
-        /// The Category to remove
-        /// </param>
+        public void AddCategory(string categoryName)
+        {
+            if (string.IsNullOrEmpty(categoryName))
+            {
+                this.errorService.ShowMessageBox(
+                    Resources.PresetService_CategoryNameEmpty,
+                    Resources.Error,
+                    MessageBoxButton.OK,
+                    MessageBoxImage.Error);
+            }
+
+            PresetDisplayCategory category = this.presets.FirstOrDefault(a => a.Category == categoryName) as PresetDisplayCategory;
+            if (category != null)
+            {
+                this.errorService.ShowMessageBox(
+                    Resources.PresetService_CategoryAlreadyExists,
+                    Resources.Error,
+                    MessageBoxButton.OK,
+                    MessageBoxImage.Error);
+
+                return;
+            }
+
+            // Otherwise, if we have category but it doesn't exist, create it.
+            this.presets.Add(new PresetDisplayCategory(categoryName, false, new BindingList<Preset>()));
+
+            // Update the presets file
+            this.SavePresetFiles();
+        }
+
         public void RemoveGroup(string categoryName)
         {
             PresetDisplayCategory category = this.presets.FirstOrDefault(p => p.Category == categoryName) as PresetDisplayCategory;
@@ -370,12 +340,6 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        /// <summary>
-        /// Set Default Preset
-        /// </summary>
-        /// <param name="preset">
-        /// The name.
-        /// </param>
         public void SetDefault(Preset preset)
         {
             // Set IsDefault false for everything.
@@ -390,15 +354,6 @@ namespace HandBrakeWPF.Services.Presets
             this.SavePresetFiles();
         }
 
-        /// <summary>
-        /// Get a Preset
-        /// </summary>
-        /// <param name="name">
-        /// The name of the preset to get
-        /// </param>
-        /// <returns>
-        /// A Preset or null object
-        /// </returns>
         public Preset GetPreset(string name)
         {
             Preset preset;
@@ -410,9 +365,6 @@ namespace HandBrakeWPF.Services.Presets
             return null;
         }
 
-        /// <summary>
-        /// Clear Built-in Presets
-        /// </summary>
         public void ClearBuiltIn()
         {
             List<IPresetObject> topLevel = new List<IPresetObject>();
@@ -468,24 +420,20 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        /// <summary>
-        /// Clear all presets
-        /// </summary>
         public void ClearAll()
         {
             this.presets.Clear();
             this.flatPresetList.Clear();
         }
 
-        /// <summary>
-        /// Reads the CLI's CLI output format and load's them into the preset List Preset
-        /// </summary>
         public void UpdateBuiltInPresets()
         {
             // Clear the current built in Presets and now parse the temporary Presets file.
             this.ClearBuiltIn();
 
-            IList<PresetCategory> presetCategories = HandBrakePresetService.GetBuiltInPresets();
+            bool hasUserDefault = this.flatPresetDict.Values.FirstOrDefault(f => f.IsDefault) != null;
+
+            IList<HBPresetCategory> presetCategories = HandBrakePresetService.GetBuiltInPresets();
 
             foreach (var category in presetCategories)
             {
@@ -494,7 +442,12 @@ namespace HandBrakeWPF.Services.Presets
                     Preset preset = JsonPresetFactory.ImportPreset(hbpreset);
                     preset.IsBuildIn = true;
                     preset.Category = category.PresetName;
-                    preset.Task.AllowedPassthruOptions = new AllowedPassthru(true); // We don't want to override the built-in preset
+                    preset.IsPresetDisabled = this.IsPresetDisabled(preset) || hbpreset.PresetDisabled;
+
+                    if (hbpreset.Default && hasUserDefault)
+                    {
+                        preset.IsDefault = false;
+                    }
 
                     this.Add(preset, true);
                 }
@@ -511,15 +464,6 @@ namespace HandBrakeWPF.Services.Presets
             this.SavePresetFiles();
         }
 
-        /// <summary>
-        /// Check if the preset "name" exists in either Presets or UserPresets lists.
-        /// </summary>
-        /// <param name="name">
-        /// Name of the preset
-        /// </param>
-        /// <returns>
-        /// True if found
-        /// </returns>
         public bool CheckIfPresetExists(string name)
         {
             if (this.flatPresetDict.ContainsKey(name))
@@ -530,15 +474,6 @@ namespace HandBrakeWPF.Services.Presets
             return false;
         }
 
-        /// <summary>
-        /// Returns a value if the preset can be updated / resaved
-        /// </summary>
-        /// <param name="name">
-        /// The name.
-        /// </param>
-        /// <returns>
-        /// True if it's not a built-in preset, false otherwise.
-        /// </returns>
         public bool CanUpdatePreset(string name)
         {
             Preset preset;
@@ -550,10 +485,6 @@ namespace HandBrakeWPF.Services.Presets
             return true;
         }
 
-        /// <summary>
-        /// Set the selected preset
-        /// </summary>
-        /// <param name="selectedPreset">The preset we want to select.</param>
         public void SetSelected(Preset selectedPreset)
         {
             foreach (var item in this.flatPresetList)
@@ -562,11 +493,36 @@ namespace HandBrakeWPF.Services.Presets
             }
 
             selectedPreset.IsSelected = true;
+
+            IPresetObject category = this.Presets.FirstOrDefault(p => p.Category == selectedPreset.Category);
+            if (category != null)
+            {
+                category.IsExpanded = true;
+            }
+        }
+
+        public void ChangePresetCategory(Preset preset, string categoryName)
+        {
+            if (string.IsNullOrEmpty(categoryName))
+            {
+                return;
+            }
+
+            if (preset != null)
+            {
+                preset.Category = categoryName;
+            }
+
+            this.Save();
+            this.ClearPresetService();
+            this.Load();
+            this.LoadCategoryStates();
+            this.OnPresetCollectionChanged();
         }
 
         public void SaveCategoryStates()
         {
-            StringCollection expandedPresets = new StringCollection();
+            List<string> expandedPresets = new List<string>();
             foreach (IPresetObject presetObject in this.presets)
             {
                 PresetDisplayCategory category = presetObject as PresetDisplayCategory;
@@ -581,7 +537,7 @@ namespace HandBrakeWPF.Services.Presets
 
         public void LoadCategoryStates()
         {
-            StringCollection expandedPresets = this.userSettingService.GetUserSetting<StringCollection>(UserSettingConstants.PresetExpandedStateList);
+            List<string> expandedPresets = this.userSettingService.GetUserSetting<List<string>>(UserSettingConstants.PresetExpandedStateList);
             if (expandedPresets == null || expandedPresets.Count == 0)
             {
                 return;
@@ -618,18 +574,11 @@ namespace HandBrakeWPF.Services.Presets
             return categoriesList;
         }
 
-        /// <summary>
-        /// Archive the presets file without deleting it.
-        /// </summary>
-        /// <param name="file">
-        /// The filename to archive
-        /// </param>
-        /// <param name="delete">
-        /// True will delete the current presets file.
-        /// </param>
-        /// <returns>
-        /// The archived filename
-        /// </returns>
+        public void Save()
+        {
+            this.SavePresetFiles();
+        }
+        
         private string ArchivePresetFile(string file, bool delete)
         {
             try
@@ -665,9 +614,6 @@ namespace HandBrakeWPF.Services.Presets
             return "Sorry, the archiving failed.";
         }
 
-        /// <summary>
-        /// Load in the Built-in and User presets into the collection
-        /// </summary>
         private void LoadPresets()
         {
             // First clear the Presets arraylists
@@ -694,7 +640,7 @@ namespace HandBrakeWPF.Services.Presets
                     this.ServiceLogMessage("Corrupted Presets File Detected: " + Environment.NewLine + exc);
                 }
 
-                // Sanity Check. Did the container deserialise.
+                // Sanity Check. Did the container deserialize.
                 if (container?.PresetList == null)
                 {
                     this.ServiceLogMessage("Attempting Preset Recovery ...");
@@ -725,8 +671,16 @@ namespace HandBrakeWPF.Services.Presets
                     this.UpdateBuiltInPresets(); // Update built-in presets stores the presets locally, so just return.
                     return;
                 }
-
+                
                 this.ProcessPresetList(container);
+
+                PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
+                if (container.VersionMajor != presetVersion.Major || container.VersionMinor != presetVersion.Minor || container.VersionMicro != presetVersion.Micro)
+                {
+                    this.UpdateBuiltInPresets();
+                }
+
+                CheckAndSetDefault(); // Make a preset default if one we have none.
             }
             catch (Exception ex)
             {
@@ -741,10 +695,10 @@ namespace HandBrakeWPF.Services.Presets
             // The presets file loaded was OK, so process it.
             foreach (var item in container.PresetList)
             {
-                object deserialisedItem = JsonConvert.DeserializeObject<PresetCategory>(item.ToString());
+                object deserializedItem = JsonSerializer.Deserialize<HBPresetCategory>(item.ToString(), JsonSettings.Options);
 
                 // Handle Categorised Presets.
-                PresetCategory category = deserialisedItem as PresetCategory;
+                HBPresetCategory category = deserializedItem as HBPresetCategory;
                 if (category != null && category.Folder)
                 {
                     foreach (HBPreset hbpreset in category.ChildrenArray)
@@ -752,44 +706,29 @@ namespace HandBrakeWPF.Services.Presets
                         Preset preset = JsonPresetFactory.ImportPreset(hbpreset);
 
                         // Migration
-                        preset.Category = category.PresetName == "User Presets" ? UserPresetCatgoryName : category.PresetName;
+                        preset.Category = category.PresetName == "User Presets" ? UserPresetCategoryName : category.PresetName;
                         preset.IsBuildIn = hbpreset.Type == 0;
-
-                        // IF we are using Source Max, Set the Max Width / Height values.
-                        if (preset.PictureSettingsMode == PresetPictureSettingsMode.SourceMaximum)
-                        {
-                            preset.Task.MaxWidth = preset.Task.Height;
-                            preset.Task.MaxHeight = preset.Task.Width;
-                        }
+                        preset.IsPresetDisabled = this.IsPresetDisabled(preset);
 
                         this.Add(preset, true);
                     }
                 }
 
                 // Uncategorised Presets
-                deserialisedItem = JsonConvert.DeserializeObject<HBPreset>(item.ToString());
-                HBPreset hbPreset = deserialisedItem as HBPreset;
+                deserializedItem = JsonSerializer.Deserialize<HBPreset>(item.ToString(), JsonSettings.Options);
+                HBPreset hbPreset = deserializedItem as HBPreset;
                 if (hbPreset != null && !hbPreset.Folder)
                 {
                     Preset preset = JsonPresetFactory.ImportPreset(hbPreset);
-                    preset.Category = UserPresetCatgoryName;
-                    preset.IsBuildIn = hbPreset.Type == 1;
-
-                    // IF we are using Source Max, Set the Max Width / Height values.
-                    if (preset.PictureSettingsMode == PresetPictureSettingsMode.SourceMaximum)
-                    {
-                        preset.Task.MaxWidth = preset.Task.Height;
-                        preset.Task.MaxHeight = preset.Task.Width;
-                    }
+                    preset.Category = UserPresetCategoryName;
+                    preset.IsBuildIn = hbPreset.Type == 0;
+                    preset.IsPresetDisabled = this.IsPresetDisabled(preset);
 
                     this.Add(preset, true);
                 }
             }
         }
 
-        /// <summary>
-        /// Update the preset files
-        /// </summary>
         private void SavePresetFiles()
         {
             try
@@ -802,7 +741,7 @@ namespace HandBrakeWPF.Services.Presets
                 }
 
                 // Organise the Presets list into Json Equivalent objects.
-                Dictionary<string, PresetCategory> presetCategories = new Dictionary<string, PresetCategory>();
+                Dictionary<string, HBPresetCategory> presetCategories = new Dictionary<string, HBPresetCategory>();
                 List<HBPreset> uncategorisedPresets = new List<HBPreset>();
 
                 // Handle User Presets.
@@ -812,8 +751,6 @@ namespace HandBrakeWPF.Services.Presets
                 this.HandlePresetListsForSave(this.flatPresetList.Where(o => o.IsBuildIn).ToList(), presetCategories, uncategorisedPresets);
 
                 // Wrap the categories in a container. 
-                JsonSerializerSettings settings = new JsonSerializerSettings { MissingMemberHandling = MissingMemberHandling.Ignore };
-
                 PresetVersion presetVersion = HandBrakePresetService.GetCurrentPresetVersion();
                 PresetTransportContainer container = new PresetTransportContainer(presetVersion.Major, presetVersion.Minor, presetVersion.Micro) { PresetList = new List<object>() };
                 container.PresetList.AddRange(presetCategories.Values);
@@ -822,7 +759,7 @@ namespace HandBrakeWPF.Services.Presets
                 // Write the preset container out to file.
                 using (FileStream strm = new FileStream(this.presetFile, FileMode.Create, FileAccess.Write))
                 {
-                    string presetsJson = JsonConvert.SerializeObject(container, Formatting.Indented, settings);
+                    string presetsJson = JsonSerializer.Serialize(container, JsonSettings.Options);
                     using (StreamWriter writer = new StreamWriter(strm))
                     {
                         writer.WriteLine(presetsJson);
@@ -835,7 +772,14 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        private void HandlePresetListsForSave(List<Preset> processList, Dictionary<string, PresetCategory> presetCategories, List<HBPreset> uncategorisedPresets)
+        private void ClearPresetService()
+        {
+            this.flatPresetDict.Clear();
+            this.flatPresetList.Clear();
+            this.presets.Clear();
+        }
+
+        private void HandlePresetListsForSave(List<Preset> processList, Dictionary<string, HBPresetCategory> presetCategories, List<HBPreset> uncategorisedPresets)
         {
             foreach (Preset item in processList)
             {
@@ -852,8 +796,8 @@ namespace HandBrakeWPF.Services.Presets
                     }
                     else
                     {
-                        presetCategories[item.Category] = new PresetCategory
-                                                          {
+                        presetCategories[item.Category] = new HBPresetCategory
+                        {
                                                               ChildrenArray = new List<HBPreset> { preset },
                                                               Folder = true,
                                                               PresetName = item.Category,
@@ -864,19 +808,10 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
-        private Preset ConvertHbPreset(HBPreset hbPreset)
+        private Preset ConvertHbPreset(HBPreset hbPreset, string categoryName)
         {
-            Preset preset = null;
-
-            preset = JsonPresetFactory.ImportPreset(hbPreset);
-            preset.Category = UserPresetCatgoryName; // TODO can we get this from the preset?
-
-            // IF we are using Source Max, Set the Max Width / Height values.
-            if (preset.PictureSettingsMode == PresetPictureSettingsMode.SourceMaximum)
-            {
-                preset.Task.MaxWidth = preset.Task.Height;
-                preset.Task.MaxHeight = preset.Task.Width;
-            }
+            Preset preset = JsonPresetFactory.ImportPreset(hbPreset);
+            preset.Category = !string.IsNullOrEmpty(categoryName) ? categoryName : UserPresetCategoryName;
 
             return preset;
         }
@@ -909,9 +844,77 @@ namespace HandBrakeWPF.Services.Presets
             }
         }
 
+        private bool IsPresetDisabled(Preset preset)
+        {
+            bool isQsvEnabled = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableQuickSyncEncoding);
+            bool isNvencEnabled = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableNvencEncoder);
+            bool isVcnEnabled = this.userSettingService.GetUserSetting<bool>(UserSettingConstants.EnableVceEncoder);
+
+            if (preset.Task.VideoEncoder == VideoEncoder.QuickSync && (!HandBrakeHardwareEncoderHelper.IsQsvAvailable || !isQsvEnabled))
+            {
+                return true;
+            }
+
+            if (preset.Task.VideoEncoder == VideoEncoder.QuickSyncH265 && (!HandBrakeHardwareEncoderHelper.IsQsvAvailableH265 || !isQsvEnabled))
+            {
+                return true;
+            }
+
+            if (preset.Task.VideoEncoder == VideoEncoder.QuickSyncH26510b && (!HandBrakeHardwareEncoderHelper.IsQsvAvailableH265 || !isQsvEnabled))
+            {
+                return true;
+            }
+
+            if (preset.Task.VideoEncoder == VideoEncoder.VceH264 && (!HandBrakeHardwareEncoderHelper.IsVceH264Available || !isVcnEnabled))
+            {
+                return true;
+            }
+
+            if (preset.Task.VideoEncoder == VideoEncoder.VceH265 && (!HandBrakeHardwareEncoderHelper.IsVceH265Available || !isVcnEnabled))
+            {
+                return true;
+            }
+
+            if (preset.Task.VideoEncoder == VideoEncoder.NvencH264 && (!HandBrakeHardwareEncoderHelper.IsNVEncH264Available || !isNvencEnabled))
+            {
+                return true;
+            }
+
+            if (preset.Task.VideoEncoder == VideoEncoder.NvencH265 && (!HandBrakeHardwareEncoderHelper.IsNVEncH265Available || !isNvencEnabled))
+            {
+                return true;
+            }
+
+            if (preset.Task.VideoEncoder == VideoEncoder.MFH264 || preset.Task.VideoEncoder == VideoEncoder.MFH265)
+            {
+                if (RuntimeInformation.ProcessArchitecture != Architecture.Arm64)
+                {
+                    return true;
+                }
+            }
+
+            return false;
+        }
+
+        private void OnPresetCollectionChanged()
+        {
+            this.PresetCollectionChanged?.Invoke(this, EventArgs.Empty);
+        }
+
+        private void CheckAndSetDefault()
+        {
+            if (this.DefaultPreset == null)
+            {
+                Preset p = this.flatPresetList.FirstOrDefault();
+                p.IsDefault = true;
+
+                this.Save();
+            }
+        }
+
         protected void ServiceLogMessage(string message)
         {
-            this.log.LogMessage(string.Format("Preset Service: {0}{1}{0}", Environment.NewLine, message), LogMessageType.Application, LogLevel.Info);
+            this.log.LogMessage(string.Format("Preset Service: {0}{1}{0}", Environment.NewLine, message));
         }
     }
 }
\ No newline at end of file
