@@ -10,24 +10,25 @@
 namespace HandBrakeWPF.Services.Queue.Interfaces
 {
     using System;
+    using System.Collections.Generic;
     using System.Collections.ObjectModel;
-    using System.ComponentModel;
 
+
+    using HandBrakeWPF.EventArgs;
+    using HandBrakeWPF.Services.Encode.EventArgs;
     using HandBrakeWPF.Services.Queue.Model;
 
-    using IEncode = Encode.Interfaces.IEncode;
-
-    /// <summary>
-    /// The Queue Processor
-    /// </summary>
     public interface IQueueService
     {
-        #region Events
-
         /// <summary>
         /// Fires when the Queue has started
         /// </summary>
-        event QueueService.QueueProgressStatus JobProcessingStarted;
+        event EventHandler<QueueProgressEventArgs> JobProcessingStarted;
+
+        /// <summary>
+        /// Fires when the status of any running job changes on the queue. Including progress.
+        /// </summary>
+        event EventHandler QueueJobStatusChanged;
 
         /// <summary>
         /// Fires when a job is Added, Removed or Re-Ordered.
@@ -38,16 +39,14 @@ namespace HandBrakeWPF.Services.Queue.Interfaces
         /// <summary>
         /// Fires when the entire encode queue has completed.
         /// </summary>
-        event QueueService.QueueCompletedEventDelegate QueueCompleted;
+        event EventHandler<QueueCompletedEventArgs> QueueCompleted;
 
         /// <summary>
         /// Fires when a pause to the encode queue has been requested.
         /// </summary>
         event EventHandler QueuePaused;
 
-        #endregion
-
-        #region Properties
+        event EventHandler<EncodeCompletedEventArgs> EncodeCompleted;
 
         /// <summary>
         /// Gets the number of jobs in the queue
@@ -60,30 +59,24 @@ namespace HandBrakeWPF.Services.Queue.Interfaces
         int ErrorCount { get; }
 
         /// <summary>
-        /// Gets the IEncodeService instance.
+        /// Gets the number of completed jobs.
         /// </summary>
-        IEncode EncodeService { get; }
+        int CompletedCount { get; }
 
         /// <summary>
         /// Gets a value indicating whether IsProcessing.
         /// </summary>
         bool IsProcessing { get; }
 
-        /// <summary>
-        /// Gets or sets Last Processed Job.
-        /// This is set when the job is poped of the queue by GetNextJobForProcessing();
-        /// </summary>
-        QueueTask LastProcessedJob { get; set; }
+        bool IsEncoding { get; }
+
+        bool IsPaused { get; }
 
         /// <summary>
         /// Gets The current queue.
         /// </summary>
         ObservableCollection<QueueTask> Queue { get; }
 
-        #endregion
-
-        #region Public Methods
-
         /// <summary>
         /// Add a job to the Queue. 
         /// This method is Thread Safe.
@@ -155,6 +148,12 @@ namespace HandBrakeWPF.Services.Queue.Interfaces
         /// </summary>
         void ClearCompleted();
 
+        /// <summary>
+        /// Get the log file paths for jobs still on the queue. (Including completed) 
+        /// </summary>
+        /// <returns>List of filepaths</returns>
+        List<string> GetLogFilePaths();
+
         /// <summary>
         /// Get the first job on the queue for processing.
         /// This also removes the job from the Queue and sets the LastProcessedJob
@@ -165,20 +164,14 @@ namespace HandBrakeWPF.Services.Queue.Interfaces
         QueueTask GetNextJobForProcessing();
 
         /// <summary>
-        /// Moves an item down one position in the queue.
+        /// Moves items in the queue list
         /// </summary>
-        /// <param name="index">
-        /// The zero-based location of the job in the queue.
-        /// </param>
-        void MoveDown(int index);
+        void MoveToBottom(IList<QueueTask> moveItems);
 
         /// <summary>
-        /// Moves an item up one position in the queue.
+        /// Moves items in the queue list
         /// </summary>
-        /// <param name="index">
-        /// The zero-based location of the job in the queue.
-        /// </param>
-        void MoveUp(int index);
+        void MoveToTop(IList<QueueTask> moveItems);
 
         /// <summary>
         /// Remove a job from the Queue.
@@ -209,26 +202,38 @@ namespace HandBrakeWPF.Services.Queue.Interfaces
         /// Starts encoding the first job in the queue and continues encoding until all jobs
         /// have been encoded.
         /// </summary>
-        /// <param name="clearCompleted">
-        /// The clear Completed.
-        /// </param>
-        void Start(bool clearCompleted);
+        void Start();
 
         /// <summary>
         /// Stop the current encode and pause the queue.
         /// </summary>
-        void Stop();
+        /// <param name="stopExistingJobs">
+        /// Set to false to allow existing jobs to complete.
+        /// </param>
+        void Stop(bool stopExistingJobs);
 
         /// <summary>
         /// Pause the queue but allow the current encode to complete.
         /// </summary>
-        void Pause();
+        /// <param name="pauseJobs">
+        /// Also pause the active jobs
+        /// </param>
+        void Pause(bool pauseJobs);
 
         /// <summary>
-        /// Pause and Encode and the Queue.
+        /// Get the status of all running queue jobs.
         /// </summary>
-        void PauseEncode();
+        /// <returns>
+        /// A list of QueueProgressStatus items
+        /// </returns>
+        List<QueueProgressStatus> GetQueueProgressStatus();
 
-        #endregion
+        List<string> GetActiveJobDestinationDirectories();
+
+
+        /// <summary>
+        /// Queue up a breakpoint task type.
+        /// </summary>
+        void AddBreakPoint();
     }
 }
\ No newline at end of file
