@@ -9,18 +9,18 @@
 
 namespace HandBrakeWPF.Services.Queue.Model
 {
-    using System.Runtime.CompilerServices;
+    using System;
+    using System.Text.Json.Serialization;
 
     using Caliburn.Micro;
 
-    using HandBrake.Interop.Model;
+    using HandBrake.Interop.Interop.Interfaces.Model;
 
     using HandBrakeWPF.Services.Presets.Model;
+    using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.Utilities;
 
-    using Newtonsoft.Json;
-
-    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
+    using EncodeTask = Encode.Model.EncodeTask;
 
     public class QueueTask : PropertyChangedBase
     {
@@ -34,10 +34,20 @@ namespace HandBrakeWPF.Services.Queue.Model
             id = id + 1;
             this.Id = string.Format("{0}.{1}", GeneralUtilities.ProcessId, id);
             this.Statistics = new QueueStats();
+            this.JobProgress = new QueueProgressStatus();
         }
 
-        public QueueTask(EncodeTask task, HBConfiguration configuration, string scannedSourcePath, Preset currentPreset, bool isPresetModified)
+        public QueueTask(QueueTaskType type)
         {
+            this.TaskType = type;
+            id = id + 1;
+            this.Id = string.Format("{0}.{1}", GeneralUtilities.ProcessId, id);
+            this.NotifyOfPropertyChange(() => this.IsBreakpointTask);
+        }
+
+        public QueueTask(EncodeTask task, HBConfiguration configuration, string scannedSourcePath, Preset currentPreset, bool isPresetModified, Title selectedTitle)
+        {
+            this.SourceTitleInfo = selectedTitle;
             this.Task = task;
             this.Configuration = configuration;
             this.Status = QueueItemStatus.Waiting;
@@ -50,55 +60,68 @@ namespace HandBrakeWPF.Services.Queue.Model
                     this.presetKey = this.presetKey + " (Modified)";
                 }
             }
-
             id = id + 1;
             this.Id = string.Format("{0}.{1}", GeneralUtilities.ProcessId, id);
+            this.SelectedPresetKey = this.presetKey;
 
             this.Statistics = new QueueStats();
+            this.TaskId = Guid.NewGuid().ToString();
+            this.JobProgress = new QueueProgressStatus();
+            this.TaskType = QueueTaskType.EncodeTask;
         }
-
+        
         [JsonIgnore]
         public string Id { get; }
 
-        [JsonProperty]
+        public string TaskId { get; set; }
+
+        public QueueTaskType TaskType { get; set; }
+
+        /* Breakpoint Task */
+
+        public bool IsBreakpointTask => TaskType == QueueTaskType.Breakpoint;
+
+        /* Encode Task*/
+
         public string ScannedSourcePath { get; set; }
 
-        [JsonProperty]
+        [JsonIgnore]
+        public Guid? TaskToken { get; set; }
+
+        public Title SourceTitleInfo { get; }
+
         public QueueItemStatus Status
         {
-            get
-            {
-                return this.status;
-            }
+            get => this.status;
 
             set
             {
                 this.status = value;
                 this.NotifyOfPropertyChange(() => this.Status);
                 this.NotifyOfPropertyChange(() => this.ShowEncodeProgress);
+                this.NotifyOfPropertyChange(() => this.IsJobStatusVisible);
             }
         }
 
-        [JsonProperty]
         public EncodeTask Task { get; set; }
 
-        [JsonProperty]
         public HBConfiguration Configuration { get; set; }
 
-        [JsonProperty]
         public QueueStats Statistics { get; set; }
 
-        [JsonIgnore]
-        public string SelectedPresetKey
-        {
-            get
-            {
-                return this.presetKey;
-            }
-        }
+        public string SelectedPresetKey { get; set; }
 
         [JsonIgnore]
-        public bool ShowEncodeProgress => this.Status == QueueItemStatus.InProgress && SystemInfo.IsWindows10();
+        public QueueProgressStatus JobProgress { get; set; }
+
+        [JsonIgnore]
+        public bool IsJobStatusVisible => this.Status == QueueItemStatus.InProgress;
+        
+        [JsonIgnore]
+        public bool ShowEncodeProgress => this.Status == QueueItemStatus.InProgress;
+
+
+        /* Overrides */
 
         public override bool Equals(object obj)
         {
@@ -115,7 +138,7 @@ namespace HandBrakeWPF.Services.Queue.Model
 
         public override string ToString()
         {
-            return string.Format("Encode Task.  Title: {0}, Source: {1}, Destination: {2}", this.Task.Title, this.Task.Source, this.Task.Destination);
+            return string.Format("Encode Task.  Title: {0}, Source: {1}, Destination: {2}", this.Task?.Title, this.Task?.Source, this.Task?.Destination);
         }
 
         protected bool Equals(QueueTask other)
