@@ -14,7 +14,9 @@ namespace HandBrakeWPF.Services.Scan.Model
     using System.IO;
     using System.Linq;
 
-    using HandBrake.Interop.Interop.Model;
+    using HandBrake.Interop.Interop.Interfaces.Model.Picture;
+
+    using Size = HandBrakeWPF.Model.Picture.Size;
 
     /// <summary>
     /// An object that represents a single Title of a DVD
@@ -77,11 +79,6 @@ namespace HandBrakeWPF.Services.Scan.Model
         /// </summary>
         public Size Resolution { get; set; }
 
-        /// <summary>
-        /// Gets or sets the aspect ratio of this Title
-        /// </summary>
-        public decimal AspectRatio { get; set; }
-
         /// <summary>
         /// Gets or sets AngleCount.
         /// </summary>
@@ -127,6 +124,19 @@ namespace HandBrakeWPF.Services.Scan.Model
         /// </summary>
         public string SourceName { get; set; }
 
+        public string DisplaySourceName
+        {
+            get
+            {
+                if (!string.IsNullOrEmpty(this.SourceName))
+                {
+                    return Path.GetFileNameWithoutExtension(this.SourceName);
+                }
+
+                return null;
+            }
+        }
+
         public string SourceDisplayName
         {
             get
@@ -176,18 +186,18 @@ namespace HandBrakeWPF.Services.Scan.Model
         #endregion
 
         /// <summary>
-        /// Calcuate the Duration
+        /// Calculate the Duration
         /// </summary>
         /// <param name="startPoint">The Start Point (Chapters)</param>
         /// <param name="endPoint">The End Point (Chapters)</param>
         /// <returns>A Timespan</returns>
         public TimeSpan CalculateDuration(long startPoint, long endPoint)
         {
-            IEnumerable<Chapter> chapers =
+            IEnumerable<Chapter> chapters =
                 this.Chapters.Where(c => c.ChapterNumber >= startPoint && c.ChapterNumber <= endPoint);
 
             TimeSpan duration = TimeSpan.FromSeconds(0.0);
-            duration = chapers.Aggregate(duration, (current, chapter) => current + chapter.Duration);
+            duration = chapters.Aggregate(duration, (current, chapter) => current + chapter.Duration);
 
             return duration;
         }
