@@ -11,40 +11,42 @@ namespace HandBrakeWPF.Services
 {
     using System;
     using System.Collections.Generic;
-    using System.Collections.Specialized;
     using System.IO;
     using System.Linq;
+    using System.Text.Json;
 
-    using HandBrake.Interop.Model;
+    using HandBrake.Interop.Interop;
     using HandBrake.Interop.Utilities;
 
-    using HandBrakeWPF.Extensions;
+    using HandBrakeWPF.Model;
+    using HandBrakeWPF.Model.Video;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Logging.Interfaces;
     using HandBrakeWPF.Utilities;
 
-    using Newtonsoft.Json;
-    using Newtonsoft.Json.Linq;
-
     using GeneralApplicationException = Exceptions.GeneralApplicationException;
     using SettingChangedEventArgs = EventArgs.SettingChangedEventArgs;
+    using SystemInfo = Utilities.SystemInfo;
 
     /// <summary>
     /// The User Setting Service
     /// </summary>
     public class UserSettingService : IUserSettingService
     {
-        private readonly string settingsFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(VersionHelper.IsNightly()), "settings.json");
+        private readonly ILog logService;
+
+        private readonly string settingsFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(HandBrakeVersionHelper.IsNightly()), "settings.json");
         private readonly string releaseSettingsFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(false), "settings.json");
         private readonly string nightlySettingsFile = Path.Combine(DirectoryUtilities.GetUserStoragePath(true), "settings.json");
-        private readonly JsonSerializerSettings settings = new JsonSerializerSettings { NullValueHandling = NullValueHandling.Ignore };
         private Dictionary<string, object> userSettings;
 
         /// <summary>
         /// Initializes a new instance of the <see cref="UserSettingService"/> class.
         /// </summary>
-        public UserSettingService()
+        public UserSettingService(ILog logService)
         {
+            this.logService = logService;
             this.Load();
         }
 
@@ -84,35 +86,45 @@ namespace HandBrakeWPF.Services
         /// </returns>
         public T GetUserSetting<T>(string name)
         {
-            if (this.userSettings.ContainsKey(name))
+            try
             {
-                if (typeof(T) == typeof(int))
+                if (this.userSettings.ContainsKey(name))
                 {
-                    object storedValue = this.userSettings[name];
-                    object converted = storedValue?.ToString().ToInt();
-                    return (T)converted;
-                }
-
-                // Treat String Arrays as StringCollections.  TODO refactor upstream code to more traditional string arrays.
-                object settingValue = this.userSettings[name];
-                if (settingValue != null && settingValue.GetType() == typeof(JArray))
-                {
-                    string[] stringArr = ((JArray)settingValue).ToObject<string[]>();
-                    StringCollection stringCollection = new StringCollection();
-                    foreach (var item in stringArr)
+                    object settingValue = this.userSettings[name];
+                    if (settingValue is JsonElement)
                     {
-                        stringCollection.Add(item);
+                        T rawValue = JsonSerializer.Deserialize<T>(
+                            ((JsonElement)settingValue).GetRawText(),
+                            JsonSettings.Options);
+                        return rawValue;
                     }
 
-                    settingValue = stringCollection;
+                    T objectElement = (T)this.userSettings[name];
+                    return objectElement;
                 }
-
-                return (T)settingValue;
+            }
+            catch (Exception e)
+            {
+                this.logService.LogMessage("Unable to fetch user setting:  " + name + " - " + e);
+                return GetDefaultValue<T>(name);
             }
 
             return default(T);
         }
 
+        public void ResetSettingsToDefaults()
+        {
+            this.userSettings.Clear();
+
+            // Set Defaults
+            Dictionary<string, object> defaults = this.GetDefaults();
+            foreach (var item in defaults.Where(item => !this.userSettings.Keys.Contains(item.Key)))
+            {
+                this.userSettings.Add(item.Key, item.Value);
+                this.Save();
+            }
+        }
+
         /// <summary>
         /// The on setting changed.
         /// </summary>
@@ -143,14 +155,14 @@ namespace HandBrakeWPF.Services
 
                 using (StreamWriter file = new StreamWriter(new FileStream(this.settingsFile, FileMode.Create, FileAccess.Write)))
                 {
-                    string appSettings = JsonConvert.SerializeObject(this.userSettings, Formatting.Indented, this.settings);
+                    string appSettings = JsonSerializer.Serialize(this.userSettings, JsonSettings.Options);
                     file.Write(appSettings);
                 }
             }
             catch (Exception exc)
             {
                 throw new GeneralApplicationException(
-                    Resources.UserSettings_AnErrorOccured,
+                    Resources.UserSettings_AnErrorOccurred,
                     Resources.SettingService_SaveErrorReset,
                     exc);
             }
@@ -169,12 +181,12 @@ namespace HandBrakeWPF.Services
                     using (StreamReader reader = new StreamReader(this.settingsFile))
                     {
                         string appSettings = reader.ReadToEnd();
-                        Dictionary<string, object> deserialisedSettings = JsonConvert.DeserializeObject<Dictionary<string, object>>(appSettings);
+                        Dictionary<string, object> deserializedSettings = JsonSerializer.Deserialize<Dictionary<string, object>>(appSettings, JsonSettings.Options);
 
-                        this.userSettings = deserialisedSettings;
+                        this.userSettings = deserializedSettings;
                     }
                 }
-                else if (VersionHelper.IsNightly() && File.Exists(this.releaseSettingsFile))
+                else if (HandBrakeVersionHelper.IsNightly() && File.Exists(this.releaseSettingsFile))
                 {
                     // Port the release versions config to the nightly.
                     if (!Directory.Exists(DirectoryUtilities.GetUserStoragePath(true)))
@@ -187,8 +199,8 @@ namespace HandBrakeWPF.Services
                     using (StreamReader reader = new StreamReader(this.settingsFile))
                     {
                         string appSettings = reader.ReadToEnd();
-                        Dictionary<string, object> deserialisedSettings = JsonConvert.DeserializeObject<Dictionary<string, object>>(appSettings);
-                        this.userSettings = deserialisedSettings;
+                        Dictionary<string, object> deserializedSettings = JsonSerializer.Deserialize<Dictionary<string, object>>(appSettings, JsonSettings.Options);
+                        this.userSettings = deserializedSettings;
                     }
                 }
                 else
@@ -204,8 +216,7 @@ namespace HandBrakeWPF.Services
                     this.Save();
                 }
 
-                // Legacy Settings forced Reset.
-                this.userSettings[UserSettingConstants.ScalingMode] = VideoScaler.Lanczos;
+                this.ResetUnsupportedSettings();
             }
             catch (Exception exc)
             {
@@ -228,6 +239,29 @@ namespace HandBrakeWPF.Services
             }
         }
 
+        private void ResetUnsupportedSettings()
+        {
+            // Legacy Settings forced Reset.
+            this.userSettings[UserSettingConstants.ScalingMode] = VideoScaler.Lanczos;
+
+            if (SystemInfo.MaximumSimultaneousInstancesSupported < 2)
+            {
+                this.userSettings[UserSettingConstants.ProcessIsolationEnabled] = false;
+                this.userSettings[UserSettingConstants.SimultaneousEncodes] = 1;
+            }
+
+            // Handle change of language code zh to zh-CN
+            object language;
+            if (this.userSettings.TryGetValue(UserSettingConstants.UiLanguage, out language))
+            {
+                if (language is string and "zh")
+                {
+                    // Reset to use system language if we have the old zh stored in settings.
+                    this.userSettings[UserSettingConstants.UiLanguage] = InterfaceLanguageUtilities.UseSystemLanguage;
+                }
+            }
+        }
+        
         /// <summary>
         /// Load Default Settings
         /// </summary>
@@ -241,22 +275,24 @@ namespace HandBrakeWPF.Services
             defaults.Add(UserSettingConstants.Verbosity, 1);
 
             // General
-            defaults.Add(UserSettingConstants.UpdateStatus, true);
+            defaults.Add(UserSettingConstants.UpdateStatus, false);
             defaults.Add(UserSettingConstants.LastUpdateCheckDate, DateTime.Now.Date.AddDays(-30));
             defaults.Add(UserSettingConstants.DaysBetweenUpdateCheck, 1);
-            defaults.Add(UserSettingConstants.UseDarkTheme, false);
+            defaults.Add(UserSettingConstants.DarkThemeMode, DarkThemeMode.Light);
             defaults.Add(UserSettingConstants.ShowPreviewOnSummaryTab, true);
             defaults.Add(UserSettingConstants.MainWindowMinimize, false);
             defaults.Add(UserSettingConstants.ClearCompletedFromQueue, false);
             defaults.Add(UserSettingConstants.ShowStatusInTitleBar, false);
             defaults.Add(UserSettingConstants.ShowAddAllToQueue, false);
             defaults.Add(UserSettingConstants.ShowAddSelectionToQueue, false);
-            defaults.Add(UserSettingConstants.VLCPath, @"C:\Program Files\VideoLAN\vlc\vlc.exe");
-
+            defaults.Add(UserSettingConstants.MediaPlayerPath, @"C:\Program Files\VideoLAN\vlc\vlc.exe");
+            defaults.Add(UserSettingConstants.PresetMenuDisplayMode, 0);
+            defaults.Add(UserSettingConstants.RightToLeftUi, 0); 
+            
             // Output Files
             defaults.Add(UserSettingConstants.AutoNaming, true);
             defaults.Add(UserSettingConstants.AutoNamePath, string.Empty);
-            defaults.Add(UserSettingConstants.AutoNameFormat, "{source}-{title}");
+            defaults.Add(UserSettingConstants.AutoNameFormat, "{source}");
             defaults.Add(UserSettingConstants.AutonameFilePrePostString, "output_");
             defaults.Add(UserSettingConstants.AutoNameTitleCase, true);
             defaults.Add(UserSettingConstants.AutoNameRemoveUnderscore, true);
@@ -276,39 +312,65 @@ namespace HandBrakeWPF.Services
 
             // Video
             defaults.Add(UserSettingConstants.EnableQuickSyncEncoding, true);
-            defaults.Add(UserSettingConstants.EnableQuickSyncDecoding, false);
+            defaults.Add(UserSettingConstants.EnableQuickSyncDecoding, true);
             defaults.Add(UserSettingConstants.UseQSVDecodeForNonQSVEnc, false);
             defaults.Add(UserSettingConstants.EnableVceEncoder, true);
             defaults.Add(UserSettingConstants.EnableNvencEncoder, true);
-
+            defaults.Add(UserSettingConstants.EnableQuickSyncLowPower, true);
+            
             // Advanced
             defaults.Add(UserSettingConstants.PreventSleep, true);
+            defaults.Add(UserSettingConstants.PauseEncodingOnLowBattery, true);
+            defaults.Add(UserSettingConstants.LowBatteryLevel, 15);
+
             defaults.Add(UserSettingConstants.DisableLibDvdNav, false);
             defaults.Add(UserSettingConstants.PauseOnLowDiskspace, true);
             defaults.Add(UserSettingConstants.PauseQueueOnLowDiskspaceLevel, 2000000000L);
             defaults.Add(UserSettingConstants.PreviewScanCount, 10);
             defaults.Add(UserSettingConstants.MinScanDuration, 10);
-            defaults.Add(UserSettingConstants.ProcessPriorityInt, 3);
+            defaults.Add(UserSettingConstants.ProcessPriorityInt, 2);
             defaults.Add(UserSettingConstants.X264Step, 0.5);
             defaults.Add(UserSettingConstants.SaveLogToCopyDirectory, false);
             defaults.Add(UserSettingConstants.SaveLogWithVideo, false);
             defaults.Add(UserSettingConstants.ClearOldLogs, true);
 
             // Preview
-            defaults.Add(UserSettingConstants.PreviewRotationFlip, false);
             defaults.Add(UserSettingConstants.LastPreviewDuration, 30);
             defaults.Add(UserSettingConstants.DefaultPlayer, false);
 
             // Experimental
-            defaults.Add(UserSettingConstants.RemoteServiceEnabled, false);
-            defaults.Add(UserSettingConstants.RemoteServicePort, true);
+            defaults.Add(UserSettingConstants.ProcessIsolationEnabled, true);
+            defaults.Add(UserSettingConstants.ProcessIsolationPort, 8037);
+            defaults.Add(UserSettingConstants.SimultaneousEncodes, 1);
 
             // Misc
-            defaults.Add(UserSettingConstants.ShowPresetPanel, false);
             defaults.Add(UserSettingConstants.ScalingMode, 0);
             defaults.Add(UserSettingConstants.ForcePresetReset, 3);
+            defaults.Add(UserSettingConstants.PreviewShowPictureSettingsOverlay, false);
+            defaults.Add(UserSettingConstants.RunCounter, 0);
+            defaults.Add(UserSettingConstants.ForceSoftwareRendering, false);
 
             return defaults;
         }
+
+        private T GetDefaultValue<T>(string name)
+        {
+            try
+            {
+                // If the current setting is corrupt, return the default and log it.
+                Dictionary<string, object> defaults = this.GetDefaults();
+                if (defaults.ContainsKey(name))
+                {
+                    return (T)this.userSettings[name];
+                }
+            }
+            catch (Exception e)
+            {
+                this.logService.LogMessage("Unable to fetch default setting:  " + name + " - " + e);
+                return default(T);
+            }
+
+            return default(T);
+        }
     }
 }
\ No newline at end of file
