@@ -14,11 +14,10 @@ namespace HandBrakeWPF.Startup
 
     using Caliburn.Micro;
 
-    using HandBrake.Interop.Interop.Providers;
-    using HandBrake.Interop.Interop.Providers.Interfaces;
-
     using HandBrakeWPF.Services;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Logging;
+    using HandBrakeWPF.Services.Logging.Interfaces;
     using HandBrakeWPF.Services.Presets;
     using HandBrakeWPF.Services.Presets.Interfaces;
     using HandBrakeWPF.Services.Queue;
@@ -28,8 +27,8 @@ namespace HandBrakeWPF.Startup
     using HandBrakeWPF.ViewModels;
     using HandBrakeWPF.ViewModels.Interfaces;
 
-    using IEncode = HandBrakeWPF.Services.Encode.Interfaces.IEncode;
-    using LibEncode = HandBrakeWPF.Services.Encode.LibEncode;
+    using IEncode = Services.Encode.Interfaces.IEncode;
+    using LibEncode = Services.Encode.LibEncode;
 
     /// <summary>
     /// The Castle Bootstrapper
@@ -64,6 +63,7 @@ namespace HandBrakeWPF.Startup
             this.container.Singleton<IUserSettingService, UserSettingService>();
             this.container.Singleton<IPresetService, PresetService>();
             this.container.Singleton<IQueueService, QueueService>();
+            this.container.Singleton<Services.Logging.Interfaces.ILog, LogService>();
 
             // Commands
 
@@ -80,10 +80,11 @@ namespace HandBrakeWPF.Startup
             this.container.Singleton<ITitleSpecificViewModel, TitleSpecificViewModel>();
             this.container.Singleton<IQueueSelectionViewModel, QueueSelectionViewModel>();
             this.container.Singleton<ICountdownAlertViewModel, CountdownAlertViewModel>();
-            this.container.Singleton<IMiniViewModel, MiniViewModel>();
             this.container.Singleton<IStaticPreviewViewModel, StaticPreviewViewModel>();
             this.container.Singleton<ISystemService, SystemService>();
-            this.container.Singleton<IHbFunctionsProvider, HbFunctionsProvider>();
+            this.container.Singleton<ILogInstanceManager, LogInstanceManager>();
+            this.container.Singleton<IPortService, PortService>();
+            this.container.Singleton<INotificationService, NotificationService>();
             
             // Tab Components
             this.container.Singleton<IAudioViewModel, AudioViewModel>();
@@ -94,7 +95,8 @@ namespace HandBrakeWPF.Startup
             this.container.Singleton<IVideoViewModel, VideoViewModel>();
             this.container.Singleton<IMetaDataViewModel, MetaDataViewModel>();
             this.container.Singleton<ISummaryViewModel, SummaryViewModel>();
-
+            this.container.Singleton<IPresetManagerViewModel, PresetManagerViewModel>();
+            
             // Shell
             this.container.Singleton<IShellViewModel, ShellViewModel>();
             this.container.Singleton<INotifyIconService, NotifyIconService>();
