@@ -15,29 +15,16 @@ namespace HandBrakeWPF.Utilities
     using System.IO;
     using System.Linq;
     using System.Text;
-    using System.Windows.Forms;
 
-    using HandBrake.Interop.Utilities;
+    using HandBrake.Interop.Interop;
 
     /// <summary>
     /// A Set of Static Utilities
     /// </summary>
     public class GeneralUtilities
     {
-        #region Constants and Fields
-
-        /// <summary>
-        /// The Default Log Directory
-        /// </summary>
         private static readonly string LogDir = DirectoryUtilities.GetLogDirectory();
 
-        #endregion
-
-        #region Properties
-
-        /// <summary>
-        /// Gets the number of HandBrake instances running.
-        /// </summary>
         public static int ProcessId
         {
             get
@@ -46,10 +33,6 @@ namespace HandBrakeWPF.Utilities
             }
         }
 
-        #endregion
-
-        #region Public Methods
-
         /// <summary>
         /// Clear all the log files older than 30 Days
         /// </summary>
@@ -64,7 +47,7 @@ namespace HandBrakeWPF.Utilities
                 var info = new DirectoryInfo(LogDir);
                 FileInfo[] logFiles = info.GetFiles("*.txt");
 
-                // Delete old and excessivly large files (> ~50MB).
+                // Delete old and excessively large files (> ~50MB).
                 foreach (FileInfo file in logFiles)
                 {
                     try
@@ -107,17 +90,17 @@ namespace HandBrakeWPF.Utilities
                 gpuBuilder.Append("GPU Information is unavailable");
             }
 
-            logHeader.AppendLine(string.Format("HandBrake {0}", VersionHelper.GetVersion()));
+            logHeader.AppendLine(string.Format("HandBrake {0}", HandBrakeVersionHelper.GetVersion()));
             logHeader.AppendLine(string.Format("OS: {0}", Environment.OSVersion));
-            logHeader.AppendLine(string.Format("CPU: {0}", SystemInfo.GetCpuCount));
+            logHeader.AppendLine(string.Format("CPU: {0}", SystemInfo.GetCpu));
             logHeader.AppendLine(string.Format("Ram: {0} MB, ", SystemInfo.TotalPhysicalMemory));
             logHeader.AppendLine(string.Format("GPU Information:{0}{1}", Environment.NewLine, gpuBuilder.ToString().TrimEnd()));
-            logHeader.AppendLine(string.Format("Screen: {0}x{1}", SystemInfo.ScreenBounds.Bounds.Width, SystemInfo.ScreenBounds.Bounds.Height));
+            logHeader.AppendLine(string.Format("Screen: {0}", SystemInfo.ScreenBounds));
             logHeader.AppendLine(string.Format("Temp Dir: {0}", Path.GetTempPath()));
-            logHeader.AppendLine(string.Format("Install Dir: {0}", Application.StartupPath));
-            logHeader.AppendLine(string.Format("Data Dir: {0}\n", DirectoryUtilities.GetUserStoragePath(VersionHelper.IsNightly())));
+            logHeader.AppendLine(string.Format("Install Dir: {0}", AppDomain.CurrentDomain.BaseDirectory));
+            logHeader.AppendLine(string.Format("Data Dir: {0}\n", DirectoryUtilities.GetUserStoragePath(HandBrakeVersionHelper.IsNightly())));
 
-            logHeader.AppendLine("-------------------------------------------");
+            logHeader.Append("-------------------------------------------");
 
             return logHeader;
         }
@@ -150,7 +133,5 @@ namespace HandBrakeWPF.Utilities
             List<int> ids = Process.GetProcessesByName("HandBrake").Select(process => process.Id).ToList();
             return ids.Contains(id);
         }
-
-        #endregion
     }
 }
\ No newline at end of file
