@@ -9,8 +9,12 @@
 
 namespace HandBrakeWPF.ViewModels
 {
+    using System;
+
+    using HandBrake.Interop.Interop;
     using HandBrake.Interop.Utilities;
 
+    using HandBrakeWPF.Properties;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     /// <summary>
@@ -33,16 +37,21 @@ namespace HandBrakeWPF.ViewModels
         {
             get
             {
-                return string.Format("{0}", VersionHelper.GetVersion());
+                return string.Format("{0}", HandBrakeVersionHelper.GetVersion());
             }
         }
 
+        public string License
+        {
+            get => string.Format("{0}{1}{1}{2}", Resources.About_Copyright, Environment.NewLine, Resources.About_GPL);
+        }
+
         /// <summary>
         /// Close this window.
         /// </summary>
         public void Close()
         {
-            this.TryClose();
+            this.TryCloseAsync();
         }
     }
 }
