@@ -16,13 +16,15 @@ namespace HandBrakeWPF.ViewModels
     using System.Diagnostics;
     using System.IO;
     using System.Linq;
-    using System.Runtime.CompilerServices;
+    using System.Runtime.Versioning;
+    using System.Threading;
+    using System.Threading.Tasks;
     using System.Windows;
 
     using Caliburn.Micro;
 
     using HandBrakeWPF.EventArgs;
-    using HandBrakeWPF.Extensions;
+    using HandBrakeWPF.Exceptions;
     using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
@@ -33,44 +35,16 @@ namespace HandBrakeWPF.ViewModels
 
     using Microsoft.Win32;
 
-    using EncodeCompletedEventArgs = Services.Encode.EventArgs.EncodeCompletedEventArgs;
-    using EncodeProgressEventArgs = Services.Encode.EventArgs.EncodeProgressEventArgs;
-
-    /// <summary>
-    /// The Preview View Model
-    /// </summary>
     public class QueueViewModel : ViewModelBase, IQueueViewModel
     {
-        #region Constants and Fields
-
         private readonly IErrorService errorService;
         private readonly IUserSettingService userSettingService;
         private readonly IQueueService queueProcessor;
-        private string jobStatus;
         private string jobsPending;
         private WhenDone whenDoneAction;
         private QueueTask selectedTask;
         private bool isQueueRunning;
-        private double progressValue;
-        private bool intermediateProgress;
-        private bool showEncodeProgress;
 
-        #endregion
-
-        #region Constructors and Destructors
-
-        /// <summary>
-        /// Initializes a new instance of the <see cref="QueueViewModel"/> class.
-        /// </summary>
-        /// <param name="userSettingService">
-        /// The user Setting Service.
-        /// </param>
-        /// <param name="queueProcessor">
-        /// The Queue Processor Service 
-        /// </param>
-        /// <param name="errorService">
-        /// The Error Service 
-        /// </param>
         public QueueViewModel(IUserSettingService userSettingService, IQueueService queueProcessor, IErrorService errorService)
         {
             this.userSettingService = userSettingService;
@@ -78,65 +52,34 @@ namespace HandBrakeWPF.ViewModels
             this.errorService = errorService;
             this.Title = Resources.QueueViewModel_Queue;
             this.JobsPending = Resources.QueueViewModel_NoEncodesPending;
-            this.JobStatus = string.Empty;
             this.SelectedItems = new BindingList<QueueTask>();
+            this.SelectedItems.ListChanged += this.SelectedItems_ListChanged;
             this.DisplayName = "Queue";
             this.IsQueueRunning = false;
+            this.SelectedTabIndex = 0;
 
             this.WhenDoneAction = (WhenDone)this.userSettingService.GetUserSetting<int>(UserSettingConstants.WhenCompleteAction);
         }
 
-        #endregion
-
-        #region Properties
-
-        /// <summary>
-        /// Gets or sets a value indicating whether the Queue is paused or not..
-        /// </summary>
         public bool IsQueueRunning
         {
-            get
-            {
-                return this.isQueueRunning;
-            }
+            get => this.isQueueRunning;
 
             set
             {
-                if (value == this.isQueueRunning) return;
+                if (value == this.isQueueRunning)
+                {
+                    return;
+                }
+
                 this.isQueueRunning = value;
                 this.NotifyOfPropertyChange(() => this.IsQueueRunning);
             }
         }
 
-        /// <summary>
-        /// Gets or sets JobStatus.
-        /// </summary>
-        public string JobStatus
-        {
-            get
-            {
-                return this.jobStatus;
-            }
-
-            set
-            {
-                this.jobStatus = value;
-                this.NotifyOfPropertyChange(() => this.JobStatus);
-                this.NotifyOfPropertyChange(() => this.IsJobStatusVisible);
-            }
-        }
-
-        public bool IsJobStatusVisible => !string.IsNullOrEmpty(this.JobStatus)  && this.SelectedTask?.Status == QueueItemStatus.InProgress;
-
-        /// <summary>
-        /// Gets or sets JobsPending.
-        /// </summary>
         public string JobsPending
         {
-            get
-            {
-                return this.jobsPending;
-            }
+            get => this.jobsPending;
 
             set
             {
@@ -145,15 +88,9 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets WhenDoneAction.
-        /// </summary>
         public WhenDone WhenDoneAction
         {
-            get
-            {
-                return this.whenDoneAction;
-            }
+            get => this.whenDoneAction;
 
             set
             {
@@ -162,32 +99,21 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets the queue tasks.
-        /// </summary>
-        public ObservableCollection<QueueTask> QueueTasks
-        {
-            get
-            {
-                return this.queueProcessor.Queue;
-            }
-        }
+        public ObservableCollection<QueueTask> QueueTasks => this.queueProcessor.Queue;
 
-        /// <summary>
-        /// Gets or sets the selected items.
-        /// </summary>
-        public BindingList<QueueTask> SelectedItems { get; set; }
+        public BindingList<QueueTask> SelectedItems { get; }
 
         public QueueTask SelectedTask
         {
-            get
-            {
-                return this.selectedTask;
-            }
+            get => this.selectedTask;
 
             set
             {
-                if (Equals(value, this.selectedTask)) return;
+                if (Equals(value, this.selectedTask))
+                {
+                    return;
+                }
+
                 this.selectedTask = value;
                 this.NotifyOfPropertyChange(() => this.SelectedTask);
                 this.HandleLogData();
@@ -198,9 +124,14 @@ namespace HandBrakeWPF.ViewModels
                 this.NotifyOfPropertyChange(() => this.CanPerformActionOnSource);
                 this.NotifyOfPropertyChange(() => this.CanPlayFile);
                 this.NotifyOfPropertyChange(() => this.StatsVisible);
+                this.NotifyOfPropertyChange(() => this.JobInfoVisible);
             }
         }
 
+        public bool JobInfoVisible => SelectedItems.Count == 1 && this.SelectedTask != null && !this.SelectedTask.IsBreakpointTask;
+
+        public int SelectedTabIndex { get; set; }
+
         public string ActivityLog { get; private set; }
 
         public bool CanRetryJob => this.SelectedTask != null && this.SelectedTask.Status != QueueItemStatus.Waiting && this.SelectedTask.Status != QueueItemStatus.InProgress;
@@ -212,42 +143,9 @@ namespace HandBrakeWPF.ViewModels
         public bool CanPerformActionOnSource => this.SelectedTask != null;
 
         public bool CanPlayFile =>
-            this.SelectedTask != null && this.SelectedTask.Task.Destination != null && 
+            this.SelectedTask != null && this.SelectedTask.Task != null && this.SelectedTask.Task.Destination != null && 
             this.SelectedTask.Status == QueueItemStatus.Completed && File.Exists(this.SelectedTask.Task.Destination);
 
-        public double ProgressValue
-        {
-            get => this.progressValue;
-            set
-            {
-                if (value == this.progressValue) return;
-                this.progressValue = value;
-                this.NotifyOfPropertyChange(() => this.ProgressValue);
-            }
-        }
-
-        public bool IntermediateProgress
-        {
-            get => this.intermediateProgress;
-            set
-            {
-                if (value == this.intermediateProgress) return;
-                this.intermediateProgress = value;
-                this.NotifyOfPropertyChange(() => this.IntermediateProgress);
-            }
-        }
-
-        public bool ShowEncodeProgress
-        {
-            get => this.showEncodeProgress;
-            set
-            {
-                if (value == this.showEncodeProgress) return;
-                this.showEncodeProgress = value;
-                this.NotifyOfPropertyChange(() => this.ShowEncodeProgress);
-            }
-        }
-
         public bool StatsVisible
         {
             get
@@ -262,30 +160,11 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        #endregion
-
-        #region Public Methods
-
-        /// <summary>
-        /// Update the When Done Setting
-        /// </summary>
-        /// <param name="action">
-        /// The action.
-        /// </param>
         public void WhenDone(int action)
         {
             this.WhenDone(action, true);
         }
 
-        /// <summary>
-        /// Update the When Done Setting
-        /// </summary>
-        /// <param name="action">
-        /// The action.
-        /// </param>
-        /// <param name="saveChange">
-        /// Save the change to the setting. Use false when updating UI.
-        /// </param>
         public void WhenDone(int action, bool saveChange)
         {
             this.WhenDoneAction = (WhenDone)action;
@@ -299,87 +178,85 @@ namespace HandBrakeWPF.ViewModels
             ovm.UpdateSettings();
         }
 
-        /// <summary>
-        /// Clear the Queue
-        /// </summary>
         public void Clear()
         {
             MessageBoxResult result = this.errorService.ShowMessageBox(
-                Resources.QueueViewModel_ClearQueueConfrimation, Resources.Confirm, MessageBoxButton.YesNo, MessageBoxImage.Question);
+                Resources.QueueViewModel_ClearQueueConfirmation, Resources.Confirm, MessageBoxButton.YesNo, MessageBoxImage.Question);
             if (result == MessageBoxResult.Yes)
             {
                 this.queueProcessor.Clear();
             }
         }
 
-        /// <summary>
-        /// Clear Completed Items
-        /// </summary>
         public void ClearCompleted()
         {
             this.queueProcessor.ClearCompleted();
         }
 
-        /// <summary>
-        /// Close this window.
-        /// </summary>
         public void Close()
         {
-            this.TryClose();
+            this.TryCloseAsync();
         }
 
-        /// <summary>
-        /// Handle the On Window Load
-        /// </summary>
         public override void OnLoad()
         {
             // Setup the window to the correct state.
-            this.IsQueueRunning = this.queueProcessor.EncodeService.IsEncoding;
+            this.IsQueueRunning = this.queueProcessor.IsProcessing;
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
 
             base.OnLoad();
         }
 
-        /// <summary>
-        /// Can Pause the Queue.
-        /// Used by Caliburn Micro to enable/disable the context menu item.
-        /// </summary>
-        /// <returns>
-        /// True when we can pause the queue.
-        /// </returns>
         public bool CanPauseQueue()
         {
             return this.IsQueueRunning;
         }
 
-        /// <summary>
-        /// Pause the Queue
-        /// </summary>
         public void PauseQueue()
         {
-            this.queueProcessor.Pause();
+            this.queueProcessor.Pause(true);
 
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.IsQueueRunning = false;
-
-            this.errorService.ShowMessageBox(Resources.QueueViewModel_QueuePauseNotice, Resources.QueueViewModel_Queue,
-                MessageBoxButton.OK, MessageBoxImage.Information);
         }
 
-        /// <summary>
-        /// Pause the Queue
-        /// </summary>
-        /// <remarks>
-        /// Prevents evaluation of CanPauseQueue
-        /// </remarks>
         public void PauseQueueToolbar()
         {
             this.PauseQueue();
         }
 
-        /// <summary>
-        /// The remove selected jobs.
-        /// </summary>
+        public void StopQueue()
+        {
+            if (this.queueProcessor.IsEncoding)
+            {
+                MessageBoxResult result = this.errorService.ShowMessageBox(
+                    "There are currently jobs running. Would you like to complete the current jobs before stopping the queue?",
+                    "Confirm",
+                    MessageBoxButton.YesNoCancel,
+                    MessageBoxImage.Question);
+
+                if (result == MessageBoxResult.Yes)
+                {
+                    this.queueProcessor.Stop(false);
+                }
+                else if (result == MessageBoxResult.Cancel)
+                {
+                    return;
+                }
+                else
+                {
+                    this.queueProcessor.Stop(true);
+                }
+            }
+            else
+            {
+                this.queueProcessor.Stop(true);
+            }
+
+            this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
+            this.IsQueueRunning = false;
+        }
+
         public void RemoveSelectedJobs()
         {
             if (this.SelectedItems.Count == 0)
@@ -406,12 +283,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Remove a Job from the queue
-        /// </summary>
-        /// <param name="queueTask">
-        /// The Job to remove from the queue
-        /// </param>
         public void RemoveJob(object queueTask)
         {
             QueueTask task = queueTask as QueueTask;
@@ -434,7 +305,6 @@ namespace HandBrakeWPF.ViewModels
 
                 if (result == MessageBoxResult.Yes)
                 {
-                    this.queueProcessor.EncodeService.Stop();
                     this.queueProcessor.Remove(task);
                     removed = true;
                 }
@@ -451,12 +321,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Reset the job state to waiting.
-        /// </summary>
-        /// <param name="task">
-        /// The task.
-        /// </param>
         public void RetryJob(QueueTask task)
         {
             this.queueProcessor.RetryJob(task);
@@ -464,18 +328,27 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.CanRetryJob);
         }
 
-        /// <summary>
-        /// Start Encode
-        /// </summary>
         public void StartQueue()
         {
-            if (!this.QueueTasks.Any(a => a.Status == QueueItemStatus.Waiting || a.Status == QueueItemStatus.InProgress))
+            // Remove any old Stop Tasks.
+            if (this.QueueTasks.Any(t => t.TaskType == QueueTaskType.Breakpoint))
+            {
+                IEnumerable<QueueTask> stopTasks = this.QueueTasks.Where(t => t.TaskType == QueueTaskType.Breakpoint).ToList();
+                foreach (var item in stopTasks)
+                {
+                    this.QueueTasks.Remove(item);
+                }
+            }
+
+            // Check for Pending Jobs
+            if (!this.QueueTasks.Any(a => a.Status == QueueItemStatus.Waiting || a.Status == QueueItemStatus.InProgress || a.Status == QueueItemStatus.Paused))
             {
                 this.errorService.ShowMessageBox(
                     Resources.QueueViewModel_NoPendingJobs, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
                 return;
             }
-
+            
+            // Low disk space Check
             var firstOrDefault = this.QueueTasks.FirstOrDefault(s => s.Status == QueueItemStatus.Waiting);
             if (firstOrDefault != null && !DriveUtilities.HasMinimumDiskSpace(firstOrDefault.Task.Destination,
                     this.userSettingService.GetUserSetting<long>(UserSettingConstants.PauseQueueOnLowDiskspaceLevel)))
@@ -490,7 +363,7 @@ namespace HandBrakeWPF.ViewModels
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.IsQueueRunning = true;
 
-            this.queueProcessor.Start(userSettingService.GetUserSetting<bool>(UserSettingConstants.ClearCompletedFromQueue));
+            this.queueProcessor.Start();
         }
 
         public void ExportCli()
@@ -530,21 +403,22 @@ namespace HandBrakeWPF.ViewModels
             OpenFileDialog dialog = new OpenFileDialog { Filter = "Json (*.json)|*.json", CheckFileExists = true };
             if (dialog.ShowDialog() == true)
             {
-                this.queueProcessor.ImportJson(dialog.FileName);
+                try
+                {
+                    this.queueProcessor.ImportJson(dialog.FileName);
+                }
+                catch (Exception exc)
+                {
+                    this.errorService.ShowError(Resources.QueueViewModel_ImportFail, Resources.QueueViewModel_ImportFailSolution, exc);
+                }
             }
         }
 
-        /// <summary>
-        /// Edit this Job
-        /// </summary>
-        /// <param name="task">
-        /// The task.
-        /// </param>
         public void EditJob(QueueTask task)
         {
             MessageBoxResult result = this.errorService.ShowMessageBox(
-                Resources.QueueViewModel_EditConfrimation,
-                "Modify Job?",
+                Resources.QueueViewModel_EditConfirmation,
+                Resources.QueueViewModel_EditJob,
                 MessageBoxButton.YesNo,
                 MessageBoxImage.Question);
 
@@ -624,87 +498,62 @@ namespace HandBrakeWPF.ViewModels
         {
             if (this.SelectedTask != null && this.SelectedTask.Task != null && File.Exists(this.SelectedTask.Task.Destination))
             {
-                Process.Start(this.SelectedTask.Task.Destination);
+                try
+                {
+                    Process.Start(this.SelectedTask.Task.Destination);
+                }
+                catch (Win32Exception exc)
+                {
+                    throw new GeneralApplicationException(
+                        exc.Message,
+                        Resources.QueueViewModel_PlayFileErrorSolution, exc);
+                }
             }
         }
 
-        public void MoveUp()
+        public void MoveToTop()
         {
-            Dictionary<int, QueueTask> tasks = new Dictionary<int, QueueTask>();
-            foreach (var item in this.SelectedItems)
-            {
-                tasks.Add(this.QueueTasks.IndexOf(item), item);
-            }
-
-            foreach (var item in tasks.OrderBy(s => s.Key))
-            {
-                this.QueueTasks.MoveUp(item.Value);
-            }
+            this.queueProcessor.MoveToTop(this.SelectedItems);
         }
 
-        public void MoveDown()
+        public void MoveToBottom()
         {
-            Dictionary<int, QueueTask> tasks = new Dictionary<int, QueueTask>();
-            foreach (var item in this.SelectedItems)
-            {
-                tasks.Add(this.QueueTasks.IndexOf(item), item);
-            }
-
-            foreach (var item in tasks.OrderByDescending(s => s.Key))
-            {
-                this.QueueTasks.MoveDown(item.Value);
-            }
+            this.queueProcessor.MoveToBottom(this.SelectedItems);
         }
 
-        #endregion
-
-        #region Methods
-
         public void Activate()
         {
-           this.OnActivate();
+           this.OnActivateAsync(CancellationToken.None);
         }
 
         public void Deactivate()
         {
-           this.OnDeactivate(false);
+           this.OnDeactivateAsync(false, CancellationToken.None);
         }
 
-        /// <summary>
-        /// Override the OnActive to run the Screen Loading code in the view model base.
-        /// </summary>
-        protected override void OnActivate()
+        protected override Task OnActivateAsync(CancellationToken cancellationToken)
         {
             this.Load();
 
-            this.queueProcessor.QueueCompleted += this.queueProcessor_QueueCompleted;
+            this.queueProcessor.QueueCompleted += this.QueueProcessor_QueueCompleted;
             this.queueProcessor.QueueChanged += this.QueueManager_QueueChanged;
-            this.queueProcessor.EncodeService.EncodeStatusChanged += this.EncodeService_EncodeStatusChanged;
-            this.queueProcessor.EncodeService.EncodeCompleted += this.EncodeService_EncodeCompleted;
             this.queueProcessor.JobProcessingStarted += this.QueueProcessorJobProcessingStarted;
             this.queueProcessor.QueuePaused += this.QueueProcessor_QueuePaused;
 
+            this.IsQueueRunning = this.queueProcessor.IsProcessing;
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
-
-            base.OnActivate();
+            
+            return base.OnActivateAsync(cancellationToken);
         }
 
-        /// <summary>
-        /// Override the Deactivate
-        /// </summary>
-        /// <param name="close">
-        /// The close.
-        /// </param>
-        protected override void OnDeactivate(bool close)
+        protected override Task OnDeactivateAsync(bool close, CancellationToken cancellationToken)
         {
-            this.queueProcessor.QueueCompleted -= this.queueProcessor_QueueCompleted;
+            this.queueProcessor.QueueCompleted -= this.QueueProcessor_QueueCompleted;
             this.queueProcessor.QueueChanged -= this.QueueManager_QueueChanged;
-            this.queueProcessor.EncodeService.EncodeStatusChanged -= this.EncodeService_EncodeStatusChanged;
-            this.queueProcessor.EncodeService.EncodeCompleted -= this.EncodeService_EncodeCompleted;
             this.queueProcessor.JobProcessingStarted -= this.QueueProcessorJobProcessingStarted;
             this.queueProcessor.QueuePaused -= this.QueueProcessor_QueuePaused;
 
-            base.OnDeactivate(close);
+            return base.OnDeactivateAsync(close, cancellationToken);
         }
 
         private void OpenDirectory(string directory)
@@ -728,7 +577,7 @@ namespace HandBrakeWPF.ViewModels
                     directory = Path.GetDirectoryName(directory);
                     if (directory != null && Directory.Exists(directory))
                     {
-                        Process.Start(directory);
+                        Process.Start("explorer.exe", directory);
                     }
                 }
             }
@@ -738,9 +587,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Open the Log file directory
-        /// </summary>
         public void OpenLogDirectory()
         {
             string logDir = DirectoryUtilities.GetLogDirectory();
@@ -749,9 +595,6 @@ namespace HandBrakeWPF.ViewModels
             prc.Start();
         }
 
-        /// <summary>
-        /// Copy the log file to the system clipboard
-        /// </summary>
         public void CopyLog()
         {
             try
@@ -799,72 +642,11 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.ActivityLog);
         }
 
-        /// <summary>
-        /// Handle the Encode Status Changed Event.
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The EncodeProgressEventArgs.
-        /// </param>
-        private void EncodeService_EncodeStatusChanged(object sender, EncodeProgressEventArgs e)
+        private void SelectedItems_ListChanged(object sender, ListChangedEventArgs e)
         {
-            Execute.OnUIThread(() =>
-            {
-                this.IntermediateProgress = false;
-
-                string totalHrsLeft = e.EstimatedTimeLeft.Days >= 1 ? string.Format(@"{0:d\:hh\:mm\:ss}", e.EstimatedTimeLeft) : string.Format(@"{0:hh\:mm\:ss}", e.EstimatedTimeLeft);
-                string elapsedTimeHrs = e.ElapsedTime.Days >= 1 ? string.Format(@"{0:d\:hh\:mm\:ss}", e.ElapsedTime) : string.Format(@"{0:hh\:mm\:ss}", e.ElapsedTime);
-
-                if (e.IsSubtitleScan)
-                {
-                    this.JobStatus = string.Format(Resources.MainViewModel_EncodeStatusChanged_SubScan_StatusLabel,
-                        e.Task,
-                        e.TaskCount,
-                        e.PercentComplete,
-                        totalHrsLeft,
-                        elapsedTimeHrs,
-                        null);
-
-                    this.ProgressValue = e.PercentComplete;
-                }
-                else if (e.IsMuxing)
-                {
-                    this.JobStatus = Resources.MainView_Muxing;
-                    this.IntermediateProgress = true;
-                }
-                else if (e.IsSearching)
-                {
-                    this.JobStatus = string.Format(Resources.MainView_ProgressStatusWithTask, Resources.MainView_Searching, e.PercentComplete, e.EstimatedTimeLeft, null);
-                    this.ProgressValue = e.PercentComplete;
-                }
-                else
-                {
-                    this.JobStatus =
-                        string.Format(Resources.QueueViewModel_EncodeStatusChanged_StatusLabel,
-                            e.Task,
-                            e.TaskCount,
-                            e.PercentComplete,
-                            e.CurrentFrameRate,
-                            e.AverageFrameRate,
-                            totalHrsLeft,
-                            elapsedTimeHrs,
-                            null);
-                    this.ProgressValue = e.PercentComplete;
-                }
-            });
+            this.NotifyOfPropertyChange(() => this.JobInfoVisible);
         }
-
-        /// <summary>
-        /// Handle the Queue Changed Event.
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The e.
-        /// </param>
+        
         private void QueueManager_QueueChanged(object sender, EventArgs e)
         {
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
@@ -880,69 +662,35 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.CanPerformActionOnSource);
             this.NotifyOfPropertyChange(() => this.CanPlayFile);
             this.NotifyOfPropertyChange(() => this.StatsVisible);
+            this.NotifyOfPropertyChange(() => this.JobInfoVisible);
             this.HandleLogData();
+
+            if (this.SelectedTask == null)
+            {
+                this.SelectedTask = this.QueueTasks.FirstOrDefault();
+            }
         }
 
-        /// <summary>
-        /// Handle the Queue Completed Event
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The EventArgs.
-        /// </param>
-        private void queueProcessor_QueueCompleted(object sender, EventArgs e)
+        private void QueueProcessor_QueueCompleted(object sender, EventArgs e)
         {
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.IsQueueRunning = false;
             this.NotifyOfPropertyChange(() => this.SelectedTask);
             this.NotifyOfPropertyChange(() => this.StatsVisible);
             this.NotifyOfPropertyChange(() => this.CanRetryJob);
-
-            this.JobStatus = string.Empty;
+            this.NotifyOfPropertyChange(() => this.JobInfoVisible);
         }
 
-        /// <summary>
-        /// The encode service_ encode completed.
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The e.
-        /// </param>
-        private void EncodeService_EncodeCompleted(object sender, EncodeCompletedEventArgs e)
-        {
-            if (!this.queueProcessor.IsProcessing)
-            {
-                this.JobStatus = string.Empty;
-            }
-        }
-
-        /// <summary>
-        /// The queue processor job processing started.
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The QueueProgressEventArgs.
-        /// </param>
         private void QueueProcessorJobProcessingStarted(object sender, QueueProgressEventArgs e)
         {
-            this.JobStatus = Resources.QueueViewModel_QueueStarted;
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
-            this.IsQueueRunning = true;
+            this.IsQueueRunning = this.queueProcessor.IsProcessing;
         }
 
         private void QueueProcessor_QueuePaused(object sender, EventArgs e)
         {
-            this.JobStatus = Resources.QueueViewModel_QueuePaused;
             this.JobsPending = string.Format(Resources.QueueViewModel_JobsPending, this.queueProcessor.Count);
             this.IsQueueRunning = false;
         }
-
-        #endregion
     }
 }
\ No newline at end of file
