@@ -190,7 +190,7 @@ namespace HandBrakeWPF.ViewModels
         public bool CanClose()
         {
             IQueueService processor = IoC.Get<IQueueService>();
-            if (processor != null && processor.EncodeService.IsEncoding)
+            if (processor != null && processor.IsEncoding)
             {
                 MessageBoxResult result =
                     this.errorService.ShowMessageBox(
@@ -201,11 +201,12 @@ namespace HandBrakeWPF.ViewModels
 
                 if (result == MessageBoxResult.Yes)
                 {
-                    processor.Stop();
+                    processor.Stop(true);
                     this.MainViewModel?.Shutdown();
 
                     return true;
                 }
+
                 return false;
             }
 
