@@ -11,45 +11,50 @@ namespace HandBrakeWPF.ViewModels
 {
     using System;
     using System.Collections.Generic;
+    using System.ComponentModel;
     using System.Diagnostics;
     using System.Globalization;
     using System.IO;
-    using System.Linq;
     using System.Runtime.ExceptionServices;
     using System.Threading;
     using System.Windows;
     using System.Windows.Media.Imaging;
 
-    using HandBrake.Interop.Interop.Model.Encoding;
-    using HandBrake.Interop.Interop.Providers.Interfaces;
+    using Caliburn.Micro;
 
+    using HandBrake.Interop.Interop.Interfaces.Model.Picture;
+
+    using HandBrakeWPF.Exceptions;
     using HandBrakeWPF.Factories;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Encode.Model.Models;
     using HandBrakeWPF.Services.Interfaces;
+    using HandBrakeWPF.Services.Logging.Interfaces;
     using HandBrakeWPF.Services.Queue.Model;
     using HandBrakeWPF.Services.Scan.Interfaces;
     using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
-    using EncodeCompletedEventArgs = HandBrakeWPF.Services.Encode.EventArgs.EncodeCompletedEventArgs;
-    using EncodeProgressEventArgs = HandBrakeWPF.Services.Encode.EventArgs.EncodeProgressEventArgs;
-    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
-    using IEncode = HandBrakeWPF.Services.Encode.Interfaces.IEncode;
-    using LibEncode = HandBrakeWPF.Services.Encode.LibEncode;
-    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
-    using PointToPointMode = HandBrakeWPF.Services.Encode.Model.Models.PointToPointMode;
+    using EncodeCompletedEventArgs = Services.Encode.EventArgs.EncodeCompletedEventArgs;
+    using EncodeProgressEventArgs = Services.Encode.EventArgs.EncodeProgressEventArgs;
+    using EncodeTask = Services.Encode.Model.EncodeTask;
+    using IEncode = Services.Encode.Interfaces.IEncode;
+    using ILog = HandBrakeWPF.Services.Logging.Interfaces.ILog;
+    using LibEncode = Services.Encode.LibEncode;
+    using OutputFormat = Services.Encode.Model.Models.OutputFormat;
+    using PointToPointMode = Services.Encode.Model.Models.PointToPointMode;
 
-    /// <summary>
-    ///     The Static Preview View Model
-    /// </summary>
     public class StaticPreviewViewModel : ViewModelBase, IStaticPreviewViewModel
     {
         private readonly IScan scanService;
-        private readonly IEncode encodeService;
         private readonly IErrorService errorService;
+        private readonly ILog logService;
+        private readonly ILogInstanceManager logInstanceManager;
+        private readonly IPortService portService;
         private readonly IUserSettingService userSettingService;
+
+        private IEncode encodeService;
         private int height;
         private BitmapSource previewImage;
         private int selectedPreviewImage;
@@ -59,11 +64,9 @@ namespace HandBrakeWPF.ViewModels
         private double percentageValue;
         private bool isEncoding;
         private bool useSystemDefaultPlayer;
-        private bool previewRotateFlip;
+        private bool showPictureSettingControls;
 
-        #region Constructors and Destructors
-
-        public StaticPreviewViewModel(IScan scanService, IUserSettingService userSettingService, IErrorService errorService, IHbFunctionsProvider hbFunctionsProvider)
+        public StaticPreviewViewModel(IScan scanService, IUserSettingService userSettingService, IErrorService errorService, ILog logService, ILogInstanceManager logInstanceManager, IPortService portService)
         {
             this.scanService = scanService;
             this.selectedPreviewImage = 1;
@@ -73,7 +76,9 @@ namespace HandBrakeWPF.ViewModels
             // Live Preview
             this.userSettingService = userSettingService;
             this.errorService = errorService;
-            this.encodeService = new LibEncode(hbFunctionsProvider); // Preview needs a separate instance rather than the shared singleton. This could maybe do with being refactored at some point
+            this.logService = logService;
+            this.logInstanceManager = logInstanceManager;
+            this.portService = portService;
 
             this.Title = "Preview";
             this.Percentage = "0.00%";
@@ -82,18 +87,12 @@ namespace HandBrakeWPF.ViewModels
             this.CanPlay = true;
 
             this.useSystemDefaultPlayer = userSettingService.GetUserSetting<bool>(UserSettingConstants.DefaultPlayer);
+            this.showPictureSettingControls = userSettingService.GetUserSetting<bool>(UserSettingConstants.PreviewShowPictureSettingsOverlay);
             this.Duration = userSettingService.GetUserSetting<int>(UserSettingConstants.LastPreviewDuration);
-            this.previewRotateFlip = userSettingService.GetUserSetting<bool>(UserSettingConstants.PreviewRotationFlip);
-            this.NotifyOfPropertyChange(() => this.previewRotateFlip); // Don't want to trigger an Update, so setting the backing variable. 
         }
+        
+        public IPictureSettingsViewModel PictureSettingsViewModel { get; private set; }
 
-        #endregion
-
-        #region Public Properties
-
-        /// <summary>
-        ///     Gets or sets the height.
-        /// </summary>
         public int Height
         {
             get
@@ -111,9 +110,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        ///     Gets or sets the preview image.
-        /// </summary>
         public BitmapSource PreviewImage
         {
             get
@@ -132,9 +128,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        ///     Gets or sets the selected preview image.
-        /// </summary>
         public int SelectedPreviewImage
         {
             get
@@ -154,37 +147,10 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        public bool PreviewRotateFlip
-        {
-            get => this.previewRotateFlip;
-            set
-            {
-                if (value == this.previewRotateFlip)
-                {
-                    return;
-                }
-
-                this.previewRotateFlip = value;
-                this.NotifyOfPropertyChange(() => this.PreviewRotateFlip);
-
-                this.UpdatePreviewFrame();
-                this.userSettingService.SetUserSetting(UserSettingConstants.PreviewRotationFlip, value);
-            }
-        }
-
-        /// <summary>
-        ///     Gets or sets the task.
-        /// </summary>
         public EncodeTask Task { get; set; }
 
-        /// <summary>
-        /// Gets or sets the scanned source.
-        /// </summary>
-        public Source ScannedSource { get; set; } 
+        public Source ScannedSource { get; set; }
 
-        /// <summary>
-        ///     Gets the total previews.
-        /// </summary>
         public int TotalPreviews
         {
             get
@@ -193,9 +159,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        ///     Gets or sets the width.
-        /// </summary>
         public int Width
         {
             get
@@ -213,9 +176,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether preview not available.
-        /// </summary>
         public bool PreviewNotAvailable
         {
             get
@@ -233,13 +193,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        #endregion
-
-        #region LivePreviewProperties
-
-        /// <summary>
-        /// Gets AvailableDurations.
-        /// </summary>
         public IEnumerable<int> AvailableDurations
         {
             get
@@ -248,14 +201,8 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets Duration.
-        /// </summary>
         public int Duration { get; set; }
 
-        /// <summary>
-        /// Gets or sets Percentage.
-        /// </summary>
         public string Percentage
         {
             get
@@ -270,9 +217,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets PercentageValue.
-        /// </summary>
         public double PercentageValue
         {
             get
@@ -287,9 +231,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets StartPoints.
-        /// </summary>
         public IEnumerable<int> StartPoints
         {
             get
@@ -306,9 +247,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether UseSystemDefaultPlayer.
-        /// </summary>
         public bool UseSystemDefaultPlayer
         {
             get
@@ -323,15 +261,13 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether IsEncoding.
-        /// </summary>
         public bool IsEncoding
         {
             get
             {
                 return this.isEncoding;
             }
+
             set
             {
                 this.isEncoding = value;
@@ -341,28 +277,23 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// Gets or sets the Currently Playing / Encoding Filename.
-        /// </summary>
         public string CurrentlyPlaying { get; set; }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether can play.
-        /// </summary>
         public bool CanPlay { get; set; }
-        #endregion
 
-        #region Public Methods and Operators
+        public bool IsOpen { get; set; }
+
+        public bool ShowPictureSettingControls
+        {
+            get => this.showPictureSettingControls;
+            set
+            {
+                this.showPictureSettingControls = value;
+                this.NotifyOfPropertyChange(() => this.ShowPictureSettingControls);
+                this.userSettingService.SetUserSetting(UserSettingConstants.PreviewShowPictureSettingsOverlay, value);
+            }
+        }
 
-        /// <summary>
-        /// The update preview frame.
-        /// </summary>
-        /// <param name="task">
-        /// The task.
-        /// </param>
-        /// <param name="scannedSource">
-        /// The scanned Source.
-        /// </param>
         public void UpdatePreviewFrame(EncodeTask task, Source scannedSource)
         {
             this.Task = task;
@@ -372,11 +303,6 @@ namespace HandBrakeWPF.ViewModels
             this.ScannedSource = scannedSource;
         }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether is open.
-        /// </summary>
-        public bool IsOpen { get; set; }
-
         public void NextPreview()
         {
             int maxPreview = this.userSettingService.GetUserSetting<int>(UserSettingConstants.PreviewScanCount);
@@ -398,20 +324,10 @@ namespace HandBrakeWPF.ViewModels
             this.SelectedPreviewImage = this.SelectedPreviewImage - 1;
         }
 
-        /// <summary>
-        ///     The update preview frame.
-        /// </summary>
         [HandleProcessCorruptedStateExceptions]
         public void UpdatePreviewFrame()
         {
-            // Don't preview for small images.
-            if (this.Task.Anamorphic == Anamorphic.Loose && this.Task.Width < 32)
-            {
-                PreviewNotAvailable = true;
-                return;
-            }
-
-            if ((this.Task.Anamorphic == Anamorphic.None || this.Task.Anamorphic == Anamorphic.Custom) && (this.Task.Width < 32 || this.Task.Height < 32))
+            if (this.Task.Width < 32 || this.Task.Height < 32)
             {
                 PreviewNotAvailable = true;
                 return;
@@ -420,7 +336,7 @@ namespace HandBrakeWPF.ViewModels
             BitmapSource image = null;
             try
             {
-                image = this.scanService.GetPreview(this.Task, this.SelectedPreviewImage, HBConfigurationFactory.Create());
+                image = this.scanService.GetPreview(this.Task, this.SelectedPreviewImage);
             }
             catch (Exception exc)
             {
@@ -430,11 +346,6 @@ namespace HandBrakeWPF.ViewModels
 
             if (image != null)
             {
-                if (previewRotateFlip)
-                {
-                    image = BitmapHelpers.CreateTransformedBitmap(image, this.Task.Rotation, this.Task.FlipVideo);
-                }
-
                 PreviewNotAvailable = false;
                 this.Width = (int)Math.Ceiling(image.Width);
                 this.Height = (int)Math.Ceiling(image.Height);
@@ -442,12 +353,6 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
-        /// <summary>
-        /// The preview size changed.
-        /// </summary>
-        /// <param name="ea">
-        /// The ea.
-        /// </param>
         public int FixWidth(int width)
         {
             Rect workArea = SystemParameters.WorkArea;
@@ -470,49 +375,40 @@ namespace HandBrakeWPF.ViewModels
             return height;
         }
 
-        #endregion
-
-        #region Public Method - Live Preview 
-
-        #region Public Methods
-
-        /// <summary>
-        /// Close this window.
-        /// </summary>
         public void Close()
         {
             this.IsOpen = false;
         }
 
-        /// <summary>
-        /// Handle The Initialisation 
-        /// </summary>
+        public void SetPictureSettingsInstance(IPictureSettingsViewModel pictureSettingsViewModel)
+        {
+            this.PictureSettingsViewModel = pictureSettingsViewModel;
+        }
+
         public override void OnLoad()
         {
         }
 
-        /// <summary>
-        /// Encode and play a sample
-        /// </summary>
         public void Play()
         {
             try
             {
                 this.IsEncoding = true;
                 if (File.Exists(this.CurrentlyPlaying))
+                {
                     File.Delete(this.CurrentlyPlaying);
+                }
             }
             catch (Exception)
             {
                 this.IsEncoding = false;
-                this.errorService.ShowMessageBox(Resources.StaticPreview_UnableToDeletePreview, 
-                               Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
+                this.errorService.ShowMessageBox(Resources.StaticPreview_UnableToDeletePreview, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
+                return;
             }
 
             if (this.Task == null || string.IsNullOrEmpty(Task.Source))
             {
-                this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_ScanFirst, 
-                               Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
+                this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_ScanFirst, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
                 return;
             }
 
@@ -540,6 +436,7 @@ namespace HandBrakeWPF.ViewModels
                         formatExtension = "mkv";
                         break;
                 }
+
                 string filename = Path.ChangeExtension(Path.GetTempFileName(), formatExtension);
                 encodeTask.Destination = filename;
                 this.CurrentlyPlaying = filename;
@@ -563,7 +460,7 @@ namespace HandBrakeWPF.ViewModels
             SubtitleTrack scanTrack = null;
             foreach (var track in encodeTask.SubtitleTracks)
             {
-                if (track.SourceTrack != null && track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch)
+                if (track.SourceTrack != null && track.SourceTrack.IsFakeForeignAudioScanTrack)
                 {
                     scanTrack = track;
                     break;
@@ -575,17 +472,18 @@ namespace HandBrakeWPF.ViewModels
                 encodeTask.SubtitleTracks.Remove(scanTrack);
             }
 
-            QueueTask task = new QueueTask(encodeTask, HBConfigurationFactory.Create(), this.ScannedSource.ScanPath, null, false);
+            QueueTask task = new QueueTask(encodeTask, HBConfigurationFactory.Create(), this.ScannedSource.ScanPath, null, false, null);
             ThreadPool.QueueUserWorkItem(this.CreatePreview, task);
         }
 
-        #endregion
+        public void CancelEncode()
+        {
+            if (this.encodeService.IsEncoding)
+            {
+                this.encodeService.Stop();
+            }
+        }
 
-        #region Private Methods
-
-        /// <summary>
-        /// Play the Encoded file
-        /// </summary>
         private void PlayFile()
         {
             // Launch VLC and Play video.
@@ -593,71 +491,62 @@ namespace HandBrakeWPF.ViewModels
             {
                 if (File.Exists(this.CurrentlyPlaying))
                 {
+                    string mediaPlayerPath = userSettingService.GetUserSetting<string>(UserSettingConstants.MediaPlayerPath);
                     string args = "\"" + this.CurrentlyPlaying + "\"";
 
                     if (this.UseSystemDefaultPlayer)
                     {
-                        Process.Start(args);
+                        this.logService.LogMessage(string.Format("# VideoPreview: Using system media player. ({0})", args));
+
+                        try
+                        {
+                            Process.Start(args);
+                        }
+                        catch (Win32Exception exc)
+                        {
+                            Execute.OnUIThread(
+                                () => this.errorService.ShowError(
+                                    exc.Message,
+                                    Resources.QueueViewModel_PlayFileErrorSolution,
+                                    exc));
+                        }
                     }
                     else
                     {
-                        if (!File.Exists(userSettingService.GetUserSetting<string>(UserSettingConstants.VLCPath)))
+                        if (File.Exists(mediaPlayerPath))
                         {
-                            // Attempt to find VLC if it doesn't exist in the default set location.
-                            string vlcPath;
-
-                            if (IntPtr.Size == 8 || (!string.IsNullOrEmpty(Environment.GetEnvironmentVariable("PROCESSOR_ARCHITEW6432"))))
-                                vlcPath = Environment.GetEnvironmentVariable("ProgramFiles(x86)");
-                            else
-                                vlcPath = Environment.GetEnvironmentVariable("ProgramFiles");
-
-                            if (!string.IsNullOrEmpty(vlcPath))
-                            {
-                                vlcPath = Path.Combine(vlcPath, "VideoLAN\\VLC\\vlc.exe");
-                            }
-
-                            if (File.Exists(vlcPath))
-                            {
-                                userSettingService.SetUserSetting(UserSettingConstants.VLCPath, vlcPath);
-                            }
-                            else
-                            {
-                                this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_UnableToFindVLC, 
-                                                                 Resources.Error, MessageBoxButton.OK, MessageBoxImage.Warning);
-                            }
+                            this.logService.LogMessage(string.Format("# Video Preview: Playing file using defined media player. ({0})", args));
+                            this.logService.LogMessage(string.Format("# Video Preview: Media Player Path: {0}", mediaPlayerPath));
+                            ProcessStartInfo process = new ProcessStartInfo(mediaPlayerPath, args);
+                            Process.Start(process);
+                            return;
                         }
-
-                        if (File.Exists(userSettingService.GetUserSetting<string>(UserSettingConstants.VLCPath)))
+                        else
                         {
-                            ProcessStartInfo vlc = new ProcessStartInfo(userSettingService.GetUserSetting<string>(UserSettingConstants.VLCPath), args);
-                            Process.Start(vlc);
+                            // Fallback to the System Default
+                            this.logService.LogMessage(string.Format("# Video Preview: Falling back to system media player. ({0})", args));
+                            Process.Start(args);
                         }
                     }
                 }
                 else
                 {
-                    this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_UnableToPlayFile, 
-                                 Resources.Error, MessageBoxButton.OK, MessageBoxImage.Warning);
+                    this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_UnableToPlayFile, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Warning);
                 }
             }
         }
 
-        /// <summary>
-        /// Create the Preview.
-        /// </summary>
-        /// <param name="state">
-        /// The state.
-        /// </param>
         private void CreatePreview(object state)
         {
             // Make sure we are not already encoding and if we are then display an error.
-            if (encodeService.IsEncoding)
+            if (this.encodeService != null && encodeService.IsEncoding)
             {
-                this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_AlreadyEncoding, 
-                               Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
+                this.errorService.ShowMessageBox(Resources.StaticPreviewViewModel_AlreadyEncoding, Resources.Error, MessageBoxButton.OK, MessageBoxImage.Error);
                 return;
             }
 
+            this.encodeService = new LibEncode(userSettingService, logInstanceManager, 0, portService); // Preview needs a separate instance rather than the shared singleton. This could maybe do with being refactored at some point
+
             this.encodeService.EncodeCompleted += this.encodeService_EncodeCompleted;
             this.encodeService.EncodeStatusChanged += this.encodeService_EncodeStatusChanged;
 
@@ -665,34 +554,12 @@ namespace HandBrakeWPF.ViewModels
             this.userSettingService.SetUserSetting(UserSettingConstants.LastPreviewDuration, this.Duration);
         }
 
-        #endregion
-
-        #region Event Handlers
-
-        /// <summary>
-        /// Handle Encode Progress Events
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The EncodeProgressEventArgs.
-        /// </param>
         private void encodeService_EncodeStatusChanged(object sender, EncodeProgressEventArgs e)
         {
             this.Percentage = string.Format("{0} %", Math.Round(e.PercentComplete, 2).ToString(CultureInfo.InvariantCulture));
             this.PercentageValue = e.PercentComplete;
         }
 
-        /// <summary>
-        /// Handle the Encode Completed Event
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The EncodeCompletedEventArgs.
-        /// </param>
         private void encodeService_EncodeCompleted(object sender, EncodeCompletedEventArgs e)
         {
             this.Percentage = "0.00%";
@@ -702,9 +569,10 @@ namespace HandBrakeWPF.ViewModels
             this.encodeService.EncodeCompleted -= this.encodeService_EncodeCompleted;
             this.encodeService.EncodeStatusChanged -= this.encodeService_EncodeStatusChanged;
 
-            this.PlayFile();
+            if (e.ErrorInformation != "1")
+            {
+                this.PlayFile();
+            }
         }
-        #endregion
-        #endregion
     }
 }
\ No newline at end of file
