@@ -13,7 +13,6 @@ namespace HandBrakeWPF.ViewModels
     using System.Collections.Generic;
     using System.IO;
     using System.Linq;
-    using System.Runtime.CompilerServices;
     using System.Windows;
 
     using Caliburn.Micro;
@@ -27,14 +26,13 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.Services.Presets.Model;
     using HandBrakeWPF.Services.Scan.Model;
     using HandBrakeWPF.ViewModels.Interfaces;
-    using HandBrakeWPF.Views;
 
     using Microsoft.Win32;
 
-    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
-    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
-    using SubtitleTrack = HandBrakeWPF.Services.Encode.Model.Models.SubtitleTrack;
-    using SubtitleType = HandBrakeWPF.Services.Encode.Model.Models.SubtitleType;
+    using EncodeTask = Services.Encode.Model.EncodeTask;
+    using OutputFormat = Services.Encode.Model.Models.OutputFormat;
+    using SubtitleTrack = Services.Encode.Model.Models.SubtitleTrack;
+    using SubtitleType = Services.Encode.Model.Models.SubtitleType;
 
     /// <summary>
     /// The Subtitles View Model
@@ -42,7 +40,6 @@ namespace HandBrakeWPF.ViewModels
     public class SubtitlesViewModel : ViewModelBase, ISubtitlesViewModel
     {
         private readonly IErrorService errorService;
-        private readonly IWindowManager windowManager;
 
         #region Constants and Fields
 
@@ -65,14 +62,14 @@ namespace HandBrakeWPF.ViewModels
         public SubtitlesViewModel(IErrorService errorService, IWindowManager windowManager)
         {
             this.errorService = errorService;
-            this.windowManager = windowManager;
-            this.SubtitleDefaultsViewModel = new SubtitlesDefaultsViewModel();
+            this.SubtitleBehaviours = new SubtitleBehaviours();
+            this.SubtitleDefaultsViewModel = new SubtitlesDefaultsViewModel(windowManager);
             this.Task = new EncodeTask();
 
-            this.Langauges = LanguageUtilities.MapLanguages().Keys;
+            this.Languages = LanguageUtilities.MapLanguages().Keys;
             this.CharacterCodes = CharCodesUtilities.GetCharacterCodes();
 
-            this.foreignAudioSearchTrack = new Subtitle { SubtitleType = SubtitleType.ForeignAudioSearch, Language = Resources.SubtitleViewModel_ForeignAudioSearch };
+            this.foreignAudioSearchTrack = new Subtitle { IsFakeForeignAudioScanTrack = true, Language = Resources.SubtitleViewModel_ForeignAudioSearch };
             this.SourceTracks = new List<Subtitle> { this.foreignAudioSearchTrack };
         }
 
@@ -93,9 +90,9 @@ namespace HandBrakeWPF.ViewModels
         public IEnumerable<string> CharacterCodes { get; set; }
 
         /// <summary>
-        /// Gets or sets Langauges.
+        /// Gets or sets Languages.
         /// </summary>
-        public IEnumerable<string> Langauges { get; set; }
+        public IEnumerable<string> Languages { get; set; }
 
         /// <summary>
         /// Gets or sets SourceTracks.
@@ -119,38 +116,10 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public EncodeTask Task { get; set; }
 
-        /// <summary>
-        /// Gets the panel title.
-        /// </summary>
-        public string PanelTitle
-        {
-            get
-            {
-                return Resources.SubtitlesViewModel_SubTracks;
-            }
-        }
-
-        /// <summary>
-        /// Gets the switch display title.
-        /// </summary>
-        public string SwitchDisplayTitle
-        {
-            get
-            {
-                return Resources.SubtitlesViewModel_ConfigureDefaults;
-            }
-        }
-
         /// <summary>
         /// Gets the default audio behaviours. 
         /// </summary>
-        public SubtitleBehaviours SubtitleBehaviours
-        {
-            get
-            {
-                return this.SubtitleDefaultsViewModel.SubtitleBehaviours;
-            }
-        }
+        public SubtitleBehaviours SubtitleBehaviours { get; private set; }
 
         public bool IsBurnableOnly
         {
@@ -177,7 +146,7 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void AddAllClosedCaptions()
         {
-            foreach (Subtitle subtitle in this.SourceTitlesSubset(null).Where(s => s.SubtitleType == SubtitleType.CC))
+            foreach (Subtitle subtitle in this.SourceTitlesSubset(null).Where(s => s.SubtitleType == SubtitleType.CC608 || s.SubtitleType == SubtitleType.CC708))
             {
                 this.Add(subtitle);
             }
@@ -212,7 +181,7 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void AddFirstForSelectedLanguages()
         {
-            bool anyLanguageSelected = this.SubtitleBehaviours.SelectedLangauges.Contains(Constants.Any);
+            bool anyLanguageSelected = this.SubtitleBehaviours.SelectedLanguages.Contains(Constants.Any);
             foreach (Subtitle sourceTrack in this.GetSelectedLanguagesTracks())
             {
                 // Step 2: Check if the track list already contains this track
@@ -362,7 +331,7 @@ namespace HandBrakeWPF.ViewModels
                 case SubtitleBehaviourModes.FirstMatch: // Adding all remaining tracks
                     this.AddFirstForSelectedLanguages();
                     break;
-                case SubtitleBehaviourModes.AllMatching: // Add Langauges tracks for the additional languages selected, in-order.
+                case SubtitleBehaviourModes.AllMatching: // Add Languages tracks for the additional languages selected, in-order.
                     this.AddAllRemainingForSelectedLanguages();
                     break;
             }
@@ -376,7 +345,7 @@ namespace HandBrakeWPF.ViewModels
                     case SubtitleBurnInBehaviourModes.None:
                         foreach (var track in this.Task.SubtitleTracks)
                         {
-                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch)
+                            if (track.SourceTrack.IsFakeForeignAudioScanTrack)
                             {
                                 track.Forced = true;
                                 break;
@@ -388,7 +357,7 @@ namespace HandBrakeWPF.ViewModels
                         foreach (var track in this.Task.SubtitleTracks)
                         {
                             // Set the Foreign Audio Track to burned-in
-                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch)
+                            if (track.SourceTrack.IsFakeForeignAudioScanTrack)
                             {
                                 track.Burned = true;
                                 track.Forced = true;
@@ -402,7 +371,7 @@ namespace HandBrakeWPF.ViewModels
                         foreach (var track in this.Task.SubtitleTracks)
                         {
                             // Foreign Audio Search is always first in the list.
-                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch) 
+                            if (track.SourceTrack.IsFakeForeignAudioScanTrack) 
                             {
                                 track.Forced = true;
                                 continue;
@@ -429,7 +398,7 @@ namespace HandBrakeWPF.ViewModels
                             }
 
                             // But if there is a foreign audio track, prefer this to the first.
-                            if (track.SourceTrack.SubtitleType == SubtitleType.ForeignAudioSearch)
+                            if (track.SourceTrack.IsFakeForeignAudioScanTrack)
                             {
                                 track.Burned = true;
                                 track.Forced = true;
@@ -454,11 +423,10 @@ namespace HandBrakeWPF.ViewModels
         /// </summary>
         public void ShowSubtitleDefaultsPanel()
         {
-            SubtitlesDefaultsView view = new SubtitlesDefaultsView();
-            view.DataContext = this.SubtitleDefaultsViewModel;
-
-            if (view.ShowDialog() == true)
+            this.SubtitleDefaultsViewModel.SetupPreset(this.SubtitleBehaviours);
+            if (this.SubtitleDefaultsViewModel.ShowWindow())
             {
+                this.SubtitleBehaviours = new SubtitleBehaviours(this.SubtitleDefaultsViewModel.SubtitleBehaviours);
                 this.OnTabStatusChanged(null);
             }
         }
@@ -510,7 +478,9 @@ namespace HandBrakeWPF.ViewModels
             this.Task = task;
             this.NotifyOfPropertyChange(() => this.Task);
 
-            this.SubtitleDefaultsViewModel.SetupLanguages(preset);
+            this.SubtitleBehaviours = new SubtitleBehaviours(preset.SubtitleTrackBehaviours);
+
+            this.SubtitleDefaultsViewModel.SetupPreset(preset);
             this.AutomaticSubtitleSelection();
         }
 
@@ -550,9 +520,9 @@ namespace HandBrakeWPF.ViewModels
                 return false;
             }
 
-            foreach (var item in this.SubtitleBehaviours.SelectedLangauges)
+            foreach (var item in this.SubtitleBehaviours.SelectedLanguages)
             {
-                if (!preset.SubtitleTrackBehaviours.SelectedLangauges.Contains(item))
+                if (!preset.SubtitleTrackBehaviours.SelectedLanguages.Contains(item))
                 {
                     return false;
                 }
@@ -640,7 +610,7 @@ namespace HandBrakeWPF.ViewModels
         /// <summary>
         /// Add a subtitle track.
         /// The Source track is set based on the following order. If null, it will skip to the next option.
-        ///   1. Passed in Subitle param
+        ///   1. Passed in Subtitle param
         ///   2. First preferred Subtitle from source
         ///   3. First subtitle from source.
         /// Will not add a subtitle if the source has none.
@@ -654,14 +624,20 @@ namespace HandBrakeWPF.ViewModels
                               ?? ((this.SourceTracks != null)
                                       ? (this.SourceTracks.FirstOrDefault(l => l.Language == this.GetPreferredSubtitleTrackLanguage())
                                          ?? this.SourceTracks.FirstOrDefault(
-                                             s => s.SubtitleType != SubtitleType.ForeignAudioSearch))
+                                             s => !s.IsFakeForeignAudioScanTrack))
                                       : null);
 
             if (source == null)
             {
                 source = foreignAudioSearchTrack;
+
+                if (this.Task.SubtitleTracks.Any(s => s.SourceTrack.Equals(this.foreignAudioSearchTrack)))
+                {
+                    return; // Don't add more than one Foreign Audio Scan
+                }
             }
 
+
             SubtitleTrack track = new SubtitleTrack
                                       {
                                           SubtitleType = source.SubtitleType,
@@ -672,10 +648,18 @@ namespace HandBrakeWPF.ViewModels
             if (this.SubtitleBehaviours.SelectedBurnInBehaviour == SubtitleBurnInBehaviourModes.ForeignAudio
                   || this.SubtitleBehaviours.SelectedBurnInBehaviour == SubtitleBurnInBehaviourModes.ForeignAudioPreferred)
             {
-                if (subtitle != null && subtitle.SubtitleType == SubtitleType.ForeignAudioSearch)
+                if (subtitle != null && subtitle.IsFakeForeignAudioScanTrack)
                 {
-                    track.Burned = true;
-                    this.SetBurnedToFalseForAllExcept(track);
+                    // Only set burned if it's an an available option.
+                    if (this.Task.OutputFormat == OutputFormat.Mp4 && this.Task.SubtitleTracks.Any(s => s.Burned))
+                    {
+                        track.Burned = false;
+                    }
+                    else
+                    {
+                        track.Burned = true;
+                        this.SetBurnedToFalseForAllExcept(track);
+                    }
                 }
             }
 
@@ -710,10 +694,16 @@ namespace HandBrakeWPF.ViewModels
         private List<Subtitle> GetSelectedLanguagesTracks()
         {
             // Translate to Iso Codes
-            List<string> iso6392Codes = this.SubtitleBehaviours.SelectedLangauges.Contains(Constants.Any)
-                ? LanguageUtilities.GetIsoCodes()
-                : LanguageUtilities.GetLanguageCodes(
-                    this.SubtitleBehaviours.SelectedLangauges.ToArray());
+            List<string> iso6392Codes = new List<string>();
+            if (this.SubtitleBehaviours.SelectedLanguages.Contains(Constants.Any))
+            {
+                iso6392Codes = LanguageUtilities.GetIsoCodes();
+                iso6392Codes = LanguageUtilities.OrderIsoCodes(iso6392Codes, this.SubtitleBehaviours.SelectedLanguages);
+            }
+            else
+            {
+                iso6392Codes = LanguageUtilities.GetLanguageCodes(this.SubtitleBehaviours.SelectedLanguages.ToArray());
+            }
 
 
             List<Subtitle> orderedSubtitles = new List<Subtitle>();
@@ -733,7 +723,7 @@ namespace HandBrakeWPF.ViewModels
         /// </returns>
         private string GetPreferredSubtitleTrackLanguage()
         {
-            string langName = this.SubtitleBehaviours.SelectedLangauges.FirstOrDefault(w => w != Constants.Any);
+            string langName = this.SubtitleBehaviours.SelectedLanguages.FirstOrDefault(w => w != Constants.Any);
             string langCode = LanguageUtilities.GetLanguageCode(langName);
             return langCode;
         }
@@ -769,7 +759,7 @@ namespace HandBrakeWPF.ViewModels
                                               SrtOffset = 0,
                                               SrtCharCode = "UTF-8",
                                               SrtLang = "English",
-                                              SubtitleType = SubtitleType.SRT,
+                                              SubtitleType = SubtitleType.IMPORTSRT,
                                               SrtPath = srtFile
                                           };
                 this.Task.SubtitleTracks.Add(track);
