@@ -19,11 +19,13 @@ namespace HandBrakeWPF.ViewModels
     using System.Windows.Media.Imaging;
 
     using HandBrake.Interop.Interop;
-    using HandBrake.Interop.Interop.Model.Encoding;
+    using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
+    using HandBrake.Interop.Interop.Interfaces.Model.Picture;
 
     using HandBrakeWPF.EventArgs;
     using HandBrakeWPF.Factories;
     using HandBrakeWPF.Helpers;
+    using HandBrakeWPF.Model.Filters;
     using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Encode.Model;
@@ -36,6 +38,8 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.ViewModelItems.Filters;
     using HandBrakeWPF.ViewModels.Interfaces;
 
+    using VideoEncoder = HandBrakeWPF.Model.Video.VideoEncoder;
+
     public class SummaryViewModel : ViewModelBase, ISummaryViewModel
     {
         private readonly IScan scanService;
@@ -52,6 +56,8 @@ namespace HandBrakeWPF.ViewModels
 
         private bool showPreview;
 
+        private DelayedActionProcessor previewDelayProcessor = new DelayedActionProcessor();
+
         public SummaryViewModel(IScan scanService, IUserSettingService userSettingService)
         {
             this.scanService = scanService;
@@ -230,7 +236,7 @@ namespace HandBrakeWPF.ViewModels
                     this.NotifyOfPropertyChange(() => this.IsMkvOrWebm);
                     this.NotifyOfPropertyChange(() => this.IsIpodAtomVisible);
                     this.SetExtension(string.Format(".{0}", this.Task.OutputFormat.ToString().ToLower()));
-                    this.UpdateDisplayedInfo(); // output format may coreced to another due to container incompatibility
+                    this.UpdateDisplayedInfo(); // output format may be coerced to another due to container incompatibility
 
                     this.OnOutputFormatChanged(new OutputFormatChangedEventArgs(null));
                     this.OnTabStatusChanged(null);
@@ -323,6 +329,16 @@ namespace HandBrakeWPF.ViewModels
             }
         }
 
+        public bool MetadataPassthru
+        {
+            get => this.task?.MetaData.PassthruMetadataEnabled ?? false;
+            set
+            {
+                this.task.MetaData.PassthruMetadataEnabled = value;
+                this.NotifyOfPropertyChange(() => this.MetadataPassthru);
+            }
+        }
+
         #endregion
 
         public void SetSource(Source scannedSource, Title selectedTitle, Preset currentPreset, EncodeTask encodeTask)
@@ -330,6 +346,7 @@ namespace HandBrakeWPF.ViewModels
             this.Source = scannedSource;
             this.CurrentTitle = selectedTitle;
             this.Task = encodeTask;
+            this.Task.MetaData = new MetaData(selectedTitle.Metadata, this.MetadataPassthru);
             this.UpdateDisplayedInfo();
             this.SetPreviewControlVisibility();
         }
@@ -354,6 +371,7 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.OptimizeMP4);
             this.NotifyOfPropertyChange(() => this.IPod5GSupport);
             this.NotifyOfPropertyChange(() => this.AlignAVStart);
+            this.NotifyOfPropertyChange(() => this.MetadataPassthru);
         }
 
         public bool MatchesPreset(Preset preset)
@@ -390,7 +408,10 @@ namespace HandBrakeWPF.ViewModels
             }
 
             this.PopulateSummaryTab();
-            this.UpdatePreviewFrame();
+            if (this.ShowPreview)
+            {
+                this.previewDelayProcessor.PerformTask(this.UpdatePreviewFrame, 250);
+            }
         }
 
         public void SetContainer(OutputFormat container)
@@ -465,6 +486,7 @@ namespace HandBrakeWPF.ViewModels
             this.OptimizeMP4 = selectedPreset.Task.OptimizeMP4;
             this.IPod5GSupport = selectedPreset.Task.IPod5GSupport;
             this.AlignAVStart = selectedPreset.Task.AlignAVStart;
+            this.MetadataPassthru = selectedPreset.Task?.MetaData.PassthruMetadataEnabled ?? false;
         }
 
         private void SetExtension(string newExtension)
@@ -540,7 +562,17 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.FiltersInfo);
 
             // Picture Section
-            this.DimensionInfo = string.Format("{0}x{1} {2}, {3}x{4} {5}", this.Task.Width, this.Task.Height, Resources.SummaryView_storage, this.Task.DisplayWidth, this.Task.Height, Resources.SummaryView_display);
+            string storageDesc = Resources.SummaryView_storage;
+            int? width = this.task.Width;
+            int? height = this.task.Height;
+            if (this.task.Padding.Enabled)
+            {
+                storageDesc = string.Format("{0} {1}", Resources.SummaryView_storage, Resources.SummaryView_Padded);
+                width = this.task.Width + this.task.Padding.W;
+                height = this.task.Height + this.task.Padding.H;
+            }
+     
+            this.DimensionInfo = string.Format("{0}x{1} {2}, {3}x{4} {5}", width, height, storageDesc, this.Task.DisplayWidth, this.Task.Height, Resources.SummaryView_display);
             this.NotifyOfPropertyChange(() => this.DimensionInfo);
 
             this.AspectInfo = string.Empty;
@@ -696,7 +728,7 @@ namespace HandBrakeWPF.ViewModels
         private void UpdatePreviewFrame()
         {
             // Don't preview for small images.
-            if (this.Task.Anamorphic == Anamorphic.Loose && this.Task.Width < 32)
+            if (this.Task.Width < 32)
             {
                 this.PreviewNotAvailable = true;
                 this.IsPreviewInfoVisible = false;
@@ -713,7 +745,7 @@ namespace HandBrakeWPF.ViewModels
             BitmapSource image = null;
             try
             {
-                image = this.scanService.GetPreview(this.Task, this.selectedPreview - 1, HBConfigurationFactory.Create()); 
+                image = this.scanService.GetPreview(this.Task, this.selectedPreview - 1); 
             }
             catch (Exception exc)
             {
@@ -723,8 +755,6 @@ namespace HandBrakeWPF.ViewModels
 
             if (image != null)
             {
-                image = BitmapHelpers.CreateTransformedBitmap(image, this.task.Rotation, this.task.FlipVideo);
-
                 this.PreviewNotAvailable = false;
                 this.PreviewImage = image;
                 this.MaxWidth = (int)image.Width;
