@@ -19,9 +19,10 @@ namespace HandBrakeWPF.ViewModels
     using Caliburn.Micro;
 
     using HandBrake.Interop.Interop;
-    using HandBrake.Interop.Interop.Model.Encoding;
+    using HandBrake.Interop.Interop.Interfaces.Model.Encoders;
 
     using HandBrakeWPF.EventArgs;
+    using HandBrakeWPF.Model;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Services.Presets.Model;
@@ -30,14 +31,16 @@ namespace HandBrakeWPF.ViewModels
     using HandBrakeWPF.ViewModels.Interfaces;
 
     using Clipboard = System.Windows.Clipboard;
-    using EncodeTask = HandBrakeWPF.Services.Encode.Model.EncodeTask;
-    using FramerateMode = HandBrakeWPF.Services.Encode.Model.Models.FramerateMode;
-    using OutputFormat = HandBrakeWPF.Services.Encode.Model.Models.OutputFormat;
-    using SettingChangedEventArgs = HandBrakeWPF.EventArgs.SettingChangedEventArgs;
-    using VideoLevel = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoLevel;
-    using VideoPreset = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoPreset;
-    using VideoProfile = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoProfile;
-    using VideoTune = HandBrakeWPF.Services.Encode.Model.Models.Video.VideoTune;
+    using EncodeTask = Services.Encode.Model.EncodeTask;
+    using FramerateMode = Services.Encode.Model.Models.FramerateMode;
+    using OutputFormat = Services.Encode.Model.Models.OutputFormat;
+    using SettingChangedEventArgs = EventArgs.SettingChangedEventArgs;
+    using VideoEncoder = Model.Video.VideoEncoder;
+    using VideoEncodeRateType = Model.Video.VideoEncodeRateType;
+    using VideoLevel = Services.Encode.Model.Models.Video.VideoLevel;
+    using VideoPreset = Services.Encode.Model.Models.Video.VideoPreset;
+    using VideoProfile = Services.Encode.Model.Models.Video.VideoProfile;
+    using VideoTune = Services.Encode.Model.Models.Video.VideoTune;
 
     /// <summary>
     /// The Video View Model
@@ -191,7 +194,9 @@ namespace HandBrakeWPF.ViewModels
                     || this.SelectedVideoEncoder == VideoEncoder.VceH265
                     || this.SelectedVideoEncoder == VideoEncoder.QuickSync
                     || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH265
-                    || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH26510b)
+                    || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH26510b
+                    || this.SelectedVideoEncoder == VideoEncoder.MFH264
+                    || this.SelectedVideoEncoder == VideoEncoder.MFH265)
                 {
                     return false;
                 }
@@ -335,6 +340,8 @@ namespace HandBrakeWPF.ViewModels
                     case VideoEncoder.VceH265:
                     case VideoEncoder.NvencH264:
                     case VideoEncoder.NvencH265:
+                    case VideoEncoder.MFH264:
+                    case VideoEncoder.MFH265:
                         rfValue = 51.0 - value;
                         rfValue = Math.Round(rfValue, 0);
                         this.Task.Quality = rfValue;
@@ -352,7 +359,7 @@ namespace HandBrakeWPF.ViewModels
                 this.NotifyOfPropertyChange(() => this.RF);
                 this.NotifyOfPropertyChange(() => this.DisplayRF);
                 this.NotifyOfPropertyChange(() => this.IsLossless);
-                this.OnTabStatusChanged(null);
+                this.OnTabStatusChanged(new TabStatusEventArgs("filters", ChangedOption.Quality));
             }
         }
 
@@ -373,7 +380,7 @@ namespace HandBrakeWPF.ViewModels
                 }
                 this.Task.VideoBitrate = value;
                 this.NotifyOfPropertyChange(() => this.VideoBitrate);
-                this.OnTabStatusChanged(null);
+                this.OnTabStatusChanged(new TabStatusEventArgs("filters", ChangedOption.Bitrate));
             }
         }
 
@@ -440,7 +447,10 @@ namespace HandBrakeWPF.ViewModels
                 }
 
                 if (this.SelectedVideoEncoder == VideoEncoder.NvencH264
-                    || this.SelectedVideoEncoder == VideoEncoder.NvencH265)
+                    || this.SelectedVideoEncoder == VideoEncoder.NvencH265
+                    || this.SelectedVideoEncoder == VideoEncoder.MFH264
+                    || this.SelectedVideoEncoder == VideoEncoder.MFH265
+                    )
                 {
                     return string.Empty;
                 }
@@ -598,8 +608,9 @@ namespace HandBrakeWPF.ViewModels
                              && this.SelectedVideoEncoder != VideoEncoder.QuickSyncH265
                              && this.SelectedVideoEncoder != VideoEncoder.QuickSyncH26510b
                              && this.SelectedVideoEncoder != VideoEncoder.NvencH264
-                             && this.SelectedVideoEncoder != VideoEncoder.NvencH265;
-
+                             && this.SelectedVideoEncoder != VideoEncoder.NvencH265
+                             && this.SelectedVideoEncoder != VideoEncoder.MFH264
+                             && this.SelectedVideoEncoder != VideoEncoder.MFH265;
             }
         }
 
@@ -959,7 +970,8 @@ namespace HandBrakeWPF.ViewModels
                     || preset.Task.VideoEncoder == VideoEncoder.X265 || preset.Task.VideoEncoder == VideoEncoder.X265_10 || preset.Task.VideoEncoder == VideoEncoder.X265_12
                     || preset.Task.VideoEncoder == VideoEncoder.QuickSync || preset.Task.VideoEncoder == VideoEncoder.QuickSyncH265 || preset.Task.VideoEncoder == VideoEncoder.QuickSyncH26510b
                     || preset.Task.VideoEncoder == VideoEncoder.VceH264 || preset.Task.VideoEncoder == VideoEncoder.VceH265
-                    || preset.Task.VideoEncoder == VideoEncoder.NvencH264 || preset.Task.VideoEncoder == VideoEncoder.NvencH265)
+                    || preset.Task.VideoEncoder == VideoEncoder.NvencH264 || preset.Task.VideoEncoder == VideoEncoder.NvencH265
+                    || preset.Task.VideoEncoder == VideoEncoder.MFH264 || preset.Task.VideoEncoder == VideoEncoder.MFH265)
                 {
                     this.VideoLevel = preset.Task.VideoLevel != null ? preset.Task.VideoLevel.Clone() : this.VideoLevels.FirstOrDefault();
                     this.VideoProfile = preset.Task.VideoProfile != null ? preset.Task.VideoProfile.Clone() : this.VideoProfiles.FirstOrDefault();
@@ -977,6 +989,10 @@ namespace HandBrakeWPF.ViewModels
                                          ?? VideoTune.None;
                     }
                 }
+                else if (preset.Task.VideoEncoder == VideoEncoder.VP8 || preset.Task.VideoEncoder == VideoEncoder.VP9)
+                {
+                    this.VideoPresetValue = preset.Task.VideoPreset != null ? this.VideoPresets.IndexOf(preset.Task.VideoPreset) : 0;
+                }
             }
 
             this.ExtraArguments = preset.Task.ExtraAdvancedArguments;
@@ -1081,7 +1097,8 @@ namespace HandBrakeWPF.ViewModels
                 || this.Task.VideoEncoder == VideoEncoder.X265_12 || this.Task.VideoEncoder == VideoEncoder.QuickSync
                 || this.Task.VideoEncoder == VideoEncoder.QuickSyncH265 || this.Task.VideoEncoder == VideoEncoder.QuickSyncH26510b
                 || this.Task.VideoEncoder == VideoEncoder.VceH264 || this.Task.VideoEncoder == VideoEncoder.VceH265
-                || this.Task.VideoEncoder == VideoEncoder.NvencH264 || this.Task.VideoEncoder == VideoEncoder.NvencH265)
+                || this.Task.VideoEncoder == VideoEncoder.NvencH264 || this.Task.VideoEncoder == VideoEncoder.NvencH265
+                || this.Task.VideoEncoder == VideoEncoder.MFH264 || this.Task.VideoEncoder == VideoEncoder.MFH265)
             {
                 if (!Equals(preset.Task.VideoPreset, this.Task.VideoPreset))
                 {
@@ -1183,6 +1200,8 @@ namespace HandBrakeWPF.ViewModels
                 case VideoEncoder.VceH265:
                 case VideoEncoder.NvencH264:
                 case VideoEncoder.NvencH265:
+                case VideoEncoder.MFH264:
+                case VideoEncoder.MFH265:
                     this.QualityMin = 0;
                     this.QualityMax = 51;
                     break;
@@ -1208,7 +1227,7 @@ namespace HandBrakeWPF.ViewModels
         }
 
         /// <summary>
-        /// The get actualx 264 query.
+        /// The get actual x264 query.
         /// </summary>
         /// <returns>
         /// The <see cref="string"/>.
@@ -1331,10 +1350,13 @@ namespace HandBrakeWPF.ViewModels
                 case VideoEncoder.VceH265:
                 case VideoEncoder.NvencH264:
                 case VideoEncoder.NvencH265:
+                case VideoEncoder.MFH264:
+                case VideoEncoder.MFH265:
 
                     if (this.SelectedVideoEncoder == VideoEncoder.QuickSync || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH265 || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH26510b
                         || this.SelectedVideoEncoder == VideoEncoder.VceH264 || this.SelectedVideoEncoder == VideoEncoder.VceH265
-                        || this.SelectedVideoEncoder == VideoEncoder.NvencH264 || this.SelectedVideoEncoder == VideoEncoder.NvencH265)
+                        || this.SelectedVideoEncoder == VideoEncoder.NvencH264 || this.SelectedVideoEncoder == VideoEncoder.NvencH265
+                        || this.SelectedVideoEncoder == VideoEncoder.MFH264 || this.SelectedVideoEncoder == VideoEncoder.MFH265)
                     {
                         cqStep = 1;
                     }
@@ -1435,14 +1457,9 @@ namespace HandBrakeWPF.ViewModels
                     }
 
                     this.VideoPresetMaxValue = encoder.Presets.Count - 1;
-                    int middlePreset = (int)Math.Round((decimal)(this.VideoPresetMaxValue / 2), 0);
+                    
 
-                    if (selectedEncoder == VideoEncoder.NvencH264 || selectedEncoder == VideoEncoder.NvencH265)
-                    {
-                        middlePreset = this.VideoPresets.IndexOf(this.VideoPresets.FirstOrDefault(s => s.ShortName == "slow"));
-                    }
-
-                    this.VideoPresetValue = middlePreset;
+                    this.VideoPresetValue = GetDefaultEncoderPreset(selectedEncoder);
                 }
                 else
                 {
@@ -1471,7 +1488,8 @@ namespace HandBrakeWPF.ViewModels
                                        this.SelectedVideoEncoder == VideoEncoder.X265 || this.SelectedVideoEncoder == VideoEncoder.X265_10 || this.SelectedVideoEncoder == VideoEncoder.X265_12 ||
                                        this.SelectedVideoEncoder == VideoEncoder.QuickSync || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH265 || this.SelectedVideoEncoder == VideoEncoder.QuickSyncH26510b ||
                                        this.SelectedVideoEncoder == VideoEncoder.VceH264 || this.SelectedVideoEncoder == VideoEncoder.VceH265 ||
-                                       this.SelectedVideoEncoder == VideoEncoder.NvencH264 || this.SelectedVideoEncoder == VideoEncoder.NvencH265;
+                                       this.SelectedVideoEncoder == VideoEncoder.NvencH264 || this.SelectedVideoEncoder == VideoEncoder.NvencH265 ||
+                                       this.SelectedVideoEncoder == VideoEncoder.MFH264 || this.SelectedVideoEncoder == VideoEncoder.MFH265;
 
             this.DisplayFastDecode = this.SelectedVideoEncoder == VideoEncoder.X264 || this.SelectedVideoEncoder == VideoEncoder.X264_10;
             this.NotifyOfPropertyChange(() => this.DisplayFastDecode);
@@ -1492,7 +1510,9 @@ namespace HandBrakeWPF.ViewModels
                                          || this.SelectedVideoEncoder == VideoEncoder.VceH264
                                          || this.SelectedVideoEncoder == VideoEncoder.VceH265
                                          || this.SelectedVideoEncoder == VideoEncoder.NvencH264
-                                         || this.SelectedVideoEncoder == VideoEncoder.NvencH265;
+                                         || this.SelectedVideoEncoder == VideoEncoder.NvencH265
+                                         || this.SelectedVideoEncoder == VideoEncoder.MFH264
+                                         || this.SelectedVideoEncoder == VideoEncoder.MFH265;
 
             // Refresh Display
             this.NotifyOfPropertyChange(() => this.Rfqp);
@@ -1500,17 +1520,14 @@ namespace HandBrakeWPF.ViewModels
             this.NotifyOfPropertyChange(() => this.IsTwoPassEnabled);
             this.NotifyOfPropertyChange(() => this.DisplayTwoPass);
 
-            // Handle some quicksync specific options.
-            if (selectedEncoder == VideoEncoder.QuickSync || selectedEncoder == VideoEncoder.QuickSyncH265 || selectedEncoder == VideoEncoder.QuickSyncH26510b)
-            {
-                this.TwoPass = false;
-                this.TurboFirstPass = false;
-                this.SelectedFramerate = null;
-            }
-
             if (selectedEncoder == VideoEncoder.NvencH264 || selectedEncoder == VideoEncoder.NvencH265 
                                                           || selectedEncoder == VideoEncoder.VceH264 
-                                                          || selectedEncoder == VideoEncoder.VceH265)
+                                                          || selectedEncoder == VideoEncoder.VceH265
+                                                          || selectedEncoder == VideoEncoder.MFH264
+                                                          || selectedEncoder == VideoEncoder.MFH265
+                                                          || selectedEncoder == VideoEncoder.QuickSync
+                                                          || selectedEncoder == VideoEncoder.QuickSyncH265
+                                                          || selectedEncoder == VideoEncoder.QuickSyncH26510b)
             {
                 this.TwoPass = false;
                 this.TurboFirstPass = false;
@@ -1532,5 +1549,44 @@ namespace HandBrakeWPF.ViewModels
 
             this.SetRF(displayRF);
         }
+
+        private int GetDefaultEncoderPreset(VideoEncoder selectedEncoder)
+        {
+            int defaultPreset = (int)Math.Round((decimal)(this.VideoPresetMaxValue / 2), 0);
+
+            // Override for NVEnc
+            if (selectedEncoder == VideoEncoder.NvencH264 || selectedEncoder == VideoEncoder.NvencH265)
+            {
+                defaultPreset = this.VideoPresets.IndexOf(this.VideoPresets.FirstOrDefault(s => s.ShortName == "medium"));
+            }
+
+            // Override for QuickSync
+            if (selectedEncoder == VideoEncoder.QuickSyncH265 || selectedEncoder == VideoEncoder.QuickSyncH26510b)
+            {
+                if (HandBrakeHardwareEncoderHelper.QsvHardwareGeneration > 6) 
+                {
+                    defaultPreset = this.VideoPresets.IndexOf(this.VideoPresets.FirstOrDefault(s => s.ShortName == "speed")); // TGL
+                }
+                else
+                {
+                    defaultPreset = this.VideoPresets.IndexOf(this.VideoPresets.FirstOrDefault(s => s.ShortName == "balanced")); // ICL and Earlier.
+                }
+            }
+
+            if (selectedEncoder == VideoEncoder.QuickSync)
+            {
+                // h264 encoder hasn't changed much in recent years, so stick to balanced. 
+                defaultPreset = this.VideoPresets.IndexOf(this.VideoPresets.FirstOrDefault(s => s.ShortName == "balanced")); 
+            }
+
+            // Override for VCE
+            if (selectedEncoder == VideoEncoder.VceH264 || selectedEncoder == VideoEncoder.VceH265)
+            {
+                // TODO Would be good to have VCE version detection.
+                defaultPreset = this.VideoPresets.IndexOf(this.VideoPresets.FirstOrDefault(s => s.ShortName == "balanced"));
+            }
+
+            return defaultPreset;
+        }
     }
 }
\ No newline at end of file
