@@ -1,15 +1,11 @@
 ﻿// --------------------------------------------------------------------------------------------------------------------
-// <copyright file="QueueTwoView.xaml.cs" company="HandBrake Project (http://handbrake.fr)">
+// <copyright file="QueueView.xaml.cs" company="HandBrake Project (http://handbrake.fr)">
 //   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
 // </copyright>
-// <summary>
-//   Interaction logic for QueueTwoView.xaml
-// </summary>
 // --------------------------------------------------------------------------------------------------------------------
 
 namespace HandBrakeWPF.Views
 {
-    using System.Linq;
     using System.Windows;
     using System.Windows.Controls;
     using System.Windows.Input;
@@ -18,16 +14,10 @@ namespace HandBrakeWPF.Views
     using HandBrakeWPF.Services.Queue.Model;
     using HandBrakeWPF.ViewModels;
 
-    /// <summary>
-    /// Interaction logic for VideoView
-    /// </summary>
     public partial class QueueView : Window
     {
         private QueueTask mouseActiveQueueTask;
 
-        /// <summary>
-        /// Initializes a new instance of the <see cref="QueueView"/> class.
-        /// </summary>
         public QueueView()
         {
             this.InitializeComponent();
@@ -97,10 +87,11 @@ namespace HandBrakeWPF.Views
 
             this.DeleteMenuItem.Header = this.queueJobs.SelectedItems.Count > 1 ? Properties.Resources.QueueView_DeleteSelected : Properties.Resources.QueueView_Delete;
             this.DeleteMenuItem.IsEnabled = this.mouseActiveQueueTask != null || this.queueJobs.SelectedItems.Count >= 1;
-
             this.EditMenuItem.IsEnabled = this.mouseActiveQueueTask != null && this.queueJobs.SelectedItems.Count == 1;
             this.openSourceDir.IsEnabled = this.mouseActiveQueueTask != null && this.queueJobs.SelectedItems.Count == 1;
             this.openDestDir.IsEnabled = this.mouseActiveQueueTask != null && this.queueJobs.SelectedItems.Count == 1;
+            this.moveToBottomMenuItem.IsEnabled = this.mouseActiveQueueTask != null && this.queueJobs.SelectedItems.Count >= 1;
+            this.moveToTopMenuItem.IsEnabled = this.mouseActiveQueueTask != null && this.queueJobs.SelectedItems.Count >= 1;
         }
 
         private static T FindParent<T>(DependencyObject from) where T : class
