@@ -12,31 +12,31 @@ namespace HandBrakeWPF.Views
     using System;
     using System.ComponentModel;
     using System.Drawing;
+    using System.Globalization;
     using System.IO;
     using System.Windows;
-    using System.Windows.Forms;
+    using System.Windows.Controls;
     using System.Windows.Input;
     using System.Windows.Resources;
 
     using Caliburn.Micro;
 
     using HandBrakeWPF.Commands;
+    using HandBrakeWPF.Model;
+    using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Services.Interfaces;
     using HandBrakeWPF.Utilities;
     using HandBrakeWPF.ViewModels.Interfaces;
 
     using Application = System.Windows.Application;
-    using Execute = Caliburn.Micro.Execute;
+    using FlowDirection = System.Windows.FlowDirection;
 
     /// <summary>
     /// Interaction logic for ShellView.xaml
     /// </summary>
     public partial class ShellView
     {
-        /// <summary>
-        /// The my notify icon.
-        /// </summary>
-        private readonly NotifyIcon notifyIcon;
+        private INotifyIconService notifyIconService;
 
         /// <summary>
         /// Initializes a new instance of the <see cref="ShellView"/> class.
@@ -50,23 +50,21 @@ namespace HandBrakeWPF.Views
 
             if (minimiseToTray)
             {
-                INotifyIconService notifyIconService = IoC.Get<INotifyIconService>();
-                this.notifyIcon = new NotifyIcon();
-                this.notifyIcon.ContextMenu = new ContextMenu(new[] { new MenuItem("Restore", NotifyIconClick), new MenuItem("Mini Status Display", ShowMiniStatusDisplay) });
-                notifyIconService.RegisterNotifyIcon(this.notifyIcon);
-
                 StreamResourceInfo streamResourceInfo = Application.GetResourceStream(new Uri("pack://application:,,,/handbrakepineapple.ico"));
                 if (streamResourceInfo != null)
                 {
                     Stream iconStream = streamResourceInfo.Stream;
-                    this.notifyIcon.Icon = new Icon(iconStream);
+
+                    notifyIconService = IoC.Get<INotifyIconService>();
+                    notifyIconService.Setup(new Icon(iconStream));
+                    this.notifyIconService.SetClickCallback(() => this.NotifyIconClick());
                 }
 
-                this.notifyIcon.Click += this.NotifyIconClick;
                 this.StateChanged += this.ShellViewStateChanged;
             }
 
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.E, ModifierKeys.Control)), new KeyGesture(Key.E, ModifierKeys.Control))); // Start Encode
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.P, ModifierKeys.Alt)), new KeyGesture(Key.P, ModifierKeys.Alt))); // Pause Encode
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.K, ModifierKeys.Control)), new KeyGesture(Key.K, ModifierKeys.Control))); // Stop Encode
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.L, ModifierKeys.Control)), new KeyGesture(Key.L, ModifierKeys.Control))); // Open Log Window
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.Q, ModifierKeys.Control)), new KeyGesture(Key.Q, ModifierKeys.Control))); // Open Queue Window
@@ -75,9 +73,9 @@ namespace HandBrakeWPF.Views
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.A, ModifierKeys.Control | ModifierKeys.Shift)), new KeyGesture(Key.A, ModifierKeys.Control | ModifierKeys.Shift))); // Add selection to Queue
 
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Control)), new KeyGesture(Key.O, ModifierKeys.Control))); // File Scan
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Alt)), new KeyGesture(Key.O, ModifierKeys.Alt)));     // Scan Window
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Alt)), new KeyGesture(Key.O, ModifierKeys.Alt))); // Scan Window
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.O, ModifierKeys.Control | ModifierKeys.Shift)), new KeyGesture(Key.O, ModifierKeys.Control | ModifierKeys.Shift))); // Scan a Folder
-            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.G, ModifierKeys.Control | ModifierKeys.Shift)), new KeyGesture(Key.G, ModifierKeys.Control | ModifierKeys.Shift))); // Garbage Colleciton
+            this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.G, ModifierKeys.Control | ModifierKeys.Shift)), new KeyGesture(Key.G, ModifierKeys.Control | ModifierKeys.Shift))); // Garbage Collection
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.F1, ModifierKeys.None)), new KeyGesture(Key.F1, ModifierKeys.None))); // Help
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.S, ModifierKeys.Control)), new KeyGesture(Key.S, ModifierKeys.Control))); // Browse Destination
 
@@ -90,10 +88,26 @@ namespace HandBrakeWPF.Views
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.D6, ModifierKeys.Control)), new KeyGesture(Key.D6, ModifierKeys.Control)));
             this.InputBindings.Add(new InputBinding(new ProcessShortcutCommand(new KeyGesture(Key.D7, ModifierKeys.Control)), new KeyGesture(Key.D7, ModifierKeys.Control)));
 
-            // Enable Windows 7 Taskbar progress indication.
+            // Enable Windows Taskbar progress indication.
             if (this.TaskbarItemInfo == null)
             {
-                this.TaskbarItemInfo = Win7.WindowsTaskbar;
+                this.TaskbarItemInfo = WindowsTaskbar.GetTaskBar();
+            }
+
+            // Setup the Right To Left Mode
+            RightToLeftMode rightToLeft = (RightToLeftMode)userSettingService.GetUserSetting<int>(UserSettingConstants.RightToLeftUi);
+            switch (rightToLeft)
+            {
+                case RightToLeftMode.EntireInterface:
+                    if (Application.Current.MainWindow != null)
+                    {
+                        Application.Current.MainWindow.FlowDirection = FlowDirection.RightToLeft;
+                    }
+                    break;
+                case RightToLeftMode.TextOnly:
+                    FrameworkElement.FlowDirectionProperty.OverrideMetadata(typeof(TextBlock), new FrameworkPropertyMetadata(FlowDirection.RightToLeft));
+                    FrameworkElement.FlowDirectionProperty.OverrideMetadata(typeof(TextBox), new FrameworkPropertyMetadata(FlowDirection.RightToLeft));
+                    break;
             }
         }
 
@@ -116,73 +130,31 @@ namespace HandBrakeWPF.Views
                 }
             }
 
-            if (this.notifyIcon != null)
-            {
-                this.notifyIcon.Visible = false;
-            }
+            this.notifyIconService?.SetVisibility(false);
 
             base.OnClosing(e);
         }
 
-        /// <summary>
-        /// The show mini status display.
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The e.
-        /// </param>
-        private void ShowMiniStatusDisplay(object sender, EventArgs e)
-        {
-            IMiniViewModel titleSpecificView = IoC.Get<IMiniViewModel>();
-            IWindowManager windowManager = IoC.Get<IWindowManager>();
-            Execute.OnUIThread(
-                () =>
-                {
-                    titleSpecificView.Activate();
-                    windowManager.ShowWindow(titleSpecificView);
-                });
-        }
-
-        /// <summary>
-        /// The notify icon_ click.
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The e.
-        /// </param>
-        private void NotifyIconClick(object sender, EventArgs e)
+        private void NotifyIconClick()
         {
             this.WindowState = WindowState.Normal;
-            this.Topmost = true;
+
+            // Bit of a hack but does work
+            this.Topmost = true; 
+            this.Topmost = false;
         }
 
-        /// <summary>
-        /// The shell view state changed.
-        /// </summary>
-        /// <param name="sender">
-        /// The sender.
-        /// </param>
-        /// <param name="e">
-        /// The e.
-        /// </param>
         private void ShellViewStateChanged(object sender, EventArgs e)
         {
-            if (this.notifyIcon != null)
+            if (this.WindowState == WindowState.Minimized)
             {
-                if (this.WindowState == WindowState.Minimized)
-                {
-                    this.ShowInTaskbar = false;
-                    notifyIcon.Visible = true;      
-                }
-                else if (this.WindowState == WindowState.Normal)
-                {
-                    notifyIcon.Visible = false;
-                    this.ShowInTaskbar = true;
-                }
+                this.ShowInTaskbar = false;
+                this.notifyIconService?.SetVisibility(true);
+            }
+            else if (this.WindowState == WindowState.Normal)
+            {
+                this.notifyIconService?.SetVisibility(false);
+                this.ShowInTaskbar = true;
             }
         }
     }
