@@ -10,16 +10,11 @@
 namespace HandBrakeWPF.Views
 {
     using System.Windows;
-    using System.Windows.Controls;
 
-    /// <summary>
-    /// Interaction logic for SubtitlesDefaultsView.xaml
-    /// </summary>
+    using HandBrakeWPF.ViewModels;
+
     public partial class SubtitlesDefaultsView : Window
     {
-        /// <summary>
-        /// Initializes a new instance of the <see cref="SubtitlesDefaultsView"/> class.
-        /// </summary>
         public SubtitlesDefaultsView()
         {
             this.InitializeComponent();
@@ -27,6 +22,7 @@ namespace HandBrakeWPF.Views
 
         private void Apply_OnClick(object sender, RoutedEventArgs e)
         {
+            ((SubtitlesDefaultsViewModel)DataContext).IsApplied = true;
             this.Close();
         }
     }
